package javax.swing;

import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Point;
import java.awt.Rectangle;
import java.beans.PropertyVetoException;
import java.io.Serializable;

public class DefaultDesktopManager implements DesktopManager, Serializable {
   static final String PREVIOUS_BOUNDS_PROPERTY = "previousBounds";
   static final String HAS_BEEN_ICONIFIED_PROPERTY = "wasIconOnce";
   static final int DEFAULT_DRAG_MODE = 0;
   static final int OUTLINE_DRAG_MODE = 1;
   static final int FASTER_DRAG_MODE = 2;
   int dragMode = 0;
   private static JInternalFrame currentActiveFrame = null;
   private transient Rectangle currentBounds = null;
   private transient Graphics desktopGraphics = null;
   private transient Rectangle desktopBounds = null;
   private transient Rectangle[] floatingItems = new Rectangle[0];
   private transient Point currentLoc = null;

   public void activateFrame(JInternalFrame var1) {
      Container var2 = ((Component)var1).getParent();
      if (var2 == null) {
         var2 = var1.getDesktopIcon().getParent();
         if (var2 == null) {
            return;
         }
      }

      if (currentActiveFrame == null) {
         currentActiveFrame = var1;
      } else if (currentActiveFrame != var1) {
         if (currentActiveFrame.isSelected()) {
            try {
               currentActiveFrame.setSelected(false);
            } catch (PropertyVetoException var3) {
            }
         }

         currentActiveFrame = var1;
      }

      var1.moveToFront();
   }

   public void beginDraggingFrame(JComponent var1) {
      this.setupDragMode(var1);
      if (this.dragMode == 2) {
         this.floatingItems = this.findFloatingItems(var1);
         this.currentBounds = ((Component)var1).getBounds();
         this.desktopBounds = ((Component)var1).getParent().getBounds();
         this.desktopBounds.x = 0;
         this.desktopBounds.y = 0;
         this.desktopGraphics = ((Component)var1).getParent().getGraphics();
         ((JInternalFrame)var1).isDragging = true;
      }

   }

   public void beginResizingFrame(JComponent var1, int var2) {
      this.setupDragMode(var1);
   }

   public void closeFrame(JInternalFrame var1) {
      if (((Component)var1).getParent() != null) {
         Container var2 = ((Component)var1).getParent();
         var2.remove(var1);
         ((Component)var2).repaint(((JComponent)var1).getX(), ((JComponent)var1).getY(), ((JComponent)var1).getWidth(), ((JComponent)var1).getHeight());
      }

      this.removeIconFor(var1);
      if (this.getPreviousBounds(var1) != null) {
         this.setPreviousBounds(var1, (Rectangle)null);
      }

      if (this.wasIcon(var1)) {
         this.setWasIcon(var1, (Boolean)null);
      }

   }

   public void deactivateFrame(JInternalFrame var1) {
      if (currentActiveFrame == var1) {
         currentActiveFrame = null;
      }

   }

   public void deiconifyFrame(JInternalFrame var1) {
      JInternalFrame.JDesktopIcon var2 = var1.getDesktopIcon();
      if (((Component)var2).getParent() != null) {
         ((Component)var2).getParent().add(var1);
         this.removeIconFor(var1);

         try {
            var1.setSelected(true);
         } catch (PropertyVetoException var3) {
         }
      }

   }

   public void dragFrame(JComponent var1, int var2, int var3) {
      if (this.dragMode == 1) {
         JDesktopPane var4 = this.getDesktopPane(var1);
         if (var4 != null) {
            Graphics var5 = ((JComponent)var4).getGraphics();
            var5.setXORMode(Color.white);
            if (this.currentLoc != null) {
               var5.drawRect(this.currentLoc.x, this.currentLoc.y, var1.getWidth() - 1, var1.getHeight() - 1);
            }

            var5.drawRect(var2, var3, var1.getWidth() - 1, var1.getHeight() - 1);
            this.currentLoc = new Point(var2, var3);
            var5.setPaintMode();
         }
      } else if (this.dragMode == 2) {
         this.dragFrameFaster(var1, var2, var3);
      } else {
         this.setBoundsForFrame(var1, var2, var3, var1.getWidth(), var1.getHeight());
      }

   }

   private void dragFrameFaster(JComponent var1, int var2, int var3) {
      Rectangle var4 = new Rectangle(this.currentBounds.x, this.currentBounds.y, this.currentBounds.width, this.currentBounds.height);
      this.currentBounds.x = var2;
      this.currentBounds.y = var3;
      if (this.isFloaterCollision(var4, this.currentBounds)) {
         this.setBoundsForFrame(var1, var2, var3, var1.getWidth(), var1.getHeight());
      } else {
         this.emergencyCleanup(var1);
         Rectangle var5 = var4.intersection(this.desktopBounds);
         this.desktopGraphics.copyArea(var5.x, var5.y, var5.width, var5.height, var2 - var4.x, var3 - var4.y);
         ((Component)var1).setBounds(this.currentBounds);
         RepaintManager var6 = RepaintManager.currentManager(var1);
         JComponent var7 = (JComponent)((Component)var1).getParent();
         var6.markCompletelyClean(var7);
         var6.markCompletelyClean(var1);
         Object var8 = null;
         Rectangle[] var11;
         if (var4.intersects(this.currentBounds)) {
            var11 = SwingUtilities.computeDifference(var4, this.currentBounds);
         } else {
            var11 = new Rectangle[]{var4};
         }

         for(int var9 = 0; var9 < var11.length; ++var9) {
            var7.paintImmediately(var11[var9]);
         }

         if (!var5.equals(var4)) {
            var11 = SwingUtilities.computeDifference(var4, this.desktopBounds);

            for(int var10 = 0; var10 < var11.length; ++var10) {
               var11[var10].x += var2 - var4.x;
               var11[var10].y += var3 - var4.y;
               ((JInternalFrame)var1).isDragging = false;
               var7.paintImmediately(var11[var10]);
               ((JInternalFrame)var1).isDragging = true;
            }
         }

      }
   }

   private void emergencyCleanup(JComponent var1) {
      if (((JInternalFrame)var1).danger) {
         SwingUtilities.invokeLater(new 1(var1));
         ((JInternalFrame)var1).danger = false;
      }

   }

   public void endDraggingFrame(JComponent var1) {
      if (this.dragMode == 1 && this.currentLoc != null) {
         this.setBoundsForFrame(var1, this.currentLoc.x, this.currentLoc.y, var1.getWidth(), var1.getHeight());
         this.currentLoc = null;
      } else if (this.dragMode == 2) {
         this.currentBounds = null;
         this.desktopGraphics = null;
         this.desktopBounds = null;
         ((JInternalFrame)var1).isDragging = false;
      }

   }

   public void endResizingFrame(JComponent var1) {
      if (this.dragMode == 1 && this.currentBounds != null) {
         this.setBoundsForFrame(var1, this.currentBounds.x, this.currentBounds.y, this.currentBounds.width, this.currentBounds.height);
         this.currentBounds = null;
      }

   }

   private Rectangle[] findFloatingItems(JComponent var1) {
      Container var2 = ((Component)var1).getParent();
      Component[] var3 = var2.getComponents();
      int var4 = 0;

      for(var4 = 0; var4 < var3.length && var3[var4] != var1; ++var4) {
      }

      Rectangle[] var5 = new Rectangle[var4];

      for(int var7 = 0; var7 < var5.length; ++var7) {
         var5[var7] = var3[var7].getBounds();
      }

      return var5;
   }

   protected Rectangle getBoundsForIconOf(JInternalFrame var1) {
      Container var2 = ((Component)var1).getParent();
      Rectangle var3 = ((Component)var2).getBounds();
      Component[] var4 = var2.getComponents();
      JInternalFrame.JDesktopIcon var5 = var1.getDesktopIcon();
      Dimension var6 = ((JComponent)var5).getPreferredSize();
      Rectangle var7 = null;
      JInternalFrame.JDesktopIcon var8 = null;
      int var9 = 0;
      int var10 = var3.height - var6.height;
      int var11 = var6.width;
      int var12 = var6.height;
      boolean var13 = false;

      while(!var13) {
         var7 = new Rectangle(var9, var10, var11, var12);
         var13 = true;

         for(int var14 = 0; var14 < var4.length; ++var14) {
            if (var4[var14] instanceof JInternalFrame) {
               var8 = ((JInternalFrame)var4[var14]).getDesktopIcon();
            } else if (var4[var14] instanceof JInternalFrame.JDesktopIcon) {
               var8 = (JInternalFrame.JDesktopIcon)var4[var14];
            }

            if (!var8.equals(var5) && var7.intersects(((Component)var8).getBounds())) {
               var13 = false;
               break;
            }
         }

         var9 += ((Component)var8).getBounds().width;
         if (var9 + var11 > var3.width) {
            var9 = 0;
            var10 -= var12;
         }
      }

      return var7;
   }

   JDesktopPane getDesktopPane(JComponent var1) {
      JDesktopPane var2 = null;
      Container var3 = ((Component)var1).getParent();

      while(var2 == null) {
         if (var3 instanceof JDesktopPane) {
            var2 = (JDesktopPane)var3;
         } else {
            if (var3 == null) {
               break;
            }

            var3 = ((Component)var3).getParent();
         }
      }

      return var2;
   }

   protected Rectangle getPreviousBounds(JInternalFrame var1) {
      return (Rectangle)((JComponent)var1).getClientProperty("previousBounds");
   }

   public void iconifyFrame(JInternalFrame var1) {
      JInternalFrame.JDesktopIcon var2 = var1.getDesktopIcon();
      if (!this.wasIcon(var1)) {
         Rectangle var4 = this.getBoundsForIconOf(var1);
         ((Component)var2).setBounds(var4.x, var4.y, var4.width, var4.height);
         this.setWasIcon(var1, Boolean.TRUE);
      }

      Container var3 = ((Component)var1).getParent();
      if (var3 instanceof JLayeredPane) {
         JLayeredPane var7 = (JLayeredPane)var3;
         int var5 = JLayeredPane.getLayer(var1);
         JLayeredPane.putLayer(var2, var5);
      }

      var3.remove(var1);
      var3.add(var2);
      ((Component)var3).repaint(((JComponent)var1).getX(), ((JComponent)var1).getY(), ((JComponent)var1).getWidth(), ((JComponent)var1).getHeight());

      try {
         var1.setSelected(false);
      } catch (PropertyVetoException var6) {
      }

   }

   private boolean isFloaterCollision(Rectangle var1, Rectangle var2) {
      if (this.floatingItems.length == 0) {
         return false;
      } else {
         for(int var3 = 0; var3 < this.floatingItems.length; ++var3) {
            boolean var4 = var1.intersects(this.floatingItems[var3]);
            if (var4) {
               return true;
            }

            boolean var5 = var2.intersects(this.floatingItems[var3]);
            if (var5) {
               return true;
            }
         }

         return false;
      }
   }

   public void maximizeFrame(JInternalFrame var1) {
      Rectangle var2;
      if (!var1.isIcon()) {
         this.setPreviousBounds(var1, ((Component)var1).getBounds());
         var2 = ((Component)var1).getParent().getBounds();
      } else {
         Container var3 = var1.getDesktopIcon().getParent();
         if (var3 == null) {
            return;
         }

         var2 = ((Component)var3).getBounds();

         try {
            var1.setIcon(false);
         } catch (PropertyVetoException var5) {
         }
      }

      this.setBoundsForFrame(var1, 0, 0, var2.width, var2.height);

      try {
         var1.setSelected(true);
      } catch (PropertyVetoException var4) {
      }

      this.removeIconFor(var1);
   }

   public void minimizeFrame(JInternalFrame var1) {
      if (this.getPreviousBounds(var1) != null) {
         Rectangle var2 = this.getPreviousBounds(var1);
         this.setPreviousBounds(var1, (Rectangle)null);

         try {
            var1.setSelected(true);
         } catch (PropertyVetoException var4) {
         }

         if (var1.isIcon()) {
            try {
               var1.setIcon(false);
            } catch (PropertyVetoException var3) {
            }
         }

         this.setBoundsForFrame(var1, var2.x, var2.y, var2.width, var2.height);
      }

      this.removeIconFor(var1);
   }

   public void openFrame(JInternalFrame var1) {
      if (var1.getDesktopIcon().getParent() != null) {
         var1.getDesktopIcon().getParent().add(var1);
         this.removeIconFor(var1);
      }

   }

   protected void removeIconFor(JInternalFrame var1) {
      JInternalFrame.JDesktopIcon var2 = var1.getDesktopIcon();
      Container var3 = ((Component)var2).getParent();
      if (var3 != null) {
         var3.remove(var2);
         ((Component)var3).repaint(((JComponent)var2).getX(), ((JComponent)var2).getY(), ((JComponent)var2).getWidth(), ((JComponent)var2).getHeight());
      }

   }

   public void resizeFrame(JComponent var1, int var2, int var3, int var4, int var5) {
      if (this.dragMode != 0 && this.dragMode != 2) {
         JDesktopPane var6 = this.getDesktopPane(var1);
         if (var6 != null) {
            Graphics var7 = ((JComponent)var6).getGraphics();
            var7.setXORMode(Color.white);
            if (this.currentBounds != null) {
               var7.drawRect(this.currentBounds.x, this.currentBounds.y, this.currentBounds.width - 1, this.currentBounds.height - 1);
            }

            var7.drawRect(var2, var3, var4 - 1, var5 - 1);
            this.currentBounds = new Rectangle(var2, var3, var4, var5);
            var7.setPaintMode();
         }
      } else {
         this.setBoundsForFrame(var1, var2, var3, var4, var5);
      }

   }

   public void setBoundsForFrame(JComponent var1, int var2, int var3, int var4, int var5) {
      boolean var6 = var1.getWidth() != var4 || var1.getHeight() != var5;
      ((Component)var1).setBounds(var2, var3, var4, var5);
      if (var6) {
         ((Container)var1).validate();
      }

   }

   protected void setPreviousBounds(JInternalFrame var1, Rectangle var2) {
      if (var2 != null) {
         ((JComponent)var1).putClientProperty("previousBounds", var2);
      }

   }

   protected void setWasIcon(JInternalFrame var1, Boolean var2) {
      if (var2 != null) {
         ((JComponent)var1).putClientProperty("wasIconOnce", var2);
      }

   }

   private void setupDragMode(JComponent var1) {
      JDesktopPane var2 = this.getDesktopPane(var1);
      if (var2 != null) {
         String var3 = (String)((JComponent)var2).getClientProperty("JDesktopPane.dragMode");
         if (var3 != null && var3.equals("outline")) {
            this.dragMode = 1;
         } else if (var3 != null && var3.equals("faster") && var1 instanceof JInternalFrame) {
            this.dragMode = 2;
         } else {
            this.dragMode = 0;
         }
      }

   }

   protected boolean wasIcon(JInternalFrame var1) {
      return ((JComponent)var1).getClientProperty("wasIconOnce") == Boolean.TRUE;
   }
}
