package javax.swing;

import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Graphics;
import java.awt.LayoutManager;
import java.awt.Rectangle;
import java.util.Hashtable;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;

public class JLayeredPane extends JComponent implements Accessible {
   public static final Integer DEFAULT_LAYER = new Integer(0);
   public static final Integer PALETTE_LAYER = new Integer(100);
   public static final Integer MODAL_LAYER = new Integer(200);
   public static final Integer POPUP_LAYER = new Integer(300);
   public static final Integer DRAG_LAYER = new Integer(400);
   public static final Integer FRAME_CONTENT_LAYER = new Integer(-30000);
   public static final String LAYER_PROPERTY = "layeredContainerLayer";
   private Hashtable componentToLayer;
   private boolean optimizedDrawingPossible = true;

   public JLayeredPane() {
      ((Container)this).setLayout((LayoutManager)null);
   }

   protected void addImpl(Component var1, Object var2, int var3) {
      int var4 = DEFAULT_LAYER;
      if (var2 instanceof Integer) {
         var4 = (Integer)var2;
         this.setLayer(var1, var4);
      } else {
         var4 = this.getLayer(var1);
      }

      int var5 = this.insertIndexForLayer(var4, var3);
      super.addImpl(var1, var2, var5);
      var1.validate();
      var1.repaint();
      this.validateOptimizedDrawing();
   }

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleJLayeredPane(this);
      }

      return super.accessibleContext;
   }

   public int getComponentCountInLayer(int var1) {
      int var5 = 0;
      int var3 = ((Container)this).getComponentCount();

      for(int var2 = 0; var2 < var3; ++var2) {
         int var4 = this.getLayer(((Container)this).getComponent(var2));
         if (var4 == var1) {
            ++var5;
         } else if (var5 > 0 || var4 < var1) {
            break;
         }
      }

      return var5;
   }

   protected Hashtable getComponentToLayer() {
      if (this.componentToLayer == null) {
         this.componentToLayer = new Hashtable(4);
      }

      return this.componentToLayer;
   }

   public Component[] getComponentsInLayer(int var1) {
      int var5 = 0;
      Component[] var6 = new Component[this.getComponentCountInLayer(var1)];
      int var3 = ((Container)this).getComponentCount();

      for(int var2 = 0; var2 < var3; ++var2) {
         int var4 = this.getLayer(((Container)this).getComponent(var2));
         if (var4 == var1) {
            var6[var5++] = ((Container)this).getComponent(var2);
         } else if (var5 > 0 || var4 < var1) {
            break;
         }
      }

      return var6;
   }

   public int getIndexOf(Component var1) {
      int var3 = ((Container)this).getComponentCount();

      for(int var2 = 0; var2 < var3; ++var2) {
         if (var1 == ((Container)this).getComponent(var2)) {
            return var2;
         }
      }

      return -1;
   }

   public int getLayer(Component var1) {
      Integer var2;
      if (var1 instanceof JComponent) {
         var2 = (Integer)((JComponent)var1).getClientProperty("layeredContainerLayer");
      } else {
         var2 = (Integer)this.getComponentToLayer().get(var1);
      }

      return var2 == null ? DEFAULT_LAYER : var2;
   }

   public static int getLayer(JComponent var0) {
      Integer var1;
      return (var1 = (Integer)var0.getClientProperty("layeredContainerLayer")) != null ? var1 : DEFAULT_LAYER;
   }

   public static JLayeredPane getLayeredPaneAbove(Component var0) {
      if (var0 == null) {
         return null;
      } else {
         Container var1;
         for(var1 = var0.getParent(); var1 != null && !(var1 instanceof JLayeredPane); var1 = ((Component)var1).getParent()) {
         }

         return (JLayeredPane)var1;
      }
   }

   protected Integer getObjectForLayer(int var1) {
      Integer var2;
      switch (var1) {
         case 0:
            var2 = DEFAULT_LAYER;
            break;
         case 100:
            var2 = PALETTE_LAYER;
            break;
         case 200:
            var2 = MODAL_LAYER;
            break;
         case 300:
            var2 = POPUP_LAYER;
            break;
         case 400:
            var2 = DRAG_LAYER;
            break;
         default:
            var2 = new Integer(var1);
      }

      return var2;
   }

   public int getPosition(Component var1) {
      int var7 = 0;
      int var3 = ((Container)this).getComponentCount();
      int var6 = this.getIndexOf(var1);
      if (var6 == -1) {
         return -1;
      } else {
         int var4 = this.getLayer(var1);

         for(int var2 = var6 - 1; var2 >= 0; --var2) {
            int var5 = this.getLayer(((Container)this).getComponent(var2));
            if (var5 != var4) {
               return var7;
            }

            ++var7;
         }

         return var7;
      }
   }

   public int highestLayer() {
      return ((Container)this).getComponentCount() > 0 ? this.getLayer(((Container)this).getComponent(0)) : 0;
   }

   protected int insertIndexForLayer(int var1, int var2) {
      int var6 = -1;
      int var7 = -1;
      int var4 = ((Container)this).getComponentCount();

      for(int var3 = 0; var3 < var4; ++var3) {
         int var5 = this.getLayer(((Container)this).getComponent(var3));
         if (var6 == -1 && var5 == var1) {
            var6 = var3;
         }

         if (var5 < var1) {
            if (var3 == 0) {
               var6 = 0;
               var7 = 0;
            } else {
               var7 = var3;
            }
            break;
         }
      }

      if (var6 == -1 && var7 == -1) {
         return var4;
      } else {
         if (var6 != -1 && var7 == -1) {
            var7 = var4;
         }

         if (var7 != -1 && var6 == -1) {
            var6 = var7;
         }

         if (var2 == -1) {
            return var7;
         } else {
            return var2 > -1 && var6 + var2 <= var7 ? var6 + var2 : var7;
         }
      }
   }

   public boolean isOptimizedDrawingEnabled() {
      return this.optimizedDrawingPossible;
   }

   public int lowestLayer() {
      int var1 = ((Container)this).getComponentCount();
      return var1 > 0 ? this.getLayer(((Container)this).getComponent(var1 - 1)) : 0;
   }

   public void moveToBack(Component var1) {
      this.setPosition(var1, this.getComponentCountInLayer(this.getLayer(var1)));
   }

   public void moveToFront(Component var1) {
      this.setPosition(var1, 0);
   }

   public void paint(Graphics var1) {
      if (((JComponent)this).isOpaque()) {
         Rectangle var2 = var1.getClipBounds();
         Color var3 = ((Component)this).getBackground();
         if (var3 == null) {
            var3 = Color.lightGray;
         }

         var1.setColor(var3);
         var1.fillRect(var2.x, var2.y, var2.width, var2.height);
      }

      super.paint(var1);
   }

   protected String paramString() {
      String var1 = this.optimizedDrawingPossible ? "true" : "false";
      return super.paramString() + ",optimizedDrawingPossible=" + var1;
   }

   public static void putLayer(JComponent var0, int var1) {
      Integer var2 = new Integer(var1);
      var0.putClientProperty("layeredContainerLayer", var2);
   }

   public void remove(int var1) {
      ((Container)this).getComponent(var1);
      super.remove(var1);
      this.validateOptimizedDrawing();
   }

   public void setLayer(Component var1, int var2) {
      this.setLayer(var1, var2, -1);
   }

   public void setLayer(Component var1, int var2, int var3) {
      Integer var4 = this.getObjectForLayer(var2);
      if (var2 == this.getLayer(var1) && var3 == this.getPosition(var1)) {
         if (var1 instanceof JComponent) {
            ((JComponent)this).repaint(((JComponent)var1)._bounds);
         } else {
            ((JComponent)this).repaint(var1.getBounds());
         }

      } else {
         if (var1 instanceof JComponent) {
            ((JComponent)var1).putClientProperty("layeredContainerLayer", var4);
         } else {
            this.getComponentToLayer().put(var1, var4);
         }

         if (var1.getParent() != null && var1.getParent() == this) {
            ((Container)this).remove(var1);
            ((Container)this).add(var1, (Object)null, var3);
            if (var1 instanceof JComponent) {
               ((JComponent)this).repaint(((JComponent)var1)._bounds);
            } else {
               ((JComponent)this).repaint(var1.getBounds());
            }

         } else {
            if (var1 instanceof JComponent) {
               ((JComponent)this).repaint(((JComponent)var1)._bounds);
            } else {
               ((JComponent)this).repaint(var1.getBounds());
            }

         }
      }
   }

   public void setPosition(Component var1, int var2) {
      this.setLayer(var1, this.getLayer(var1), var2);
   }

   private void validateOptimizedDrawing() {
      boolean var1 = false;
      Object var2 = ((Component)this).getTreeLock();
      synchronized(var2){}

      try {
         Object var6 = null;
         int var4 = 0;

         for(int var5 = ((Container)this).getComponentCount(); var4 < var5; ++var4) {
            Integer var9 = null;
            if ((((Container)this).getComponent(var4) instanceof JInternalFrame || ((Container)this).getComponent(var4) instanceof JComponent && (var9 = (Integer)((JComponent)((Container)this).getComponent(var4)).getClientProperty("layeredContainerLayer")) != null) && (var9 == null || !var9.equals(FRAME_CONTENT_LAYER))) {
               var1 = true;
               break;
            }
         }
      } catch (Throwable var8) {
         throw var8;
      }

      if (var1) {
         this.optimizedDrawingPossible = false;
      } else {
         this.optimizedDrawingPossible = true;
      }

   }
}
