package javax.swing;

import java.awt.Component;
import java.awt.Container;
import java.awt.Graphics;
import java.awt.Insets;
import java.awt.event.KeyEvent;
import java.awt.event.MouseEvent;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.util.Vector;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;
import javax.swing.plaf.MenuBarUI;

public class JMenuBar extends JComponent implements Accessible, MenuElement {
   private static final String uiClassID = "MenuBarUI";
   private transient SingleSelectionModel selectionModel;
   private boolean paintBorder = true;
   private Insets margin = null;

   public JMenuBar() {
      this.setSelectionModel(new DefaultSingleSelectionModel());
      this.updateUI();
   }

   public JMenu add(JMenu var1) {
      super.add(var1);
      return var1;
   }

   public void addNotify() {
      super.addNotify();
      KeyboardManager.getCurrentManager().registerMenuBar(this);
   }

   JComponent.KeyboardBinding bindingForKeyStroke(KeyStroke var1, int var2) {
      JComponent.KeyboardBinding var3 = super.bindingForKeyStroke(var1, var2);
      if (var3 != null) {
         return var3;
      } else {
         Component[] var5 = ((Container)this).getComponents();

         for(int var4 = 0; var4 < var5.length; ++var4) {
            if (var5[var4] instanceof JMenu) {
               var3 = bindingForKeyStrokeRecursive(var5[var4], var1, var2);
            }

            if (var3 != null) {
               return var3;
            }
         }

         return null;
      }
   }

   static JComponent.KeyboardBinding bindingForKeyStrokeRecursive(Component var0, KeyStroke var1, int var2) {
      JComponent.KeyboardBinding var3 = null;
      if (var0 == null) {
         return null;
      } else {
         if (var0 instanceof JComponent) {
            var3 = ((JComponent)var0).bindingForKeyStroke(var1, var2);
            if (var3 != null) {
               return var3;
            }
         }

         if (var0 instanceof JMenu) {
            JMenu var4 = (JMenu)var0;
            Component[] var6 = var4.getMenuComponents();
            if (var6 != null) {
               for(int var5 = 0; var5 < var6.length; ++var5) {
                  if (var6[var5] instanceof JMenuItem) {
                     var3 = bindingForKeyStrokeRecursive(var6[var5], var1, var2);
                  }

                  if (var3 != null) {
                     return var3;
                  }
               }
            }
         }

         return var3;
      }
   }

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleJMenuBar(this);
      }

      return super.accessibleContext;
   }

   public Component getComponent() {
      return this;
   }

   public Component getComponentAtIndex(int var1) {
      return ((Container)this).getComponent(var1);
   }

   public int getComponentIndex(Component var1) {
      int var2 = ((Container)this).getComponentCount();
      Component[] var3 = ((Container)this).getComponents();

      for(int var4 = 0; var4 < var2; ++var4) {
         Component var5 = var3[var4];
         if (var5 == var1) {
            return var4;
         }
      }

      return -1;
   }

   public JMenu getHelpMenu() {
      throw new Error("getHelpMenu() not yet implemented.");
   }

   public Insets getMargin() {
      return this.margin == null ? new Insets(0, 0, 0, 0) : this.margin;
   }

   public JMenu getMenu(int var1) {
      Component var2 = this.getComponentAtIndex(var1);
      return var2 instanceof JMenu ? (JMenu)var2 : null;
   }

   public int getMenuCount() {
      return ((Container)this).getComponentCount();
   }

   public SingleSelectionModel getSelectionModel() {
      return this.selectionModel;
   }

   public MenuElement[] getSubElements() {
      Vector var2 = new Vector();
      int var3 = ((Container)this).getComponentCount();

      for(int var4 = 0; var4 < var3; ++var4) {
         Component var5 = ((Container)this).getComponent(var4);
         if (var5 instanceof MenuElement) {
            var2.addElement(var5);
         }
      }

      MenuElement[] var1 = new MenuElement[var2.size()];
      int var7 = 0;

      for(int var6 = var2.size(); var7 < var6; ++var7) {
         var1[var7] = (MenuElement)var2.elementAt(var7);
      }

      return var1;
   }

   public MenuBarUI getUI() {
      return (MenuBarUI)super.ui;
   }

   public String getUIClassID() {
      return "MenuBarUI";
   }

   public boolean isBorderPainted() {
      return this.paintBorder;
   }

   public boolean isManagingFocus() {
      return true;
   }

   public boolean isSelected() {
      return this.selectionModel.isSelected();
   }

   public void menuSelectionChanged(boolean var1) {
   }

   protected void paintBorder(Graphics var1) {
      if (this.isBorderPainted()) {
         super.paintBorder(var1);
      }

   }

   protected String paramString() {
      String var1 = this.paintBorder ? "true" : "false";
      String var2 = this.margin != null ? this.margin.toString() : "";
      return super.paramString() + ",margin=" + var2 + ",paintBorder=" + var1;
   }

   public void processKeyEvent(KeyEvent var1, MenuElement[] var2, MenuSelectionManager var3) {
   }

   public void processMouseEvent(MouseEvent var1, MenuElement[] var2, MenuSelectionManager var3) {
   }

   private void readObject(ObjectInputStream var1) throws IOException, ClassNotFoundException {
      var1.defaultReadObject();
      Object[] var2 = var1.readObject();

      for(int var3 = 0; var3 < var2.length && var2[var3] != null; var3 += 2) {
         if (var2[var3].equals("selectionModel")) {
            this.selectionModel = (SingleSelectionModel)var2[var3 + 1];
         }
      }

      if (super.ui != null && this.getUIClassID().equals("MenuBarUI")) {
         super.ui.installUI(this);
      }

   }

   public void removeNotify() {
      super.removeNotify();
      KeyboardManager.getCurrentManager().unregisterMenuBar(this);
   }

   public void setBorderPainted(boolean var1) {
      boolean var2 = this.paintBorder;
      this.paintBorder = var1;
      ((JComponent)this).firePropertyChange("borderPainted", var2, this.paintBorder);
      if (var1 != var2) {
         ((JComponent)this).revalidate();
         ((Component)this).repaint();
      }

   }

   public void setHelpMenu(JMenu var1) {
      throw new Error("setHelpMenu() not yet implemented.");
   }

   public void setMargin(Insets var1) {
      Insets var2 = this.margin;
      this.margin = var1;
      ((JComponent)this).firePropertyChange("margin", var2, var1);
      if (var2 == null || !var1.equals(var2)) {
         ((JComponent)this).revalidate();
         ((Component)this).repaint();
      }

   }

   public void setSelected(Component var1) {
      SingleSelectionModel var2 = this.getSelectionModel();
      int var3 = this.getComponentIndex(var1);
      var2.setSelectedIndex(var3);
   }

   public void setSelectionModel(SingleSelectionModel var1) {
      SingleSelectionModel var2 = this.selectionModel;
      this.selectionModel = var1;
      ((JComponent)this).firePropertyChange("selectionModel", var2, this.selectionModel);
   }

   public void setUI(MenuBarUI var1) {
      super.setUI(var1);
   }

   public void updateUI() {
      this.setUI((MenuBarUI)UIManager.getUI(this));
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      Object[] var2 = new Object[4];
      int var3 = 0;
      if (this.selectionModel instanceof Serializable) {
         var2[var3++] = "selectionModel";
         var2[var3++] = this.selectionModel;
      }

      var1.writeObject(var2);
   }
}
