package javax.swing;

import java.awt.Component;
import java.awt.Container;
import java.awt.Insets;
import java.awt.LayoutManager;
import java.awt.Rectangle;
import java.io.IOException;
import java.io.ObjectOutputStream;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;
import javax.swing.border.Border;
import javax.swing.plaf.ScrollPaneUI;

public class JScrollPane extends JComponent implements ScrollPaneConstants, Accessible {
   private Border viewportBorder;
   private static final String uiClassID = "ScrollPaneUI";
   protected int verticalScrollBarPolicy;
   protected int horizontalScrollBarPolicy;
   protected JViewport viewport;
   protected JScrollBar verticalScrollBar;
   protected JScrollBar horizontalScrollBar;
   protected JViewport rowHeader;
   protected JViewport columnHeader;
   protected Component lowerLeft;
   protected Component lowerRight;
   protected Component upperLeft;
   protected Component upperRight;

   public JScrollPane() {
      this((Component)null, 20, 30);
   }

   public JScrollPane(int var1, int var2) {
      this((Component)null, var1, var2);
   }

   public JScrollPane(Component var1) {
      this(var1, 20, 30);
   }

   public JScrollPane(Component var1, int var2, int var3) {
      this.verticalScrollBarPolicy = 20;
      this.horizontalScrollBarPolicy = 30;
      this.setLayout(new ScrollPaneLayout.UIResource());
      this.setVerticalScrollBarPolicy(var2);
      this.setHorizontalScrollBarPolicy(var3);
      this.setViewport(this.createViewport());
      this.setVerticalScrollBar(this.createVerticalScrollBar());
      this.setHorizontalScrollBar(this.createHorizontalScrollBar());
      if (var1 != null) {
         this.setViewportView(var1);
      }

      this.updateUI();
   }

   public JScrollBar createHorizontalScrollBar() {
      return new ScrollBar(this, 0);
   }

   public JScrollBar createVerticalScrollBar() {
      return new ScrollBar(this, 1);
   }

   protected JViewport createViewport() {
      return new JViewport();
   }

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleJScrollPane(this);
      }

      return super.accessibleContext;
   }

   public JViewport getColumnHeader() {
      return this.columnHeader;
   }

   public Component getCorner(String var1) {
      if (var1.equals("LOWER_LEFT_CORNER")) {
         return this.lowerLeft;
      } else if (var1.equals("LOWER_RIGHT_CORNER")) {
         return this.lowerRight;
      } else if (var1.equals("UPPER_LEFT_CORNER")) {
         return this.upperLeft;
      } else {
         return var1.equals("UPPER_RIGHT_CORNER") ? this.upperRight : null;
      }
   }

   public JScrollBar getHorizontalScrollBar() {
      return this.horizontalScrollBar;
   }

   public int getHorizontalScrollBarPolicy() {
      return this.horizontalScrollBarPolicy;
   }

   public JViewport getRowHeader() {
      return this.rowHeader;
   }

   public ScrollPaneUI getUI() {
      return (ScrollPaneUI)super.ui;
   }

   public String getUIClassID() {
      return "ScrollPaneUI";
   }

   public JScrollBar getVerticalScrollBar() {
      return this.verticalScrollBar;
   }

   public int getVerticalScrollBarPolicy() {
      return this.verticalScrollBarPolicy;
   }

   public JViewport getViewport() {
      return this.viewport;
   }

   public Border getViewportBorder() {
      return this.viewportBorder;
   }

   public Rectangle getViewportBorderBounds() {
      Rectangle var1 = new Rectangle(((Component)this).getSize());
      Insets var2 = ((JComponent)this).getInsets();
      var1.x = var2.left;
      var1.y = var2.top;
      var1.width -= var2.left + var2.right;
      var1.height -= var2.top + var2.bottom;
      JViewport var3 = this.getColumnHeader();
      if (var3 != null && ((Component)var3).isVisible()) {
         int var4 = ((JComponent)var3).getHeight();
         var1.y += var4;
         var1.height -= var4;
      }

      JViewport var7 = this.getRowHeader();
      if (var7 != null && ((Component)var7).isVisible()) {
         int var5 = ((JComponent)var7).getWidth();
         var1.x += var5;
         var1.width -= var5;
      }

      JScrollBar var8 = this.getVerticalScrollBar();
      if (var8 != null && ((Component)var8).isVisible()) {
         var1.width -= ((JComponent)var8).getWidth();
      }

      JScrollBar var6 = this.getHorizontalScrollBar();
      if (var6 != null && ((Component)var6).isVisible()) {
         var1.height -= ((JComponent)var6).getHeight();
      }

      return var1;
   }

   public boolean isOpaque() {
      JViewport var1;
      Component var2;
      return (var1 = this.getViewport()) != null && (var2 = var1.getView()) != null && var2 instanceof JComponent && ((JComponent)var2).isOpaque() && ((JComponent)var2).getWidth() >= ((JComponent)var1).getWidth() && ((JComponent)var2).getHeight() >= ((JComponent)var1).getHeight();
   }

   public boolean isValidateRoot() {
      return true;
   }

   protected String paramString() {
      String var1 = this.viewportBorder != null ? this.viewportBorder.toString() : "";
      String var2 = this.viewport != null ? this.viewport.toString() : "";
      String var3;
      if (this.verticalScrollBarPolicy == 20) {
         var3 = "VERTICAL_SCROLLBAR_AS_NEEDED";
      } else if (this.verticalScrollBarPolicy == 21) {
         var3 = "VERTICAL_SCROLLBAR_NEVER";
      } else if (this.verticalScrollBarPolicy == 22) {
         var3 = "VERTICAL_SCROLLBAR_ALWAYS";
      } else {
         var3 = "";
      }

      String var4;
      if (this.horizontalScrollBarPolicy == 30) {
         var4 = "HORIZONTAL_SCROLLBAR_AS_NEEDED";
      } else if (this.horizontalScrollBarPolicy == 31) {
         var4 = "HORIZONTAL_SCROLLBAR_NEVER";
      } else if (this.horizontalScrollBarPolicy == 32) {
         var4 = "HORIZONTAL_SCROLLBAR_ALWAYS";
      } else {
         var4 = "";
      }

      String var5 = this.horizontalScrollBar != null ? this.horizontalScrollBar.toString() : "";
      String var6 = this.verticalScrollBar != null ? this.verticalScrollBar.toString() : "";
      String var7 = this.columnHeader != null ? this.columnHeader.toString() : "";
      String var8 = this.rowHeader != null ? this.rowHeader.toString() : "";
      String var9 = this.lowerLeft != null ? this.lowerLeft.toString() : "";
      String var10 = this.lowerRight != null ? this.lowerRight.toString() : "";
      String var11 = this.upperLeft != null ? this.upperLeft.toString() : "";
      String var12 = this.upperRight != null ? this.upperRight.toString() : "";
      return super.paramString() + ",columnHeader=" + var7 + ",horizontalScrollBar=" + var5 + ",horizontalScrollBarPolicy=" + var4 + ",lowerLeft=" + var9 + ",lowerRight=" + var10 + ",rowHeader=" + var8 + ",upperLeft=" + var11 + ",upperRight=" + var12 + ",verticalScrollBar=" + var6 + ",verticalScrollBarPolicy=" + var3 + ",viewport=" + var2 + ",viewportBorder=" + var1;
   }

   public void setColumnHeader(JViewport var1) {
      JViewport var2 = this.getColumnHeader();
      this.columnHeader = var1;
      if (var1 != null) {
         ((Container)this).add(var1, "COLUMN_HEADER");
      } else if (var2 != null) {
         ((Container)this).remove(var1);
      }

      ((JComponent)this).firePropertyChange("columnHeader", var2, var1);
      ((JComponent)this).revalidate();
      ((Component)this).repaint();
   }

   public void setColumnHeaderView(Component var1) {
      if (this.getColumnHeader() == null) {
         this.setColumnHeader(this.createViewport());
      }

      this.getColumnHeader().setView(var1);
   }

   public void setCorner(String var1, Component var2) {
      Component var3;
      if (var1.equals("LOWER_LEFT_CORNER")) {
         var3 = this.lowerLeft;
         this.lowerLeft = var2;
      } else if (var1.equals("LOWER_RIGHT_CORNER")) {
         var3 = this.lowerRight;
         this.lowerRight = var2;
      } else if (var1.equals("UPPER_LEFT_CORNER")) {
         var3 = this.upperLeft;
         this.upperLeft = var2;
      } else {
         if (!var1.equals("UPPER_RIGHT_CORNER")) {
            throw new IllegalArgumentException("invalid corner key");
         }

         var3 = this.upperRight;
         this.upperRight = var2;
      }

      ((Container)this).add(var2, var1);
      ((JComponent)this).firePropertyChange(var1, var3, var2);
   }

   public void setHorizontalScrollBar(JScrollBar var1) {
      JScrollBar var2 = this.getHorizontalScrollBar();
      this.horizontalScrollBar = var1;
      ((Container)this).add(var1, "HORIZONTAL_SCROLLBAR");
      ((JComponent)this).firePropertyChange("horizontalScrollBar", var2, var1);
   }

   public void setHorizontalScrollBarPolicy(int var1) {
      switch (var1) {
         case 30:
         case 31:
         case 32:
            int var2 = this.horizontalScrollBarPolicy;
            this.horizontalScrollBarPolicy = var1;
            ((JComponent)this).firePropertyChange("horizontalScrollBarPolicy", var2, var1);
            return;
         default:
            throw new IllegalArgumentException("invalid horizontalScrollBarPolicy");
      }
   }

   public void setLayout(LayoutManager var1) {
      if (var1 != null && !(var1 instanceof ScrollPaneLayout)) {
         String var2 = "layout of JScrollPane must be a ScrollPaneLayout";
         throw new ClassCastException(var2);
      } else {
         super.setLayout(var1);
      }
   }

   public void setRowHeader(JViewport var1) {
      JViewport var2 = this.getRowHeader();
      this.rowHeader = var1;
      if (var1 != null) {
         ((Container)this).add(var1, "ROW_HEADER");
      } else if (var2 != null) {
         ((Container)this).remove(var2);
      }

      ((JComponent)this).firePropertyChange("rowHeader", var2, var1);
   }

   public void setRowHeaderView(Component var1) {
      if (this.getRowHeader() == null) {
         this.setRowHeader(this.createViewport());
      }

      this.getRowHeader().setView(var1);
   }

   public void setUI(ScrollPaneUI var1) {
      super.setUI(var1);
   }

   public void setVerticalScrollBar(JScrollBar var1) {
      JScrollBar var2 = this.getVerticalScrollBar();
      this.verticalScrollBar = var1;
      ((Container)this).add(var1, "VERTICAL_SCROLLBAR");
      ((JComponent)this).firePropertyChange("verticalScrollBar", var2, var1);
   }

   public void setVerticalScrollBarPolicy(int var1) {
      switch (var1) {
         case 20:
         case 21:
         case 22:
            int var2 = this.verticalScrollBarPolicy;
            this.verticalScrollBarPolicy = var1;
            ((JComponent)this).firePropertyChange("verticalScrollBarPolicy", var2, var1);
            return;
         default:
            throw new IllegalArgumentException("invalid verticalScrollBarPolicy");
      }
   }

   public void setViewport(JViewport var1) {
      JViewport var2 = this.getViewport();
      this.viewport = var1;
      if (var1 != null) {
         ((Container)this).add(var1, "VIEWPORT");
      } else if (var2 != null) {
         ((Container)this).remove(var2);
      }

      ((JComponent)this).firePropertyChange("viewport", var2, var1);
      if (super.accessibleContext != null) {
         ((AccessibleJScrollPane)super.accessibleContext).resetViewPort();
      }

      ((JComponent)this).revalidate();
      ((Component)this).repaint();
   }

   public void setViewportBorder(Border var1) {
      Border var2 = this.viewportBorder;
      this.viewportBorder = var1;
      ((JComponent)this).firePropertyChange("viewportBorder", var2, var1);
   }

   public void setViewportView(Component var1) {
      if (this.getViewport() == null) {
         this.setViewport(this.createViewport());
      }

      this.getViewport().setView(var1);
   }

   public void updateUI() {
      this.setUI((ScrollPaneUI)UIManager.getUI(this));
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      if (super.ui != null && this.getUIClassID().equals("ScrollPaneUI")) {
         super.ui.installUI(this);
      }

   }
}
