package javax.swing.colorchooser;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Image;
import java.awt.Point;
import java.awt.Toolkit;
import javax.swing.ButtonGroup;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSlider;
import javax.swing.JTextField;
import javax.swing.UIManager;
import javax.swing.border.EmptyBorder;

class DefaultHSBChooserPanel extends AbstractColorChooserPanel {
   float[] hsb = new float[3];
   AbstractHSBImage palette;
   AbstractHSBImage sliderPalette;
   JSlider slider;
   JIntegerTextField hField;
   JIntegerTextField sField;
   JIntegerTextField bField;
   JTextField redField;
   JTextField greenField;
   JTextField blueField;
   boolean isAdjusting = false;
   boolean isUpdatingOften = false;
   Point paletteSelection = new Point();
   JLabel paletteLabel;
   JLabel sliderPaletteLabel;
   JRadioButton hRadio;
   JRadioButton sRadio;
   JRadioButton bRadio;
   Image paletteImage;
   Image sliderImage;
   static final int PALETTE_DIMENSION = 200;
   static final int MAX_HUE_VALUE = 359;
   static final int MAX_SATURATION_VALUE = 99;
   static final int MAX_BRIGHTNESS_VALUE = 99;
   int sliderType = 0;
   static final int HUE_SLIDER = 0;
   static final int SATURATION_SLIDER = 1;
   static final int BRIGHTNESS_SLIDER = 2;

   public DefaultHSBChooserPanel() {
   }

   protected void addPaletteListeners() {
      this.paletteLabel.addMouseListener(new 1(this));
      this.paletteLabel.addMouseMotionListener(new 2(this));
   }

   protected void addSliderListeners() {
      this.slider.addChangeListener(new 3(this));
   }

   protected void buildChooser() {
      Color var1 = ((AbstractColorChooserPanel)this).getColorFromModel();
      Color.RGBtoHSB(var1.getRed(), var1.getGreen(), var1.getBlue(), this.hsb);
      ((Container)this).setLayout(new BorderLayout());
      JComponent var2 = this.buildSliderPalettePanel();
      ((Container)this).add(var2, "West");
      JPanel var3 = new JPanel(new SmartGridLayout(1, 3));
      JComponent var4 = this.buildHSBControls();
      ((Container)var3).add(var4);
      ((Container)var3).add(new JLabel(" "));
      JComponent var5 = this.buildRGBControls();
      ((Container)var3).add(var5);
      ((JComponent)var3).setBorder(new EmptyBorder(10, 5, 10, 5));
      ((Container)this).add(var3, "Center");
   }

   protected JComponent buildHSBControls() {
      String var1 = UIManager.getString("ColorChooser.hsbHueText");
      String var2 = UIManager.getString("ColorChooser.hsbSaturationText");
      String var3 = UIManager.getString("ColorChooser.hsbBrightnessText");
      JPanel var4 = new JPanel(new SmartGridLayout(2, 3));
      this.hField = new JIntegerTextField(0, 359, (int)(this.hsb[0] * 359.0F));
      this.sField = new JIntegerTextField(0, 100, (int)(this.hsb[1] * 100.0F));
      this.bField = new JIntegerTextField(0, 100, (int)(this.hsb[2] * 100.0F));
      ButtonGroup var5 = new ButtonGroup();
      this.hRadio = new JRadioButton(var1);
      var5.add(this.hRadio);
      this.hRadio.addActionListener(new 4(this));
      this.sRadio = new JRadioButton(var2);
      var5.add(this.sRadio);
      this.sRadio.addActionListener(new 5(this));
      this.bRadio = new JRadioButton(var3);
      var5.add(this.bRadio);
      this.bRadio.addActionListener(new 6(this));
      this.hRadio.setSelected(true);
      NumberListener var6 = new NumberListener(this);
      this.hField.getDocument().addDocumentListener(var6);
      this.sField.getDocument().addDocumentListener(var6);
      this.bField.getDocument().addDocumentListener(var6);
      ((Container)var4).add(this.hRadio);
      ((Container)var4).add(this.hField);
      ((Container)var4).add(this.sRadio);
      ((Container)var4).add(this.sField);
      ((Container)var4).add(this.bRadio);
      ((Container)var4).add(this.bField);
      return var4;
   }

   protected JComponent buildRGBControls() {
      JPanel var1 = new JPanel(new SmartGridLayout(2, 3));
      Color var2 = ((AbstractColorChooserPanel)this).getColorFromModel();
      this.redField = new JTextField(String.valueOf(var2.getRed()));
      this.redField.setEditable(false);
      this.greenField = new JTextField(String.valueOf(var2.getGreen()));
      this.greenField.setEditable(false);
      this.blueField = new JTextField(String.valueOf(var2.getBlue()));
      this.blueField.setEditable(false);
      String var3 = UIManager.getString("ColorChooser.hsbRedText");
      String var4 = UIManager.getString("ColorChooser.hsbGreenText");
      String var5 = UIManager.getString("ColorChooser.hsbBlueText");
      ((Container)var1).add(new JLabel(var3));
      ((Container)var1).add(this.redField);
      ((Container)var1).add(new JLabel(var4));
      ((Container)var1).add(this.greenField);
      ((Container)var1).add(new JLabel(var5));
      ((Container)var1).add(this.blueField);
      return var1;
   }

   protected JComponent buildSliderPalettePanel() {
      JPanel var1 = new JPanel();
      this.palette = new SaturationBrightnessImage(this, 200, 200, this.hsb[0]);
      this.sliderPalette = new HueImage(this, 16, 200);
      this.slider = new JSlider(1, 0, 359, 0);
      this.slider.setPaintTrack(false);
      Dimension var2 = this.slider.getPreferredSize();
      this.slider.setPreferredSize(new Dimension(var2.width, 215));
      this.slider.setInverted(true);
      this.addSliderListeners();
      this.paletteLabel = this.createPaletteLabel();
      this.paletteImage = Toolkit.getDefaultToolkit().createImage(this.palette);
      this.paletteLabel.setIcon(new ImageIcon(this.paletteImage));
      this.addPaletteListeners();
      ((Container)var1).add(this.paletteLabel);
      ((Container)var1).add(this.slider);
      this.sliderPaletteLabel = new JLabel();
      this.sliderImage = Toolkit.getDefaultToolkit().createImage(this.sliderPalette);
      this.sliderPaletteLabel.setIcon(new ImageIcon(this.sliderImage));
      ((Container)var1).add(this.sliderPaletteLabel);
      return var1;
   }

   protected JLabel createPaletteLabel() {
      return new 7(this);
   }

   public String getDisplayName() {
      return UIManager.getString("ColorChooser.hsbNameText");
   }

   public Icon getLargeDisplayIcon() {
      return null;
   }

   public Icon getSmallDisplayIcon() {
      return null;
   }

   protected void repaintPaletteSelection() {
      this.paletteLabel.repaint();
   }

   protected void setBrightnessMode() {
      this.sliderType = 2;
      this.slider.setInverted(false);
      this.slider.setMaximum(99);
      this.palette = new HueSaturationImage(this, 200, 200, this.hsb[0], this.hsb[2]);
      this.sliderPalette = new BrightnessImage(this, 16, 200, this.hsb[0]);
      this.paletteImage.flush();
      this.sliderImage.flush();
      this.paletteImage = Toolkit.getDefaultToolkit().createImage(this.palette);
      this.sliderImage = Toolkit.getDefaultToolkit().createImage(this.sliderPalette);
      this.paletteLabel.setIcon(new ImageIcon(this.paletteImage));
      this.sliderPaletteLabel.setIcon(new ImageIcon(this.sliderImage));
      this.updateHSB(this.hsb[0], this.hsb[1], this.hsb[2]);
      ((Component)this).repaint();
   }

   protected void setHueMode() {
      this.sliderType = 0;
      this.slider.setInverted(true);
      this.slider.setMaximum(359);
      this.palette = new SaturationBrightnessImage(this, 200, 200, this.hsb[0]);
      this.sliderPalette = new HueImage(this, 16, 200);
      this.paletteImage.flush();
      this.sliderImage.flush();
      this.paletteImage = Toolkit.getDefaultToolkit().createImage(this.palette);
      this.sliderImage = Toolkit.getDefaultToolkit().createImage(this.sliderPalette);
      this.paletteLabel.setIcon(new ImageIcon(this.paletteImage));
      this.sliderPaletteLabel.setIcon(new ImageIcon(this.sliderImage));
      this.updateHSB(this.hsb[0], this.hsb[1], this.hsb[2]);
      ((Component)this).repaint();
   }

   protected void setSaturationMode() {
      this.sliderType = 1;
      this.slider.setInverted(false);
      this.slider.setMaximum(99);
      this.palette = new HueBrightnessImage(this, 200, 200, this.hsb[0], this.hsb[1]);
      this.sliderPalette = new SaturationImage(this, 16, 200, this.hsb[0]);
      this.paletteImage.flush();
      this.sliderImage.flush();
      this.paletteImage = Toolkit.getDefaultToolkit().createImage(this.palette);
      this.sliderImage = Toolkit.getDefaultToolkit().createImage(this.sliderPalette);
      this.paletteLabel.setIcon(new ImageIcon(this.paletteImage));
      this.sliderPaletteLabel.setIcon(new ImageIcon(this.sliderImage));
      this.updateHSB(this.hsb[0], this.hsb[1], this.hsb[2]);
      ((Component)this).repaint();
   }

   public void updateChooser() {
      if (!this.isAdjusting) {
         Color var1 = ((AbstractColorChooserPanel)this).getColorFromModel();
         Color.RGBtoHSB(var1.getRed(), var1.getGreen(), var1.getBlue(), this.hsb);
         this.updateHSB(this.hsb[0], this.hsb[1], this.hsb[2]);
      }

   }

   protected void updateHSB(float var1, float var2, float var3) {
      if (!this.isAdjusting) {
         this.isAdjusting = true;
         this.updatePalette(var1, var2, var3);
         this.updateSliderPalette(var1, var2, var3);
         this.updateSlider(var1, var2, var3);
         this.updateHSBTextFields(var1, var2, var3);
         Color var4 = new Color(this.palette.getRGBForLocation(this.paletteSelection.x, this.paletteSelection.y));
         this.updateRGBTextFields(var4);
         ((AbstractColorChooserPanel)this).getColorSelectionModel().setSelectedColor(var4);
         this.isAdjusting = false;
      }

   }

   protected void updateHSBTextFields(float var1, float var2, float var3) {
      int var4 = Math.round(var1 * 359.0F);
      int var5 = Math.round(var2 * 100.0F);
      int var6 = Math.round(var3 * 100.0F);
      if (this.hField.getIntegerValue() != var4) {
         this.hField.setText(String.valueOf(var4));
      }

      if (this.sField.getIntegerValue() != var5) {
         this.sField.setText(String.valueOf(var5));
      }

      if (this.bField.getIntegerValue() != var6) {
         this.bField.setText(String.valueOf(var6));
      }

   }

   protected void updatePalette(float var1, float var2, float var3) {
      int var4 = 0;
      int var5 = 0;
      switch (this.sliderType) {
         case 0:
            if (var1 != this.palette.getHue()) {
               this.palette.setHue(var1);
               this.palette.nextFrame(0);
            }

            var4 = 200 - (int)(var2 * 200.0F);
            var5 = 200 - (int)(var3 * 200.0F);
            break;
         case 1:
            if (var2 != this.palette.getSaturation()) {
               this.palette.setSaturation(var2);
               this.palette.nextFrame(0);
            }

            var4 = (int)(var1 * 200.0F);
            var5 = 200 - (int)(var3 * 200.0F);
            break;
         case 2:
            if (var3 != this.palette.getBrightness()) {
               this.palette.setBrightness(var3);
               this.palette.nextFrame(0);
            }

            var4 = (int)(var1 * 200.0F);
            var5 = 200 - (int)(var2 * 200.0F);
      }

      this.paletteSelection.setLocation(var4, var5);
      this.repaintPaletteSelection();
   }

   protected void updateRGBTextFields(Color var1) {
      this.redField.setText(String.valueOf(var1.getRed()));
      this.greenField.setText(String.valueOf(var1.getGreen()));
      this.blueField.setText(String.valueOf(var1.getBlue()));
   }

   protected void updateSlider(float var1, float var2, float var3) {
      float var4 = 0.0F;
      switch (this.sliderType) {
         case 0:
            var4 = var1;
            break;
         case 1:
            var4 = var2;
            break;
         case 2:
            var4 = var3;
      }

      this.slider.setValue(Math.round(var4 * (float)(this.slider.getMaximum() + 1)));
   }

   protected void updateSliderPalette(float var1, float var2, float var3) {
      if (this.sliderType != 0 && var1 != this.sliderPalette.getHue()) {
         this.sliderPalette.setHue(var1);
         this.sliderPalette.nextFrame(0);
      }

   }
}
