package javax.swing.colorchooser;

import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Toolkit;
import javax.swing.JComponent;
import javax.swing.JPanel;

class DefaultPreviewPanel extends JPanel {
   private int squareSize = 25;
   private int squareGap = 5;
   private int innerGap = 5;
   private int textGap = 5;
   private Font font = new Font("Dialog", 0, 12);
   private String sampleText = "Sample Text  Sample Text";
   private int swatchWidth = 50;
   private Color oldColor = null;

   public Dimension getPreferredSize() {
      FontMetrics var1 = Toolkit.getDefaultToolkit().getFontMetrics(((Component)this).getFont());
      int var2 = var1.getAscent();
      int var3 = var1.getHeight();
      int var4 = var1.stringWidth(this.sampleText);
      int var5 = var3 * 3 + this.textGap * 3;
      int var6 = this.squareSize * 3 + this.squareGap * 4 + this.swatchWidth + var4;
      return new Dimension(var6, var5);
   }

   public void paintComponent(Graphics var1) {
      if (this.oldColor == null) {
         this.oldColor = ((Component)this).getForeground();
      }

      var1.setColor(((Component)this).getBackground());
      var1.fillRect(0, 0, ((JComponent)this).getWidth(), ((JComponent)this).getHeight());
      int var2 = this.paintSquares(var1);
      int var3 = this.paintText(var1, var2);
      this.paintSwatch(var1, var2 + var3);
   }

   private int paintSquares(Graphics var1) {
      Color var2 = ((Component)this).getForeground();
      var1.setColor(Color.white);
      var1.fillRect(0, 0, this.squareSize, this.squareSize);
      var1.setColor(var2);
      var1.fillRect(this.innerGap, this.innerGap, this.squareSize - this.innerGap * 2, this.squareSize - this.innerGap * 2);
      var1.setColor(Color.white);
      var1.fillRect(this.innerGap * 2, this.innerGap * 2, this.squareSize - this.innerGap * 4, this.squareSize - this.innerGap * 4);
      var1.setColor(var2);
      var1.fillRect(0, this.squareSize + this.squareGap, this.squareSize, this.squareSize);
      var1.translate(this.squareSize + this.squareGap, 0);
      var1.setColor(Color.black);
      var1.fillRect(0, 0, this.squareSize, this.squareSize);
      var1.setColor(var2);
      var1.fillRect(this.innerGap, this.innerGap, this.squareSize - this.innerGap * 2, this.squareSize - this.innerGap * 2);
      var1.setColor(Color.white);
      var1.fillRect(this.innerGap * 2, this.innerGap * 2, this.squareSize - this.innerGap * 4, this.squareSize - this.innerGap * 4);
      var1.translate(-(this.squareSize + this.squareGap), 0);
      var1.translate(this.squareSize + this.squareGap, this.squareSize + this.squareGap);
      var1.setColor(Color.white);
      var1.fillRect(0, 0, this.squareSize, this.squareSize);
      var1.setColor(var2);
      var1.fillRect(this.innerGap, this.innerGap, this.squareSize - this.innerGap * 2, this.squareSize - this.innerGap * 2);
      var1.translate(-(this.squareSize + this.squareGap), -(this.squareSize + this.squareGap));
      var1.translate((this.squareSize + this.squareGap) * 2, 0);
      var1.setColor(Color.white);
      var1.fillRect(0, 0, this.squareSize, this.squareSize);
      var1.setColor(var2);
      var1.fillRect(this.innerGap, this.innerGap, this.squareSize - this.innerGap * 2, this.squareSize - this.innerGap * 2);
      var1.setColor(Color.black);
      var1.fillRect(this.innerGap * 2, this.innerGap * 2, this.squareSize - this.innerGap * 4, this.squareSize - this.innerGap * 4);
      var1.translate(-((this.squareSize + this.squareGap) * 2), 0);
      var1.translate((this.squareSize + this.squareGap) * 2, this.squareSize + this.squareGap);
      var1.setColor(Color.black);
      var1.fillRect(0, 0, this.squareSize, this.squareSize);
      var1.setColor(var2);
      var1.fillRect(this.innerGap, this.innerGap, this.squareSize - this.innerGap * 2, this.squareSize - this.innerGap * 2);
      var1.translate(-((this.squareSize + this.squareGap) * 2), -(this.squareSize + this.squareGap));
      return (this.squareSize + this.squareGap) * 3;
   }

   private void paintSwatch(Graphics var1, int var2) {
      int var3 = var2 + this.squareGap;
      var1.setColor(this.oldColor);
      var1.fillRect(var3, 0, this.swatchWidth, this.squareSize + this.squareGap / 2);
      var1.setColor(((Component)this).getForeground());
      var1.fillRect(var3, this.squareSize + this.squareGap / 2, this.swatchWidth, this.squareSize + this.squareGap / 2);
   }

   private int paintText(Graphics var1, int var2) {
      var1.setFont(((Component)this).getFont());
      FontMetrics var3 = var1.getFontMetrics();
      int var4 = var3.getAscent();
      int var5 = var3.getHeight();
      int var6 = var3.stringWidth(this.sampleText);
      int var7 = var2 + this.textGap;
      Color var8 = ((Component)this).getForeground();
      var1.setColor(var8);
      var1.drawString(this.sampleText, var7, var4 + 2);
      var1.fillRect(var7, var5 + this.textGap, var6 + this.textGap, var5 + 2);
      var1.setColor(Color.black);
      var1.drawString(this.sampleText, var7 + this.textGap / 2, var5 + var4 + this.textGap + 2);
      var1.setColor(Color.white);
      var1.fillRect(var7, (var5 + this.textGap) * 2, var6 + this.textGap, var5 + 2);
      var1.setColor(var8);
      var1.drawString(this.sampleText, var7 + this.textGap / 2, (var5 + this.textGap) * 2 + var4 + 2);
      return var6 + this.textGap + 4;
   }
}
