package javax.swing.colorchooser;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Container;
import java.util.EventObject;
import javax.swing.Icon;
import javax.swing.JColorChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSlider;
import javax.swing.UIManager;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

class DefaultRGBChooserPanel extends AbstractColorChooserPanel implements ChangeListener {
   protected JSlider redSlider;
   protected JSlider greenSlider;
   protected JSlider blueSlider;
   protected JIntegerTextField redField;
   protected JIntegerTextField blueField;
   protected JIntegerTextField greenField;
   private final int minValue = 0;
   private final int maxValue = 255;
   boolean isAdjusting = false;

   public DefaultRGBChooserPanel() {
   }

   protected void buildChooser() {
      String var1 = UIManager.getString("ColorChooser.rgbRedText");
      String var2 = UIManager.getString("ColorChooser.rgbGreenText");
      String var3 = UIManager.getString("ColorChooser.rgbBlueText");
      ((Container)this).setLayout(new BorderLayout());
      Color var4 = ((AbstractColorChooserPanel)this).getColorFromModel();
      JPanel var5 = new JPanel();
      ((Container)var5).setLayout(new SmartGridLayout(3, 3));
      ((Container)this).add(var5, "Center");
      NumberListener var6 = new NumberListener(this);
      JLabel var7 = new JLabel(var1);
      var7.setDisplayedMnemonic(UIManager.getInt("ColorChooser.rgbRedMnemonic"));
      ((Container)var5).add(var7);
      this.redSlider = new JSlider(0, 0, 255, var4.getRed());
      this.redSlider.setMajorTickSpacing(85);
      this.redSlider.setMinorTickSpacing(17);
      this.redSlider.setPaintTicks(true);
      this.redSlider.setPaintLabels(true);
      ((Container)var5).add(this.redSlider);
      this.redField = new JIntegerTextField(0, 255, var4.getRed());
      var7.setLabelFor(this.redSlider);
      JPanel var8 = new JPanel(new CenterLayout());
      this.redField.getDocument().addDocumentListener(var6);
      ((Container)var8).add(this.redField);
      ((Container)var5).add(var8);
      var7 = new JLabel(var2);
      var7.setDisplayedMnemonic(UIManager.getInt("ColorChooser.rgbGreenMnemonic"));
      ((Container)var5).add(var7);
      this.greenSlider = new JSlider(0, 0, 255, var4.getRed());
      this.greenSlider.setMajorTickSpacing(85);
      this.greenSlider.setMinorTickSpacing(17);
      this.greenSlider.setPaintTicks(true);
      this.greenSlider.setPaintLabels(true);
      ((Container)var5).add(this.greenSlider);
      this.greenField = new JIntegerTextField(0, 255, var4.getGreen());
      var7.setLabelFor(this.greenSlider);
      JPanel var9 = new JPanel(new CenterLayout());
      ((Container)var9).add(this.greenField);
      this.greenField.getDocument().addDocumentListener(var6);
      ((Container)var5).add(var9);
      var7 = new JLabel(var3);
      var7.setDisplayedMnemonic(UIManager.getInt("ColorChooser.rgbBlueMnemonic"));
      ((Container)var5).add(var7);
      this.blueSlider = new JSlider(0, 0, 255, var4.getRed());
      this.blueSlider.setMajorTickSpacing(85);
      this.blueSlider.setMinorTickSpacing(17);
      this.blueSlider.setPaintTicks(true);
      this.blueSlider.setPaintLabels(true);
      ((Container)var5).add(this.blueSlider);
      this.blueField = new JIntegerTextField(0, 255, var4.getBlue());
      var7.setLabelFor(this.blueSlider);
      JPanel var10 = new JPanel(new CenterLayout());
      ((Container)var10).add(this.blueField);
      this.blueField.getDocument().addDocumentListener(var6);
      ((Container)var5).add(var10);
      this.redSlider.addChangeListener(this);
      this.greenSlider.addChangeListener(this);
      this.blueSlider.addChangeListener(this);
      this.redSlider.putClientProperty("JSlider.isFilled", Boolean.TRUE);
      this.greenSlider.putClientProperty("JSlider.isFilled", Boolean.TRUE);
      this.blueSlider.putClientProperty("JSlider.isFilled", Boolean.TRUE);
   }

   public String getDisplayName() {
      return UIManager.getString("ColorChooser.rgbNameText");
   }

   public Icon getLargeDisplayIcon() {
      return null;
   }

   public Icon getSmallDisplayIcon() {
      return null;
   }

   public void installChooserPanel(JColorChooser var1) {
      super.installChooserPanel(var1);
   }

   public void setColor(Color var1) {
      this.redSlider.setValue(var1.getRed());
      this.greenSlider.setValue(var1.getGreen());
      this.blueSlider.setValue(var1.getBlue());
   }

   public void stateChanged(ChangeEvent var1) {
      if (((EventObject)var1).getSource() instanceof JSlider) {
         int var2 = this.redSlider.getValue();
         int var3 = this.greenSlider.getValue();
         int var4 = this.blueSlider.getValue();
         Color var5 = new Color(var2, var3, var4);
         ((AbstractColorChooserPanel)this).getColorSelectionModel().setSelectedColor(var5);
      }

   }

   public void uninstallChooserPanel(JColorChooser var1) {
      super.uninstallChooserPanel(var1);
   }

   public void updateChooser() {
      if (!this.isAdjusting) {
         this.isAdjusting = true;
         Color var1 = ((AbstractColorChooserPanel)this).getColorFromModel();
         int var2 = var1.getRed();
         int var3 = var1.getBlue();
         int var4 = var1.getGreen();
         this.redSlider.setValue(var2);
         this.blueSlider.setValue(var3);
         this.greenSlider.setValue(var4);
         if (this.redField.getIntegerValue() != var2) {
            this.redField.setText(String.valueOf(var1.getRed()));
         }

         if (this.greenField.getIntegerValue() != var4) {
            this.greenField.setText(String.valueOf(var1.getGreen()));
         }

         if (this.blueField.getIntegerValue() != var3) {
            this.blueField.setText(String.valueOf(var1.getBlue()));
         }

         this.isAdjusting = false;
      }
   }
}
