package javax.swing.filechooser;

import java.io.File;
import java.io.IOException;
import java.util.Vector;

public abstract class FileSystemView {
   static FileSystemView windowsFileSystemView = null;
   static FileSystemView unixFileSystemView = null;
   static FileSystemView genericFileSystemView = null;

   public File createFileObject(File var1, String var2) {
      return var1 == null ? new File(var2) : new File(var1, var2);
   }

   public File createFileObject(String var1) {
      return new File(var1);
   }

   public abstract File createNewFolder(File var1) throws IOException;

   public static FileSystemView getFileSystemView() {
      if (File.separatorChar == '\\') {
         if (windowsFileSystemView == null) {
            windowsFileSystemView = new WindowsFileSystemView();
         }

         return windowsFileSystemView;
      } else if (File.separatorChar == '/') {
         if (unixFileSystemView == null) {
            unixFileSystemView = new UnixFileSystemView();
         }

         return unixFileSystemView;
      } else {
         if (genericFileSystemView == null) {
            genericFileSystemView = new GenericFileSystemView();
         }

         return genericFileSystemView;
      }
   }

   public File[] getFiles(File var1, boolean var2) {
      Vector var3 = new Vector();
      String[] var4 = var1.list();
      int var6 = var4 == null ? 0 : var4.length;

      for(int var7 = 0; var7 < var6; ++var7) {
         File var5 = this.createFileObject(var1, var4[var7]);
         if (var2) {
            if (!this.isHiddenFile(var5)) {
               var3.addElement(var5);
            }
         } else {
            var3.addElement(var5);
         }
      }

      File[] var8 = new File[var3.size()];
      var3.copyInto(var8);
      return var8;
   }

   public File getHomeDirectory() {
      return this.createFileObject(System.getProperty("user.home"));
   }

   public File getParentDirectory(File var1) {
      if (var1 != null) {
         File var2 = this.createFileObject(var1.getAbsolutePath());
         String var3 = var2.getParent();
         if (var3 != null) {
            return new File(var3);
         }
      }

      return null;
   }

   public abstract File[] getRoots();

   public abstract boolean isHiddenFile(File var1);

   public abstract boolean isRoot(File var1);
}
