package javax.swing.plaf.basic;

import java.awt.Component;
import java.awt.Rectangle;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.EventObject;
import javax.swing.AbstractButton;
import javax.swing.ButtonModel;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JRootPane;
import javax.swing.KeyStroke;
import javax.swing.SwingUtilities;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

public class BasicButtonListener implements MouseListener, MouseMotionListener, FocusListener, ChangeListener, PropertyChangeListener {
   private Rectangle tmpRect = new Rectangle();
   private KeyStroke altPressedKeyStroke = null;
   private KeyStroke altReleasedKeyStroke = null;
   private KeyStroke nonAltReleasedKeyStroke = null;
   private static KeyStroke spacePressedKeyStroke = null;
   private static KeyStroke spaceReleasedKeyStroke = null;

   public BasicButtonListener(AbstractButton var1) {
      if (spacePressedKeyStroke == null) {
         spacePressedKeyStroke = KeyStroke.getKeyStroke(32, 0, false);
         spaceReleasedKeyStroke = KeyStroke.getKeyStroke(32, 0, true);
      }

   }

   protected void checkOpacity(AbstractButton var1) {
      ((JComponent)var1).setOpaque(var1.isContentAreaFilled());
   }

   public void focusGained(FocusEvent var1) {
      AbstractButton var2 = (AbstractButton)((EventObject)var1).getSource();
      if (var2 instanceof JButton && ((JButton)var2).isDefaultCapable()) {
         JRootPane var3 = ((JComponent)var2).getRootPane();
         if (var3 != null) {
            var3.setDefaultButton((JButton)var2);
         }
      }

      ((Component)var2).repaint();
   }

   public void focusLost(FocusEvent var1) {
      AbstractButton var2 = (AbstractButton)((EventObject)var1).getSource();
      ((Component)var2).repaint();
   }

   public void installKeyboardActions(JComponent var1) {
      AbstractButton var2 = (AbstractButton)var1;
      PressedAction var3 = new PressedAction(var2);
      ReleasedAction var4 = new ReleasedAction(var2);
      ((JComponent)var2).registerKeyboardAction(var3, spacePressedKeyStroke, 0);
      ((JComponent)var2).registerKeyboardAction(var4, spaceReleasedKeyStroke, 0);
      int var5 = var2.getMnemonic();
      if (var5 != 0) {
         this.altPressedKeyStroke = KeyStroke.getKeyStroke(var5, 8, false);
         this.altReleasedKeyStroke = KeyStroke.getKeyStroke(var5, 8, true);
         this.nonAltReleasedKeyStroke = KeyStroke.getKeyStroke(var5, 0, true);
         ((JComponent)var2).registerKeyboardAction(var3, this.altPressedKeyStroke, 2);
         ((JComponent)var2).registerKeyboardAction(var4, this.altReleasedKeyStroke, 2);
         ((JComponent)var2).registerKeyboardAction(var4, this.nonAltReleasedKeyStroke, 2);
      }

   }

   public void mouseClicked(MouseEvent var1) {
   }

   public void mouseDragged(MouseEvent var1) {
      AbstractButton var2 = (AbstractButton)((EventObject)var1).getSource();
      ButtonModel var3 = var2.getModel();
      if (var3.isPressed()) {
         this.tmpRect.width = ((JComponent)var2).getWidth();
         this.tmpRect.height = ((JComponent)var2).getHeight();
         if (this.tmpRect.contains(var1.getPoint())) {
            var3.setArmed(true);
         } else {
            var3.setArmed(false);
         }
      }

   }

   public void mouseEntered(MouseEvent var1) {
      AbstractButton var2 = (AbstractButton)((EventObject)var1).getSource();
      if (var2.isRolloverEnabled()) {
         var2.getModel().setRollover(true);
      }

   }

   public void mouseExited(MouseEvent var1) {
      AbstractButton var2 = (AbstractButton)((EventObject)var1).getSource();
      if (var2.isRolloverEnabled()) {
         var2.getModel().setRollover(false);
      }

   }

   public void mouseMoved(MouseEvent var1) {
   }

   public void mousePressed(MouseEvent var1) {
      if (SwingUtilities.isLeftMouseButton(var1)) {
         AbstractButton var2 = (AbstractButton)((EventObject)var1).getSource();
         ButtonModel var3 = var2.getModel();
         if (!var3.isEnabled()) {
            return;
         }

         var3.setArmed(true);
         var3.setPressed(true);
         if (!((JComponent)var2).hasFocus()) {
            ((JComponent)var2).requestFocus();
         }
      }

   }

   public void mouseReleased(MouseEvent var1) {
      AbstractButton var2 = (AbstractButton)((EventObject)var1).getSource();
      ButtonModel var3 = var2.getModel();
      var3.setPressed(false);
      var3.setArmed(false);
   }

   public void propertyChange(PropertyChangeEvent var1) {
      String var2 = var1.getPropertyName();
      if (var2.equals("mnemonic")) {
         this.uninstallKeyboardActions((AbstractButton)((EventObject)var1).getSource());
         this.installKeyboardActions((AbstractButton)((EventObject)var1).getSource());
      }

      if (var2.equals("contentAreaFilled")) {
         this.checkOpacity((AbstractButton)((EventObject)var1).getSource());
      }

      if (var2.equals("text")) {
         AbstractButton var3 = (AbstractButton)((EventObject)var1).getSource();
         BasicHTML.updateRenderer(var3, var3.getText());
      }

   }

   public void stateChanged(ChangeEvent var1) {
      AbstractButton var2 = (AbstractButton)((EventObject)var1).getSource();
      ((Component)var2).repaint();
   }

   public void uninstallKeyboardActions(JComponent var1) {
      AbstractButton var2 = (AbstractButton)var1;
      if (spacePressedKeyStroke != null) {
         ((JComponent)var2).unregisterKeyboardAction(spacePressedKeyStroke);
      }

      if (spaceReleasedKeyStroke != null) {
         ((JComponent)var2).unregisterKeyboardAction(spaceReleasedKeyStroke);
      }

      if (this.altPressedKeyStroke != null) {
         ((JComponent)var2).unregisterKeyboardAction(this.altPressedKeyStroke);
         this.altPressedKeyStroke = null;
      }

      if (this.altReleasedKeyStroke != null) {
         ((JComponent)var2).unregisterKeyboardAction(this.altReleasedKeyStroke);
         this.altReleasedKeyStroke = null;
      }

      if (this.nonAltReleasedKeyStroke != null) {
         ((JComponent)var2).unregisterKeyboardAction(this.nonAltReleasedKeyStroke);
         this.nonAltReleasedKeyStroke = null;
      }

   }
}
