package javax.swing.plaf.basic;

import java.awt.BorderLayout;
import java.beans.PropertyChangeListener;
import javax.swing.JColorChooser;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.LookAndFeel;
import javax.swing.UIManager;
import javax.swing.border.TitledBorder;
import javax.swing.colorchooser.AbstractColorChooserPanel;
import javax.swing.colorchooser.ColorChooserComponentFactory;
import javax.swing.event.ChangeListener;
import javax.swing.plaf.ColorChooserUI;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.UIResource;

public class BasicColorChooserUI extends ColorChooserUI {
   JColorChooser chooser;
   JTabbedPane tabbedPane;
   JPanel singlePanel;
   JPanel previewPanelHolder;
   JComponent previewPanel;
   boolean isMultiPanel = false;
   protected AbstractColorChooserPanel[] defaultChoosers;
   protected ChangeListener previewListener;
   protected PropertyChangeListener propertyChangeListener;

   protected AbstractColorChooserPanel[] createDefaultChoosers() {
      AbstractColorChooserPanel[] var1 = ColorChooserComponentFactory.getDefaultChooserPanels();
      return var1;
   }

   protected PropertyChangeListener createPropertyChangeListener() {
      return new PropertyHandler(this);
   }

   public static ComponentUI createUI(JComponent var0) {
      return new BasicColorChooserUI();
   }

   protected void installDefaults() {
      LookAndFeel.installColorsAndFont(this.chooser, "ColorChooser.background", "ColorChooser.foreground", "ColorChooser.font");
   }

   protected void installListeners() {
      this.propertyChangeListener = this.createPropertyChangeListener();
      this.chooser.addPropertyChangeListener(this.propertyChangeListener);
      this.previewListener = new PreviewListener(this);
      this.chooser.getSelectionModel().addChangeListener(this.previewListener);
   }

   protected void installPreviewPanel() {
      this.previewPanelHolder = new JPanel(new CenterLayout());
      String var1 = UIManager.getString("ColorChooser.previewText");
      this.previewPanelHolder.setBorder(new TitledBorder(var1));
      this.previewPanel = this.chooser.getPreviewPanel();
      if (this.previewPanel == null || this.previewPanel instanceof UIResource) {
         this.previewPanel = ColorChooserComponentFactory.getPreviewPanel();
      }

      this.previewPanel.setForeground(this.chooser.getColor());
      this.previewPanelHolder.add(this.previewPanel);
      this.chooser.add(this.previewPanelHolder, "South");
   }

   public void installUI(JComponent var1) {
      this.chooser = (JColorChooser)var1;
      super.installUI(var1);
      this.installDefaults();
      this.installListeners();
      this.tabbedPane = new JTabbedPane();
      this.singlePanel = new JPanel(new CenterLayout());
      this.chooser.setLayout(new BorderLayout());
      this.defaultChoosers = this.createDefaultChoosers();
      this.chooser.setChooserPanels(this.defaultChoosers);
      this.installPreviewPanel();
   }

   protected void uninstallDefaultChoosers() {
      for(int var1 = 0; var1 < this.defaultChoosers.length; ++var1) {
         this.chooser.removeChooserPanel(this.defaultChoosers[var1]);
      }

   }

   protected void uninstallDefaults() {
   }

   protected void uninstallListeners() {
      this.chooser.removePropertyChangeListener(this.propertyChangeListener);
      this.chooser.getSelectionModel().removeChangeListener(this.previewListener);
   }

   public void uninstallUI(JComponent var1) {
      this.uninstallListeners();
      this.uninstallDefaultChoosers();
      this.uninstallDefaults();
      this.defaultChoosers = null;
      this.chooser = null;
      this.tabbedPane = null;
   }
}
