package javax.swing.plaf.metal;

import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.image.ImageObserver;
import java.util.Enumeration;
import java.util.Vector;
import javax.swing.Icon;

class MetalBumps implements Icon {
   protected int xBumps;
   protected int yBumps;
   protected Color topColor;
   protected Color shadowColor;
   protected Color backColor;
   protected static Vector buffers = new Vector();
   protected BumpBuffer buffer;

   public MetalBumps(int var1, int var2) {
      this.topColor = MetalLookAndFeel.getPrimaryControlHighlight();
      this.shadowColor = MetalLookAndFeel.getPrimaryControlDarkShadow();
      this.backColor = MetalLookAndFeel.getPrimaryControlShadow();
      this.setBumpArea(var1, var2);
      this.buffer = this.getBuffer(this.topColor, this.shadowColor, this.backColor);
      if (this.buffer == null) {
         this.createBuffer();
      }

   }

   public MetalBumps(int var1, int var2, Color var3, Color var4, Color var5) {
      this.topColor = MetalLookAndFeel.getPrimaryControlHighlight();
      this.shadowColor = MetalLookAndFeel.getPrimaryControlDarkShadow();
      this.backColor = MetalLookAndFeel.getPrimaryControlShadow();
      this.setBumpArea(var1, var2);
      this.setBumpColors(var3, var4, var5);
      this.buffer = this.getBuffer(this.topColor, this.shadowColor, this.backColor);
      if (this.buffer == null) {
         this.createBuffer();
      }

   }

   public MetalBumps(Dimension var1) {
      this(var1.width, var1.height);
   }

   protected void createBuffer() {
      this.buffer = new BumpBuffer(this.topColor, this.shadowColor, this.backColor);
      buffers.addElement(this.buffer);
   }

   protected BumpBuffer getBuffer(Color var1, Color var2, Color var3) {
      BumpBuffer var4 = null;
      Enumeration var5 = buffers.elements();

      while(var5.hasMoreElements()) {
         BumpBuffer var6 = (BumpBuffer)var5.nextElement();
         if (var6.hasSameColors(var1, var2, var3)) {
            var4 = var6;
            break;
         }
      }

      return var4;
   }

   public int getIconHeight() {
      return this.yBumps * 2;
   }

   public int getIconWidth() {
      return this.xBumps * 2;
   }

   public void paintIcon(Component var1, Graphics var2, int var3, int var4) {
      int var5 = this.buffer.getImageSize().width;
      int var6 = this.buffer.getImageSize().height;
      int var7 = this.getIconWidth();
      int var8 = this.getIconHeight();
      int var9 = var3 + var7;
      int var10 = var4 + var8;

      for(int var11 = var3; var4 < var10; var4 += var6) {
         int var12 = Math.min(var10 - var4, var6);

         for(int var14 = var11; var14 < var9; var14 += var5) {
            int var13 = Math.min(var9 - var14, var5);
            var2.drawImage(this.buffer.getImage(), var14, var4, var14 + var13, var4 + var12, 0, 0, var13, var12, (ImageObserver)null);
         }
      }

   }

   public void setBumpArea(int var1, int var2) {
      this.xBumps = var1 / 2;
      this.yBumps = var2 / 2;
   }

   public void setBumpArea(Dimension var1) {
      this.setBumpArea(var1.width, var1.height);
   }

   public void setBumpColors(Color var1, Color var2, Color var3) {
      this.topColor = var1;
      this.shadowColor = var2;
      this.backColor = var3;
      this.buffer = this.getBuffer(this.topColor, this.shadowColor, this.backColor);
      if (this.buffer == null) {
         this.createBuffer();
      }

   }
}
