package javax.swing.plaf.metal;

import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Rectangle;
import javax.swing.AbstractButton;
import javax.swing.ButtonModel;
import javax.swing.JComponent;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicButtonListener;
import javax.swing.plaf.basic.BasicButtonUI;
import javax.swing.plaf.basic.BasicGraphicsUtils;

public class MetalButtonUI extends BasicButtonUI {
   private static final MetalButtonUI metalButtonUI = new MetalButtonUI();
   private boolean defaults_initialized = false;
   protected Color focusColor;
   protected Color selectColor;
   protected Color disabledTextColor;

   protected BasicButtonListener createButtonListener(AbstractButton var1) {
      return new MetalButtonListener(var1);
   }

   public static ComponentUI createUI(JComponent var0) {
      return metalButtonUI;
   }

   protected Color getDisabledTextColor() {
      return this.disabledTextColor;
   }

   protected Color getFocusColor() {
      return this.focusColor;
   }

   protected Color getSelectColor() {
      return this.selectColor;
   }

   public void installDefaults(AbstractButton var1) {
      super.installDefaults(var1);
      if (!this.defaults_initialized) {
         this.focusColor = UIManager.getColor(((BasicButtonUI)this).getPropertyPrefix() + "focus");
         this.selectColor = UIManager.getColor(((BasicButtonUI)this).getPropertyPrefix() + "select");
         this.disabledTextColor = UIManager.getColor(((BasicButtonUI)this).getPropertyPrefix() + "disabledText");
         this.defaults_initialized = true;
      }

   }

   protected void paintButtonPressed(Graphics var1, AbstractButton var2) {
      if (var2.isContentAreaFilled()) {
         Dimension var3 = ((Component)var2).getSize();
         var1.setColor(this.getSelectColor());
         var1.fillRect(0, 0, var3.width, var3.height);
      }

   }

   protected void paintFocus(Graphics var1, AbstractButton var2, Rectangle var3, Rectangle var4, Rectangle var5) {
      Rectangle var6 = new Rectangle();
      String var7 = var2.getText();
      boolean var8 = var2.getIcon() != null;
      if (var7 != null && !var7.equals("")) {
         if (!var8) {
            var6.setBounds(var4);
         } else {
            var6.setBounds(var5.union(var4));
         }
      } else if (var8) {
         var6.setBounds(var5);
      }

      var1.setColor(this.getFocusColor());
      var1.drawRect(var6.x - 1, var6.y - 1, var6.width + 1, var6.height + 1);
   }

   protected void paintText(Graphics var1, JComponent var2, Rectangle var3, String var4) {
      AbstractButton var5 = (AbstractButton)var2;
      ButtonModel var6 = var5.getModel();
      FontMetrics var7 = var1.getFontMetrics();
      if (var6.isEnabled()) {
         var1.setColor(((Component)var5).getForeground());
         BasicGraphicsUtils.drawString(var1, var4, var6.getMnemonic(), var3.x, var3.y + var7.getAscent());
      } else {
         var1.setColor(this.getDisabledTextColor());
         BasicGraphicsUtils.drawString(var1, var4, var6.getMnemonic(), var3.x, var3.y + var7.getAscent());
      }

   }

   public void uninstallDefaults(AbstractButton var1) {
      super.uninstallDefaults(var1);
      this.defaults_initialized = false;
   }
}
