package javax.swing.plaf.metal;

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.LayoutManager;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.beans.PropertyVetoException;
import java.util.EventObject;
import javax.swing.ButtonModel;
import javax.swing.Icon;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JInternalFrame;
import javax.swing.JMenuBar;
import javax.swing.UIManager;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;
import javax.swing.plaf.ColorUIResource;

class MetalInternalFrameTitlePane extends JComponent implements LayoutManager, ActionListener, PropertyChangeListener {
   protected JMenuBar menuBar;
   protected boolean isPalette = false;
   JInternalFrame frame;
   protected JButton iconButton;
   protected JButton maxButton;
   protected JButton closeButton;
   private static final Border handyEmptyBorder = new EmptyBorder(0, 0, 0, 0);
   Icon maxIcon;
   Icon altMaxIcon;
   Icon iconIcon;
   Icon closeIcon;
   int riseWidth = 0;
   int interButtonSpacing = 2;
   MetalBumps activeBumps = new MetalBumps(0, 0, MetalLookAndFeel.getPrimaryControlHighlight(), MetalLookAndFeel.getPrimaryControlDarkShadow(), MetalLookAndFeel.getPrimaryControl());
   MetalBumps inactiveBumps = new MetalBumps(0, 0, MetalLookAndFeel.getControlHighlight(), MetalLookAndFeel.getControlDarkShadow(), MetalLookAndFeel.getControl());
   MetalBumps paletteBumps;

   public MetalInternalFrameTitlePane(JInternalFrame var1) {
      this.frame = var1;
      ((JComponent)this).setFont(UIManager.getFont("InternalFrame.font"));
      this.maxIcon = (Icon)UIManager.get("InternalFrame.maximizeIcon");
      this.altMaxIcon = (Icon)UIManager.get("InternalFrame.minimizeIcon");
      this.iconIcon = (Icon)UIManager.get("InternalFrame.iconizeIcon");
      this.closeIcon = (Icon)UIManager.get("InternalFrame.closeIcon");
      this.iconButton = new NoFocusButton(this.iconIcon);
      this.iconButton.putClientProperty("paintActive", Boolean.TRUE);
      this.iconButton.setFocusPainted(false);
      this.iconButton.setBorder(handyEmptyBorder);
      this.iconButton.setOpaque(false);
      this.iconButton.addActionListener(this);
      this.iconButton.setActionCommand("Iconify");
      this.iconButton.getAccessibleContext().setAccessibleName("Iconify");
      this.maxButton = new NoFocusButton(this.maxIcon);
      this.maxButton.putClientProperty("paintActive", Boolean.TRUE);
      this.maxButton.setBorder(handyEmptyBorder);
      this.maxButton.setOpaque(false);
      this.maxButton.setFocusPainted(false);
      this.maxButton.addActionListener(this);
      this.maxButton.setActionCommand("Maximize");
      this.maxButton.getAccessibleContext().setAccessibleName("Maximize");
      this.closeButton = new NoFocusButton(this.closeIcon);
      this.closeButton.putClientProperty("paintActive", Boolean.TRUE);
      this.closeButton.setBorder(handyEmptyBorder);
      this.closeButton.setOpaque(false);
      this.closeButton.setFocusPainted(false);
      this.closeButton.addActionListener(this);
      this.closeButton.setActionCommand("Close");
      this.closeButton.getAccessibleContext().setAccessibleName("Close");
      ((Container)this).setLayout(this);
      ((Container)this).add(this.iconButton);
      ((Container)this).add(this.maxButton);
      ((Container)this).add(this.closeButton);
      this.frame.addPropertyChangeListener(this);
   }

   public void actionPerformed(ActionEvent var1) {
      if ("Close".equals(var1.getActionCommand()) && this.frame.isClosable()) {
         try {
            this.frame.setClosed(true);
         } catch (PropertyVetoException var10) {
         }
      } else if ("Iconify".equals(var1.getActionCommand()) && this.frame.isIconifiable()) {
         if (!this.frame.isIcon()) {
            try {
               this.frame.setIcon(true);
            } catch (PropertyVetoException var9) {
            }
         } else {
            try {
               this.frame.setIcon(false);
            } catch (PropertyVetoException var8) {
            }
         }

         ButtonModel var2 = this.iconButton.getModel();
         if (var2 != null) {
            var2.setRollover(false);
         }
      } else if ("Minimize".equals(var1.getActionCommand()) && this.frame.isMaximizable()) {
         try {
            this.frame.setIcon(true);
         } catch (PropertyVetoException var7) {
         }
      } else if ("Maximize".equals(var1.getActionCommand()) && this.frame.isMaximizable()) {
         if (!this.frame.isMaximum()) {
            try {
               this.frame.setMaximum(true);
            } catch (PropertyVetoException var6) {
            }
         } else {
            try {
               this.frame.setMaximum(false);
            } catch (PropertyVetoException var5) {
            }
         }
      } else if ("Restore".equals(var1.getActionCommand()) && this.frame.isMaximizable() && this.frame.isMaximum()) {
         try {
            this.frame.setMaximum(false);
         } catch (PropertyVetoException var4) {
         }
      } else if ("Restore".equals(var1.getActionCommand()) && this.frame.isIconifiable() && this.frame.isIcon()) {
         try {
            this.frame.setIcon(false);
         } catch (PropertyVetoException var3) {
         }
      }

   }

   public void addLayoutComponent(String var1, Component var2) {
   }

   protected int computeHeight() {
      if (this.isPalette) {
         return UIManager.getInt("InternalFrame.paletteTitleHeight");
      } else {
         FontMetrics var1 = Toolkit.getDefaultToolkit().getFontMetrics(((Component)this).getFont());
         int var2 = var1.getHeight();
         var2 += 7;
         int var3 = this.frame.getFrameIcon().getIconHeight();
         var3 += 5;
         int var4 = Math.max(var2, var3);
         return var4;
      }
   }

   public Dimension getPreferredSize(Container var1) {
      return new Dimension(((Component)var1).getSize().width, this.computeHeight());
   }

   public void layoutContainer(Container var1) {
      int var2 = ((JComponent)this).getWidth() - 2;
      byte var3 = 2;
      byte var4 = 7;
      int var5 = this.closeButton.getIcon().getIconHeight();
      int var6 = this.closeButton.getIcon().getIconWidth();
      int var7 = var2;
      if (this.frame.isClosable()) {
         if (this.isPalette) {
            var7 = var2 - (var6 + 4);
            this.closeButton.setBounds(var7, 2, var6 + 2, ((JComponent)this).getHeight() - 4);
            var7 -= 3;
         } else {
            var7 = var2 - (var6 + this.interButtonSpacing);
            this.closeButton.setBounds(var7, var3, var6, var5);
            var7 -= var4;
         }
      } else if (this.closeButton.getParent() != null) {
         this.closeButton.getParent().remove(this.closeButton);
      }

      if (this.frame.isMaximizable() && !this.isPalette) {
         var7 -= var6 + this.interButtonSpacing;
         this.maxButton.setBounds(var7, var3, var6, var5);
      } else if (this.maxButton.getParent() != null) {
         this.maxButton.getParent().remove(this.maxButton);
      }

      if (this.frame.isIconifiable() && !this.isPalette) {
         var7 -= var6 + this.interButtonSpacing;
         this.iconButton.setBounds(var7, var3, var6, var5);
      } else if (this.iconButton.getParent() != null) {
         this.iconButton.getParent().remove(this.iconButton);
      }

      this.riseWidth = var2 - var7;
   }

   public Dimension minimumLayoutSize(Container var1) {
      return this.preferredLayoutSize(var1);
   }

   public void paint(Graphics var1) {
      if (this.isPalette) {
         this.paintPalette(var1);
      } else {
         boolean var2 = this.frame.isSelected();
         int var3 = ((JComponent)this).getWidth();
         int var4 = ((JComponent)this).getHeight();
         ColorUIResource var5;
         ColorUIResource var6;
         ColorUIResource var8;
         MetalBumps var11;
         if (var2) {
            var5 = MetalLookAndFeel.getWindowTitleBackground();
            var6 = MetalLookAndFeel.getWindowTitleForeground();
            ColorUIResource var7 = MetalLookAndFeel.getPrimaryControlShadow();
            var8 = MetalLookAndFeel.getPrimaryControlDarkShadow();
            ColorUIResource var9 = MetalLookAndFeel.getPrimaryControlHighlight();
            ColorUIResource var10 = MetalLookAndFeel.getPrimaryControlInfo();
            var11 = this.activeBumps;
         } else {
            var5 = MetalLookAndFeel.getWindowTitleInactiveBackground();
            var6 = MetalLookAndFeel.getWindowTitleInactiveForeground();
            ColorUIResource var21 = MetalLookAndFeel.getControlShadow();
            var8 = MetalLookAndFeel.getControlDarkShadow();
            ColorUIResource var22 = MetalLookAndFeel.getControlHighlight();
            ColorUIResource var23 = MetalLookAndFeel.getControlInfo();
            var11 = this.inactiveBumps;
         }

         var1.setColor(var5);
         var1.fillRect(0, 0, var3, var4);
         var1.setColor(var8);
         var1.drawLine(0, var4 - 1, var3, var4 - 1);
         var1.drawLine(0, 0, 0, 0);
         var1.drawLine(var3 - 1, 0, var3 - 1, 0);
         int var13 = 0;
         int var14 = 5;
         String var15 = this.frame.getTitle();
         Icon var16 = this.frame.getFrameIcon();
         if (var16 != null) {
            int var17 = var4 / 2 - var16.getIconHeight() / 2;
            var16.paintIcon(this.frame, var1, var14, var17);
            var14 += var16.getIconWidth() + 2;
         }

         if (var15 != null) {
            Font var25 = ((Component)this).getFont();
            var1.setFont(var25);
            FontMetrics var18 = var1.getFontMetrics();
            int var19 = var18.getHeight();
            var13 = var18.stringWidth(this.frame.getTitle());
            var1.setColor(var6);
            int var20 = (var4 - var18.getHeight()) / 2 + var18.getAscent();
            var1.drawString(this.frame.getTitle(), var14, var20);
         }

         byte var26 = 3;
         var14 += var13 + this.interButtonSpacing;
         int var27 = ((JComponent)this).getWidth() - (var14 + this.riseWidth + this.interButtonSpacing + 5);
         int var28 = ((JComponent)this).getHeight() - 2 * var26;
         var11.setBumpArea(var27, var28);
         var11.paintIcon(this, var1, var14, var26);
         ((JComponent)this).paintChildren(var1);
      }
   }

   public void paintPalette(Graphics var1) {
      int var2 = ((JComponent)this).getWidth();
      int var3 = ((JComponent)this).getHeight();
      if (this.paletteBumps == null) {
         this.paletteBumps = new MetalBumps(0, 0, MetalLookAndFeel.getPrimaryControlHighlight(), MetalLookAndFeel.getPrimaryControlInfo(), MetalLookAndFeel.getPrimaryControlShadow());
      }

      ColorUIResource var4 = MetalLookAndFeel.getPrimaryControlShadow();
      ColorUIResource var7 = MetalLookAndFeel.getPrimaryControlDarkShadow();
      var1.setColor(var4);
      var1.fillRect(0, 0, var2, var3);
      var1.setColor(var7);
      var1.drawLine(0, var3 - 1, var2, var3 - 1);
      byte var10 = 5;
      int var11 = ((JComponent)this).getWidth() - (var10 + this.riseWidth + 2);
      int var12 = ((JComponent)this).getHeight() - 4;
      this.paletteBumps.setBumpArea(var11, var12);
      this.paletteBumps.paintIcon(this, var1, var10, 2);
      ((JComponent)this).paintChildren(var1);
   }

   public Dimension preferredLayoutSize(Container var1) {
      return this.getPreferredSize(var1);
   }

   public void propertyChange(PropertyChangeEvent var1) {
      String var2 = var1.getPropertyName();
      JInternalFrame var3 = (JInternalFrame)((EventObject)var1).getSource();
      boolean var4 = false;
      if (this.frame.isSelected()) {
         this.iconButton.putClientProperty("paintActive", Boolean.TRUE);
         this.closeButton.putClientProperty("paintActive", Boolean.TRUE);
         this.maxButton.putClientProperty("paintActive", Boolean.TRUE);
         ((Component)this).repaint();
      } else {
         this.iconButton.putClientProperty("paintActive", Boolean.FALSE);
         this.closeButton.putClientProperty("paintActive", Boolean.FALSE);
         this.maxButton.putClientProperty("paintActive", Boolean.FALSE);
         ((Component)this).repaint();
      }

      if ("selected".equals(var2)) {
         ((Component)this).repaint();
      } else if ("maximum".equals(var2)) {
         var4 = (Boolean)var1.getNewValue();
         if (var4) {
            this.maxButton.setIcon(this.altMaxIcon);
         } else {
            this.maxButton.setIcon(this.maxIcon);
         }
      } else if ("icon".equals(var2)) {
         var4 = (Boolean)var1.getNewValue();
         if (var4) {
            this.iconButton.setIcon(this.iconIcon);
         } else {
            this.iconButton.setIcon(this.iconIcon);
         }
      }

   }

   public void removeLayoutComponent(Component var1) {
   }

   public void setPalette(boolean var1) {
      this.isPalette = var1;
      if (this.isPalette) {
         this.closeButton.setIcon(UIManager.getIcon("InternalFrame.paletteCloseIcon"));
      } else {
         this.closeButton.setIcon(this.closeIcon);
      }

      ((Component)this).repaint();
      ((JComponent)this).revalidate();
   }
}
