package javax.swing.plaf.metal;

import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Rectangle;
import java.beans.PropertyChangeListener;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.UIResource;
import javax.swing.plaf.basic.BasicScrollBarUI;

public class MetalScrollBarUI extends BasicScrollBarUI {
   private static Color shadowColor;
   private static Color highlightColor;
   private static Color darkShadowColor;
   private static Color thumbColor;
   private static Color thumbShadow;
   private static Color thumbHighlightColor;
   protected MetalBumps bumps;
   protected MetalScrollButton increaseButton;
   protected MetalScrollButton decreaseButton;
   protected int scrollBarWidth;
   public static final String FREE_STANDING_PROP = "JScrollBar.isFreeStanding";
   protected boolean isFreeStanding = true;

   protected void configureScrollBarColors() {
      shadowColor = UIManager.getColor("ScrollBar.shadow");
      highlightColor = UIManager.getColor("ScrollBar.highlight");
      darkShadowColor = UIManager.getColor("ScrollBar.darkShadow");
      thumbColor = UIManager.getColor("ScrollBar.thumb");
      thumbShadow = UIManager.getColor("ScrollBar.thumbShadow");
      thumbHighlightColor = UIManager.getColor("ScrollBar.thumbHighlight");
   }

   protected JButton createDecreaseButton(int var1) {
      this.decreaseButton = new MetalScrollButton(var1, this.scrollBarWidth, this.isFreeStanding);
      return this.decreaseButton;
   }

   protected JButton createIncreaseButton(int var1) {
      this.increaseButton = new MetalScrollButton(var1, this.scrollBarWidth, this.isFreeStanding);
      return this.increaseButton;
   }

   protected PropertyChangeListener createPropertyChangeListener() {
      return new ScrollBarListener(this);
   }

   public static ComponentUI createUI(JComponent var0) {
      return new MetalScrollBarUI();
   }

   protected Dimension getMinimumThumbSize() {
      return new Dimension(this.scrollBarWidth, this.scrollBarWidth);
   }

   public Dimension getPreferredSize(JComponent var1) {
      return super.scrollbar.getOrientation() == 1 ? new Dimension(this.scrollBarWidth, this.scrollBarWidth * 3 + 10) : new Dimension(this.scrollBarWidth * 3 + 10, this.scrollBarWidth);
   }

   protected void installDefaults() {
      this.scrollBarWidth = (Integer)UIManager.get("ScrollBar.width");
      if (super.scrollbar.getBackground() == null || super.scrollbar.getBackground() instanceof UIResource) {
         super.scrollbar.setBackground(UIManager.getColor("ScrollBar.background"));
      }

      super.installDefaults();
      this.bumps = new MetalBumps(10, 10, thumbHighlightColor, thumbShadow, thumbColor);
   }

   protected void installListeners() {
      super.installListeners();
      ((ScrollBarListener)super.propertyChangeListener).handlePropertyChange(super.scrollbar.getClientProperty("JScrollBar.isFreeStanding"));
   }

   protected void paintThumb(Graphics var1, JComponent var2, Rectangle var3) {
      if (((Component)var2).isEnabled()) {
         var1.translate(var3.x, var3.y);
         if (super.scrollbar.getOrientation() == 1) {
            if (!this.isFreeStanding) {
               var3.width += 2;
            }

            var1.setColor(thumbColor);
            var1.fillRect(0, 0, var3.width - 2, var3.height - 1);
            var1.setColor(thumbShadow);
            var1.drawRect(0, 0, var3.width - 2, var3.height - 1);
            var1.setColor(thumbHighlightColor);
            var1.drawLine(1, 1, var3.width - 3, 1);
            var1.drawLine(1, 1, 1, var3.height - 2);
            this.bumps.setBumpArea(var3.width - 6, var3.height - 7);
            this.bumps.paintIcon(var2, var1, 3, 4);
            if (!this.isFreeStanding) {
               var3.width -= 2;
            }
         } else {
            if (!this.isFreeStanding) {
               var3.height += 2;
            }

            var1.setColor(thumbColor);
            var1.fillRect(0, 0, var3.width - 1, var3.height - 2);
            var1.setColor(thumbShadow);
            var1.drawRect(0, 0, var3.width - 1, var3.height - 2);
            var1.setColor(thumbHighlightColor);
            var1.drawLine(1, 1, var3.width - 3, 1);
            var1.drawLine(1, 1, 1, var3.height - 3);
            this.bumps.setBumpArea(var3.width - 7, var3.height - 6);
            this.bumps.paintIcon(var2, var1, 4, 3);
            if (!this.isFreeStanding) {
               var3.height -= 2;
            }
         }

         var1.translate(-var3.x, -var3.y);
      }
   }

   protected void paintTrack(Graphics var1, JComponent var2, Rectangle var3) {
      var1.translate(var3.x, var3.y);
      if (super.scrollbar.getOrientation() == 1) {
         if (!this.isFreeStanding) {
            var3.width += 2;
         }

         if (((Component)var2).isEnabled()) {
            var1.setColor(darkShadowColor);
            var1.drawLine(0, 0, 0, var3.height - 1);
            var1.drawLine(var3.width - 2, 0, var3.width - 2, var3.height - 1);
            var1.drawLine(2, var3.height - 1, var3.width - 1, var3.height - 1);
            var1.drawLine(2, 0, var3.width - 2, 0);
            var1.setColor(shadowColor);
            var1.drawLine(1, 1, 1, var3.height - 2);
            var1.drawLine(1, 1, var3.width - 3, 1);
            if (super.scrollbar.getValue() != super.scrollbar.getMaximum()) {
               int var4 = super.thumbRect.y + super.thumbRect.height - var3.y;
               var1.drawLine(1, var4, var3.width - 1, var4);
            }

            var1.setColor(highlightColor);
            var1.drawLine(var3.width - 1, 0, var3.width - 1, var3.height - 1);
         } else {
            MetalUtils.drawDisabledBorder(var1, 0, 0, var3.width, var3.height);
         }

         if (!this.isFreeStanding) {
            var3.width -= 2;
         }
      } else {
         if (!this.isFreeStanding) {
            var3.height += 2;
         }

         if (((Component)var2).isEnabled()) {
            var1.setColor(darkShadowColor);
            var1.drawLine(0, 0, var3.width - 1, 0);
            var1.drawLine(0, 2, 0, var3.height - 2);
            var1.drawLine(0, var3.height - 2, var3.width - 1, var3.height - 2);
            var1.drawLine(var3.width - 1, 2, var3.width - 1, var3.height - 1);
            var1.setColor(shadowColor);
            var1.drawLine(1, 1, var3.width - 2, 1);
            var1.drawLine(1, 1, 1, var3.height - 3);
            var1.drawLine(0, var3.height - 1, var3.width - 1, var3.height - 1);
            if (super.scrollbar.getValue() != super.scrollbar.getMaximum()) {
               int var5 = super.thumbRect.x + super.thumbRect.width - var3.x;
               var1.drawLine(var5, 1, var5, var3.height - 1);
            }
         } else {
            MetalUtils.drawDisabledBorder(var1, 0, 0, var3.width, var3.height);
         }

         if (!this.isFreeStanding) {
            var3.height -= 2;
         }
      }

      var1.translate(-var3.x, -var3.y);
   }

   protected void setThumbBounds(int var1, int var2, int var3, int var4) {
      if (super.thumbRect.x != var1 || super.thumbRect.y != var2 || super.thumbRect.width != var3 || super.thumbRect.height != var4) {
         int var5 = Math.min(var1, super.thumbRect.x);
         int var6 = Math.min(var2, super.thumbRect.y);
         int var7 = Math.max(var1 + var3, super.thumbRect.x + super.thumbRect.width);
         int var8 = Math.max(var2 + var4, super.thumbRect.y + super.thumbRect.height);
         super.thumbRect.setBounds(var1, var2, var3, var4);
         super.scrollbar.repaint(var5, var6, var7 - var5 + 1, var8 - var6 + 1);
      }
   }
}
