package javax.swing.plaf.metal;

import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Insets;
import java.awt.LayoutManager;
import java.awt.Rectangle;
import javax.swing.Icon;
import javax.swing.JComponent;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicTabbedPaneUI;

public class MetalTabbedPaneUI extends BasicTabbedPaneUI {
   protected int minTabWidth = 40;
   protected Color tabAreaBackground;
   protected Color selectColor;
   protected Color selectHighlight;

   protected int calculateMaxTabHeight(int var1) {
      FontMetrics var2 = ((BasicTabbedPaneUI)this).getFontMetrics();
      int var3 = var2.getHeight();
      boolean var4 = false;

      for(int var5 = 0; var5 < super.tabPane.getTabCount(); ++var5) {
         Icon var6 = super.tabPane.getIconAt(var5);
         if (var6 != null && var6.getIconHeight() > var3) {
            var4 = true;
            break;
         }
      }

      return super.calculateMaxTabHeight(var1) - (var4 ? super.tabInsets.top + super.tabInsets.bottom : 0);
   }

   protected LayoutManager createLayoutManager() {
      return new TabbedPaneLayout(this);
   }

   public static ComponentUI createUI(JComponent var0) {
      return new MetalTabbedPaneUI();
   }

   protected Color getColorForGap(int var1, int var2, int var3) {
      boolean var4 = true;
      int var5 = super.tabPane.getSelectedIndex();
      int var6 = super.tabRuns[var1 + 1];
      int var7 = ((BasicTabbedPaneUI)this).lastTabInRun(super.tabPane.getTabCount(), var1 + 1);
      boolean var8 = true;

      for(int var9 = var6; var9 <= var7; ++var9) {
         Rectangle var10 = ((BasicTabbedPaneUI)this).getTabBounds(super.tabPane, var9);
         int var11 = var10.x;
         int var12 = var10.x + var10.width - 1;
         if (var11 <= var2 && var12 - 4 > var2) {
            return var5 == var9 ? this.selectColor : super.tabPane.getBackgroundAt(var9);
         }
      }

      return super.tabPane.getBackground();
   }

   protected int getTabLabelShiftX(int var1, int var2, boolean var3) {
      return 0;
   }

   protected int getTabLabelShiftY(int var1, int var2, boolean var3) {
      return 0;
   }

   protected int getTabRunOverlay(int var1) {
      if (var1 != 2 && var1 != 4) {
         return 0;
      } else {
         int var2 = this.calculateMaxTabHeight(var1);
         return var2 / 2;
      }
   }

   protected void installDefaults() {
      super.installDefaults();
      this.tabAreaBackground = UIManager.getColor("TabbedPane.tabAreaBackground");
      this.selectColor = UIManager.getColor("TabbedPane.selected");
      this.selectHighlight = UIManager.getColor("TabbedPane.selectHighlight");
   }

   public void paint(Graphics var1, JComponent var2) {
      int var3 = super.tabPane.getTabPlacement();
      Insets var4 = var2.getInsets();
      Dimension var5 = ((Component)var2).getSize();
      if (super.tabPane.isOpaque()) {
         var1.setColor(((Component)var2).getBackground());
         switch (var3) {
            case 1:
            default:
               var1.fillRect(var4.left, var4.top, var5.width - var4.right - var4.left, ((BasicTabbedPaneUI)this).calculateTabAreaHeight(var3, super.runCount, super.maxTabHeight));
               this.paintHighlightBelowTab();
               break;
            case 2:
               var1.fillRect(var4.left, var4.top, ((BasicTabbedPaneUI)this).calculateTabAreaWidth(var3, super.runCount, super.maxTabWidth), var5.height - var4.bottom - var4.top);
               break;
            case 3:
               int var6 = ((BasicTabbedPaneUI)this).calculateTabAreaHeight(var3, super.runCount, super.maxTabHeight);
               var1.fillRect(var4.left, var5.height - var4.bottom - var6, var5.width - var4.left - var4.right, var6);
               break;
            case 4:
               int var7 = ((BasicTabbedPaneUI)this).calculateTabAreaWidth(var3, super.runCount, super.maxTabWidth);
               var1.fillRect(var5.width - var4.right - var7, var4.top, var7, var5.height - var4.top - var4.bottom);
         }
      }

      super.paint(var1, var2);
   }

   protected void paintBottomTabBorder(int var1, Graphics var2, int var3, int var4, int var5, int var6, int var7, int var8, boolean var9) {
      int var10 = super.tabPane.getTabCount();
      int var11 = ((BasicTabbedPaneUI)this).getRunForTab(var10, var1);
      int var12 = ((BasicTabbedPaneUI)this).lastTabInRun(var10, var11);
      int var13 = super.tabRuns[var11];
      int var14 = var6 - 1;
      int var15 = var5 - 1;
      if (this.shouldFillGap(var11, var1, var3, var4)) {
         var2.translate(var3, var4);
         var2.setColor(this.getColorForGap(var11, var3, var4));
         var2.fillRect(1, var14 - 4, 3, 5);
         var2.fillRect(4, var14 - 1, 2, 2);
         var2.translate(-var3, -var4);
      }

      var2.translate(var3, var4);
      var2.setColor(super.darkShadow);
      var2.drawLine(1, var14 - 5, 6, var14);
      var2.drawLine(6, var14, var15, var14);
      if (var1 == var12) {
         var2.drawLine(var15, 0, var15, var14);
      }

      if (var1 != super.tabRuns[super.runCount - 1]) {
         var2.drawLine(0, 0, 0, var14);
      } else {
         var2.drawLine(0, 0, 0, var14 - 6);
      }

      var2.setColor(var9 ? this.selectHighlight : super.highlight);
      var2.drawLine(1, var14 - 6, 6, var14 - 1);
      var2.drawLine(1, 0, 1, var14 - 6);
      if (var1 == var13 && var1 != super.tabRuns[super.runCount - 1]) {
         var2.setColor(super.tabPane.getSelectedIndex() == super.tabRuns[var11 + 1] ? this.selectHighlight : super.highlight);
         var2.drawLine(1, var14 - 4, 1, var14);
      }

      var2.translate(-var3, -var4);
   }

   protected void paintContentBorderBottomEdge(Graphics var1, int var2, int var3, int var4, int var5, int var6, int var7) {
      var1.setColor(super.shadow);
      if (var2 == 3 && var3 >= 0 && super.rects[var3].y - 1 <= var7) {
         Rectangle var8 = super.rects[var3];
         var1.setColor(super.darkShadow);
         var1.drawLine(var4, var5 + var7 - 1, var8.x, var5 + var7 - 1);
         if (var8.x + var8.width < var4 + var6 - 2) {
            var1.setColor(super.darkShadow);
            var1.drawLine(var8.x + var8.width, var5 + var7 - 1, var4 + var6 - 1, var5 + var7 - 1);
         }
      } else {
         var1.setColor(super.darkShadow);
         var1.drawLine(var4, var5 + var7 - 1, var4 + var6 - 1, var5 + var7 - 1);
      }

   }

   protected void paintContentBorderLeftEdge(Graphics var1, int var2, int var3, int var4, int var5, int var6, int var7) {
      var1.setColor(this.selectHighlight);
      if (var2 == 2 && var3 >= 0 && super.rects[var3].x + super.rects[var3].width + 1 >= var4) {
         Rectangle var8 = super.rects[var3];
         var1.drawLine(var4, var5, var4, var8.y + 1);
         if (var8.y + var8.height < var5 + var7 - 2) {
            var1.drawLine(var4, var8.y + var8.height + 1, var4, var5 + var7 + 2);
         }
      } else {
         var1.drawLine(var4, var5, var4, var5 + var7 - 2);
      }

   }

   protected void paintContentBorderRightEdge(Graphics var1, int var2, int var3, int var4, int var5, int var6, int var7) {
      var1.setColor(super.shadow);
      if (var2 == 4 && var3 >= 0 && super.rects[var3].x - 1 <= var6) {
         Rectangle var8 = super.rects[var3];
         var1.setColor(super.darkShadow);
         var1.drawLine(var4 + var6 - 1, var5, var4 + var6 - 1, var8.y);
         if (var8.y + var8.height < var5 + var7 - 2) {
            var1.setColor(super.darkShadow);
            var1.drawLine(var4 + var6 - 1, var8.y + var8.height, var4 + var6 - 1, var5 + var7 - 2);
         }
      } else {
         var1.setColor(super.darkShadow);
         var1.drawLine(var4 + var6 - 1, var5, var4 + var6 - 1, var5 + var7 - 1);
      }

   }

   protected void paintContentBorderTopEdge(Graphics var1, int var2, int var3, int var4, int var5, int var6, int var7) {
      var1.setColor(this.selectHighlight);
      if (var2 == 1 && var3 >= 0 && super.rects[var3].y + super.rects[var3].height + 1 >= var5) {
         Rectangle var8 = super.rects[var3];
         var1.drawLine(var4, var5, var8.x + 1, var5);
         if (var8.x + var8.width < var4 + var6 - 2) {
            var1.drawLine(var8.x + var8.width, var5, var4 + var6 - 2, var5);
         } else {
            var1.setColor(super.shadow);
            var1.drawLine(var4 + var6 - 2, var5, var4 + var6 - 2, var5);
         }
      } else {
         var1.drawLine(var4, var5, var4 + var6 - 2, var5);
      }

   }

   protected void paintFocusIndicator(Graphics var1, int var2, Rectangle[] var3, int var4, Rectangle var5, Rectangle var6, boolean var7) {
      if (super.tabPane.hasFocus() && var7) {
         Rectangle var8 = var3[var4];
         var1.setColor(super.focus);
         var1.translate(var8.x, var8.y);
         int var9 = var8.width - 1;
         int var10 = var8.height - 1;
         switch (var2) {
            case 1:
            case 2:
            default:
               var1.drawLine(2, 6, 6, 2);
               var1.drawLine(2, 6, 2, var10 - 1);
               var1.drawLine(6, 2, var9, 2);
               var1.drawLine(var9, 2, var9, var10 - 1);
               var1.drawLine(2, var10 - 1, var9, var10 - 1);
               break;
            case 3:
               var1.drawLine(2, var10 - 6, 6, var10 - 2);
               var1.drawLine(6, var10 - 2, var9, var10 - 2);
               var1.drawLine(2, 0, 2, var10 - 6);
               var1.drawLine(2, 0, var9, 0);
               var1.drawLine(var9, 0, var9, var10 - 2);
               break;
            case 4:
               var1.drawLine(var9 - 6, 2, var9 - 2, 6);
               var1.drawLine(1, 2, var9 - 6, 2);
               var1.drawLine(var9 - 2, 6, var9 - 2, var10);
               var1.drawLine(1, 2, 1, var10);
               var1.drawLine(1, var10, var9 - 2, var10);
         }

         var1.translate(-var8.x, -var8.y);
      }

   }

   protected void paintHighlightBelowTab() {
   }

   protected void paintLeftTabBorder(int var1, Graphics var2, int var3, int var4, int var5, int var6, int var7, int var8, boolean var9) {
      int var10 = super.tabPane.getTabCount();
      int var11 = ((BasicTabbedPaneUI)this).getRunForTab(var10, var1);
      int var12 = ((BasicTabbedPaneUI)this).lastTabInRun(var10, var11);
      int var13 = super.tabRuns[var11];
      var2.translate(var3, var4);
      int var14 = var6 - 1;
      int var15 = var5 - 1;
      if (var1 != var13) {
         var2.setColor(super.tabPane.getSelectedIndex() == var1 - 1 ? this.selectColor : super.tabPane.getBackgroundAt(var1 - 1));
         var2.fillRect(2, 0, 4, 3);
         var2.drawLine(2, 3, 2, 3);
      }

      var2.setColor(var9 ? this.selectHighlight : super.highlight);
      var2.drawLine(1, 6, 6, 1);
      var2.drawLine(6, 1, var15, 1);
      var2.drawLine(1, 6, 1, var14);
      if (var1 != var13) {
         var2.setColor(super.tabPane.getSelectedIndex() == var1 - 1 ? this.selectHighlight : super.highlight);
         var2.drawLine(1, 0, 1, 4);
      }

      var2.setColor(super.darkShadow);
      var2.drawLine(1, 5, 6, 0);
      var2.drawLine(6, 0, var15, 0);
      if (var1 != var13) {
         var2.drawLine(0, 0, 0, var14);
      } else {
         var2.drawLine(0, 6, 0, var14);
      }

      if (var1 == var12) {
         var2.drawLine(0, var14, var15, var14);
      }

      var2.translate(-var3, -var4);
   }

   protected void paintRightTabBorder(int var1, Graphics var2, int var3, int var4, int var5, int var6, int var7, int var8, boolean var9) {
      int var10 = super.tabPane.getTabCount();
      int var11 = ((BasicTabbedPaneUI)this).getRunForTab(var10, var1);
      int var12 = ((BasicTabbedPaneUI)this).lastTabInRun(var10, var11);
      int var13 = super.tabRuns[var11];
      var2.translate(var3, var4);
      int var14 = var6 - 1;
      int var15 = var5 - 1;
      if (var1 != var13) {
         var2.setColor(super.tabPane.getSelectedIndex() == var1 - 1 ? this.tabAreaBackground : super.tabPane.getBackgroundAt(var1 - 1));
         var2.fillRect(var15 - 5, 0, 5, 3);
         var2.fillRect(var15 - 2, 3, 2, 2);
      }

      var2.setColor(var9 ? this.selectHighlight : super.highlight);
      var2.drawLine(var15 - 6, 1, var15 - 1, 6);
      var2.drawLine(0, 1, var15 - 6, 1);
      if (!var9) {
         var2.drawLine(0, 1, 0, var14);
      }

      var2.setColor(super.darkShadow);
      var2.drawLine(var15 - 6, 0, var15, 6);
      var2.drawLine(0, 0, var15 - 6, 0);
      if (var1 != var13) {
         var2.drawLine(var15, 0, var15, var14);
      } else {
         var2.drawLine(var15, 6, var15, var14);
      }

      if (var1 == var12) {
         var2.drawLine(0, var14, var15, var14);
      }

      var2.translate(-var3, -var4);
   }

   protected void paintTabBackground(Graphics var1, int var2, int var3, int var4, int var5, int var6, int var7, boolean var8) {
      int var9 = var7 / 2;
      if (var8) {
         var1.setColor(this.selectColor);
      } else {
         var1.setColor(super.tabPane.getBackgroundAt(var3));
      }

      switch (var2) {
         case 1:
         default:
            var1.fillRect(var4 + 4, var5 + 2, var6 - 1 - 3, var7 - 1 - 1);
            var1.fillRect(var4 + 2, var5 + 5, 2, var7 - 5);
            break;
         case 2:
            var1.fillRect(var4 + 5, var5 + 1, var6 - 5, var7 - 1);
            var1.fillRect(var4 + 2, var5 + 4, 3, var7 - 4);
            break;
         case 3:
            var1.fillRect(var4 + 2, var5, var6 - 2, var7 - 3);
            var1.fillRect(var4 + 5, var5 + (var7 - 1) - 3, var6 - 5, 3);
            break;
         case 4:
            var1.fillRect(var4 + 1, var5 + 1, var6 - 5, var7 - 1);
            var1.fillRect(var4 + (var6 - 1) - 3, var5 + 5, 3, var7 - 5);
      }

   }

   protected void paintTabBorder(Graphics var1, int var2, int var3, int var4, int var5, int var6, int var7, boolean var8) {
      int var9 = var5 + (var7 - 1);
      int var10 = var4 + (var6 - 1);
      switch (var2) {
         case 1:
         default:
            this.paintTopTabBorder(var3, var1, var4, var5, var6, var7, var9, var10, var8);
            break;
         case 2:
            this.paintLeftTabBorder(var3, var1, var4, var5, var6, var7, var9, var10, var8);
            break;
         case 3:
            this.paintBottomTabBorder(var3, var1, var4, var5, var6, var7, var9, var10, var8);
            break;
         case 4:
            this.paintRightTabBorder(var3, var1, var4, var5, var6, var7, var9, var10, var8);
      }

   }

   protected void paintTopTabBorder(int var1, Graphics var2, int var3, int var4, int var5, int var6, int var7, int var8, boolean var9) {
      int var10 = ((BasicTabbedPaneUI)this).getRunForTab(super.tabPane.getTabCount(), var1);
      int var11 = ((BasicTabbedPaneUI)this).lastTabInRun(super.tabPane.getTabCount(), var10);
      int var12 = super.tabRuns[var10];
      if (this.shouldFillGap(var10, var1, var3, var4)) {
         var2.translate(var3, var4);
         var2.setColor(this.getColorForGap(var10, var3, var4 + 1));
         var2.fillRect(1, 0, 5, 3);
         var2.fillRect(1, 3, 2, 2);
         var2.translate(-var3, -var4);
      }

      var2.translate(var3, var4);
      int var13 = var6 - 1;
      int var14 = var5 - 1;
      var2.setColor(super.darkShadow);
      var2.drawLine(1, 5, 6, 0);
      var2.drawLine(6, 0, var14, 0);
      if (var1 == var11) {
         var2.drawLine(var14, 1, var14, var13);
      }

      if (var1 != super.tabRuns[super.runCount - 1]) {
         var2.drawLine(0, 0, 0, var13);
      } else {
         var2.drawLine(0, 6, 0, var13);
      }

      var2.setColor(var9 ? this.selectHighlight : super.highlight);
      var2.drawLine(1, 6, 6, 1);
      var2.drawLine(6, 1, var14, 1);
      var2.drawLine(1, 6, 1, var13);
      if (var1 == var12 && var1 != super.tabRuns[super.runCount - 1]) {
         var2.setColor(super.tabPane.getSelectedIndex() == super.tabRuns[var10 + 1] ? this.selectHighlight : super.highlight);
         var2.drawLine(1, 0, 1, 4);
      }

      var2.translate(-var3, -var4);
   }

   protected boolean shouldFillGap(int var1, int var2, int var3, int var4) {
      boolean var5 = false;
      if (var1 == super.runCount - 2) {
         Rectangle var6 = ((BasicTabbedPaneUI)this).getTabBounds(super.tabPane, super.tabPane.getTabCount() - 1);
         int var7 = var6.x + var6.width - 1;
         if (var7 > ((BasicTabbedPaneUI)this).getTabBounds(super.tabPane, var2).x + 2) {
            return true;
         }
      } else {
         var5 = var1 != super.runCount - 1;
      }

      return var5;
   }

   protected boolean shouldPadTabRun(int var1, int var2) {
      return super.runCount > 1 && var2 < super.runCount - 1;
   }

   protected boolean shouldRotateTabRuns(int var1, int var2) {
      return false;
   }

   public void update(Graphics var1, JComponent var2) {
      if (var2.isOpaque()) {
         var1.setColor(this.tabAreaBackground);
         var1.fillRect(0, 0, var2.getWidth(), var2.getHeight());
      }

      this.paint(var1, var2);
   }
}
