package javax.swing.table;

import java.io.Serializable;
import java.util.Enumeration;
import java.util.Vector;
import javax.swing.event.TableModelEvent;

public class DefaultTableModel extends AbstractTableModel implements Serializable {
   protected Vector dataVector;
   protected Vector columnIdentifiers;

   public DefaultTableModel() {
      this((Vector)null, 0);
   }

   public DefaultTableModel(int var1, int var2) {
      Vector var3 = new Vector(var2);
      var3.setSize(var2);
      this.setColumnIdentifiers(var3);
      this.dataVector = new Vector();
      this.setNumRows(var1);
   }

   public DefaultTableModel(Vector var1, int var2) {
      this.setColumnIdentifiers(var1);
      this.dataVector = new Vector();
      this.setNumRows(var2);
   }

   public DefaultTableModel(Vector var1, Vector var2) {
      this.setDataVector(var1, var2);
   }

   public DefaultTableModel(Object[] var1, int var2) {
      this(convertToVector(var1), var2);
   }

   public DefaultTableModel(Object[][] var1, Object[] var2) {
      this.setDataVector(var1, var2);
   }

   public void addColumn(Object var1) {
      this.addColumn(var1, (Vector)null);
   }

   public void addColumn(Object var1, Vector var2) {
      if (var1 == null) {
         throw new IllegalArgumentException("addColumn() - null parameter");
      } else {
         this.columnIdentifiers.addElement(var1);
         int var3 = 0;

         for(Enumeration var4 = this.dataVector.elements(); var4.hasMoreElements(); ++var3) {
            Object var5;
            if (var2 != null && var3 < var2.size()) {
               var5 = var2.elementAt(var3);
            } else {
               var5 = null;
            }

            ((Vector)var4.nextElement()).addElement(var5);
         }

         ((AbstractTableModel)this).fireTableStructureChanged();
      }
   }

   public void addColumn(Object var1, Object[] var2) {
      this.addColumn(var1, convertToVector(var2));
   }

   public void addRow(Vector var1) {
      if (var1 == null) {
         var1 = new Vector(this.getColumnCount());
      } else {
         var1.setSize(this.getColumnCount());
      }

      this.dataVector.addElement(var1);
      this.newRowsAdded(new TableModelEvent(this, this.getRowCount() - 1, this.getRowCount() - 1, -1, 1));
   }

   public void addRow(Object[] var1) {
      this.addRow(convertToVector(var1));
   }

   protected static Vector convertToVector(Object[] var0) {
      if (var0 == null) {
         return null;
      } else {
         Vector var1 = new Vector(var0.length);

         for(int var2 = 0; var2 < var0.length; ++var2) {
            var1.addElement(var0[var2]);
         }

         return var1;
      }
   }

   protected static Vector convertToVector(Object[][] var0) {
      if (var0 == null) {
         return null;
      } else {
         Vector var1 = new Vector(var0.length);

         for(int var2 = 0; var2 < var0.length; ++var2) {
            var1.addElement(convertToVector(var0[var2]));
         }

         return var1;
      }
   }

   public int getColumnCount() {
      return this.columnIdentifiers.size();
   }

   public String getColumnName(int var1) {
      if (this.columnIdentifiers != null && this.columnIdentifiers.size() > var1) {
         Object var2 = this.columnIdentifiers.elementAt(var1);
         return var2 == null ? super.getColumnName(var1) : var2.toString();
      } else {
         return super.getColumnName(var1);
      }
   }

   public Vector getDataVector() {
      return this.dataVector;
   }

   public int getRowCount() {
      return this.dataVector.size();
   }

   public Object getValueAt(int var1, int var2) {
      Vector var3 = (Vector)this.dataVector.elementAt(var1);
      return var3.elementAt(var2);
   }

   public void insertRow(int var1, Vector var2) {
      if (var2 == null) {
         var2 = new Vector(this.getColumnCount());
      } else {
         var2.setSize(this.getColumnCount());
      }

      this.dataVector.insertElementAt(var2, var1);
      this.newRowsAdded(new TableModelEvent(this, var1, var1, -1, 1));
   }

   public void insertRow(int var1, Object[] var2) {
      this.insertRow(var1, convertToVector(var2));
   }

   public boolean isCellEditable(int var1, int var2) {
      return true;
   }

   public void moveRow(int var1, int var2, int var3) {
      if (var1 >= 0 && var1 < this.getRowCount()) {
         if (var2 >= 0 && var2 < this.getRowCount()) {
            if (var1 > var2) {
               throw new ArrayIndexOutOfBoundsException();
            } else if (var1 > var3 || var3 > var2) {
               boolean var4 = var3 < var1;

               for(int var5 = var1; var5 <= var2; ++var5) {
                  Object var6 = this.dataVector.elementAt(var5);
                  this.dataVector.removeElementAt(var5);
                  this.dataVector.insertElementAt(var6, var3);
                  if (var4) {
                     ++var3;
                  }
               }

               ((AbstractTableModel)this).fireTableDataChanged();
            }
         } else {
            throw new ArrayIndexOutOfBoundsException(var2);
         }
      } else {
         throw new ArrayIndexOutOfBoundsException(var1);
      }
   }

   public void newDataAvailable(TableModelEvent var1) {
      ((AbstractTableModel)this).fireTableChanged(var1);
   }

   public void newRowsAdded(TableModelEvent var1) {
      int var2 = var1.getFirstRow();
      int var3 = var1.getLastRow();
      if (var2 < 0) {
         var2 = 0;
      }

      if (var3 < 0) {
         var3 = this.getRowCount() - 1;
      }

      for(int var4 = var2; var4 < var3; ++var4) {
         ((Vector)this.dataVector.elementAt(var4)).setSize(this.getColumnCount());
      }

      ((AbstractTableModel)this).fireTableChanged(var1);
   }

   public void removeRow(int var1) {
      this.dataVector.removeElementAt(var1);
      ((AbstractTableModel)this).fireTableRowsDeleted(var1, var1);
   }

   public void rowsRemoved(TableModelEvent var1) {
      ((AbstractTableModel)this).fireTableChanged(var1);
   }

   public void setColumnIdentifiers(Vector var1) {
      if (var1 != null) {
         this.columnIdentifiers = var1;
      } else {
         this.columnIdentifiers = new Vector();
      }

      ((AbstractTableModel)this).fireTableStructureChanged();
   }

   public void setColumnIdentifiers(Object[] var1) {
      this.setColumnIdentifiers(convertToVector(var1));
   }

   public void setDataVector(Vector var1, Vector var2) {
      if (var1 == null) {
         throw new IllegalArgumentException("setDataVector() - Null parameter");
      } else {
         this.dataVector = new Vector(0);
         this.setColumnIdentifiers(var2);
         this.dataVector = var1;
         this.newRowsAdded(new TableModelEvent(this, 0, this.getRowCount() - 1, -1, 1));
      }
   }

   public void setDataVector(Object[][] var1, Object[] var2) {
      this.setDataVector(convertToVector(var1), convertToVector(var2));
   }

   public void setNumRows(int var1) {
      if (var1 >= 0 && var1 != this.getRowCount()) {
         int var2 = this.getRowCount();
         if (var1 <= this.getRowCount()) {
            this.dataVector.setSize(var1);
            ((AbstractTableModel)this).fireTableRowsDeleted(this.getRowCount(), var2 - 1);
         } else {
            int var3 = this.getColumnCount();

            while(this.getRowCount() < var1) {
               Vector var4 = new Vector(var3);
               var4.setSize(var3);
               this.dataVector.addElement(var4);
            }

            ((AbstractTableModel)this).fireTableRowsInserted(var2, this.getRowCount() - 1);
         }

      }
   }

   public void setValueAt(Object var1, int var2, int var3) {
      Vector var4 = (Vector)this.dataVector.elementAt(var2);
      var4.setElementAt(var1, var3);
      ((AbstractTableModel)this).fireTableChanged(new TableModelEvent(this, var2, var2, var3));
   }
}
