package javax.swing;

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Insets;
import java.awt.ItemSelectable;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import javax.accessibility.AccessibleState;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.plaf.ButtonUI;
import javax.swing.plaf.UIResource;

public abstract class AbstractButton extends JComponent implements ItemSelectable, SwingConstants {
   public static final String MODEL_CHANGED_PROPERTY = "model";
   public static final String TEXT_CHANGED_PROPERTY = "text";
   public static final String MNEMONIC_CHANGED_PROPERTY = "mnemonic";
   public static final String MARGIN_CHANGED_PROPERTY = "margin";
   public static final String VERTICAL_ALIGNMENT_CHANGED_PROPERTY = "verticalAlignment";
   public static final String HORIZONTAL_ALIGNMENT_CHANGED_PROPERTY = "horizontalAlignment";
   public static final String VERTICAL_TEXT_POSITION_CHANGED_PROPERTY = "verticalTextPosition";
   public static final String HORIZONTAL_TEXT_POSITION_CHANGED_PROPERTY = "horizontalTextPosition";
   public static final String BORDER_PAINTED_CHANGED_PROPERTY = "borderPainted";
   public static final String FOCUS_PAINTED_CHANGED_PROPERTY = "focusPainted";
   public static final String ROLLOVER_ENABLED_CHANGED_PROPERTY = "rolloverEnabled";
   public static final String CONTENT_AREA_FILLED_CHANGED_PROPERTY = "contentAreaFilled";
   public static final String ICON_CHANGED_PROPERTY = "icon";
   public static final String PRESSED_ICON_CHANGED_PROPERTY = "pressedIcon";
   public static final String SELECTED_ICON_CHANGED_PROPERTY = "selectedIcon";
   public static final String ROLLOVER_ICON_CHANGED_PROPERTY = "rolloverIcon";
   public static final String ROLLOVER_SELECTED_ICON_CHANGED_PROPERTY = "rolloverSelectedIcon";
   public static final String DISABLED_ICON_CHANGED_PROPERTY = "disabledIcon";
   public static final String DISABLED_SELECTED_ICON_CHANGED_PROPERTY = "disabledSelectedIcon";
   protected ButtonModel model = null;
   private String text = "";
   private Insets margin = null;
   private Insets defaultMargin = null;
   private Icon defaultIcon = null;
   private Icon pressedIcon = null;
   private Icon disabledIcon = null;
   private Icon selectedIcon = null;
   private Icon disabledSelectedIcon = null;
   private Icon rolloverIcon = null;
   private Icon rolloverSelectedIcon = null;
   private boolean paintBorder = true;
   private boolean paintFocus = true;
   private boolean rolloverEnabled = false;
   private boolean contentAreaFilled = true;
   private int verticalAlignment = 0;
   private int horizontalAlignment = 0;
   private int verticalTextPosition = 0;
   private int horizontalTextPosition = 11;
   protected ChangeListener changeListener = null;
   protected ActionListener actionListener = null;
   protected ItemListener itemListener = null;
   protected transient ChangeEvent changeEvent;
   // $FF: synthetic field
   static Class class$javax$swing$event$ChangeListener;
   // $FF: synthetic field
   static Class class$java$awt$event$ActionListener;
   // $FF: synthetic field
   static Class class$java$awt$event$ItemListener;

   public void addActionListener(ActionListener var1) {
      super.listenerList.add(class$java$awt$event$ActionListener != null ? class$java$awt$event$ActionListener : (class$java$awt$event$ActionListener = class$("java.awt.event.ActionListener")), var1);
   }

   public void addChangeListener(ChangeListener var1) {
      super.listenerList.add(class$javax$swing$event$ChangeListener != null ? class$javax$swing$event$ChangeListener : (class$javax$swing$event$ChangeListener = class$("javax.swing.event.ChangeListener")), var1);
   }

   public void addItemListener(ItemListener var1) {
      super.listenerList.add(class$java$awt$event$ItemListener != null ? class$java$awt$event$ItemListener : (class$java$awt$event$ItemListener = class$("java.awt.event.ItemListener")), var1);
   }

   protected int checkHorizontalKey(int var1, String var2) {
      if (var1 != 2 && var1 != 0 && var1 != 4 && var1 != 10 && var1 != 11) {
         throw new IllegalArgumentException(var2);
      } else {
         return var1;
      }
   }

   protected int checkVerticalKey(int var1, String var2) {
      if (var1 != 1 && var1 != 0 && var1 != 3) {
         throw new IllegalArgumentException(var2);
      } else {
         return var1;
      }
   }

   // $FF: synthetic method
   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(((Throwable)var2).getMessage());
      }
   }

   protected ActionListener createActionListener() {
      return new ForwardActionEvents(this);
   }

   protected ChangeListener createChangeListener() {
      return new ButtonChangeListener(this);
   }

   protected ItemListener createItemListener() {
      return new ForwardItemEvents(this);
   }

   public void doClick() {
      this.doClick(68);
   }

   public void doClick(int var1) {
      Dimension var2 = ((Component)this).getSize();
      this.model.setArmed(true);
      this.model.setPressed(true);
      ((JComponent)this).paintImmediately(new Rectangle(0, 0, var2.width, var2.height));

      try {
         Thread.currentThread();
         Thread.sleep((long)var1);
      } catch (InterruptedException var3) {
      }

      this.model.setPressed(false);
      this.model.setArmed(false);
   }

   protected void fireActionPerformed(ActionEvent var1) {
      Object[] var2 = super.listenerList.getListenerList();
      ActionEvent var3 = null;

      for(int var4 = var2.length - 2; var4 >= 0; var4 -= 2) {
         if (var2[var4] == (class$java$awt$event$ActionListener != null ? class$java$awt$event$ActionListener : (class$java$awt$event$ActionListener = class$("java.awt.event.ActionListener")))) {
            if (var3 == null) {
               String var5 = var1.getActionCommand();
               if (var5 == null) {
                  var5 = this.getActionCommand();
               }

               var3 = new ActionEvent(this, 1001, var5, var1.getModifiers());
            }

            ((ActionListener)var2[var4 + 1]).actionPerformed(var3);
         }
      }

   }

   protected void fireItemStateChanged(ItemEvent var1) {
      Object[] var2 = super.listenerList.getListenerList();
      ItemEvent var3 = null;

      for(int var4 = var2.length - 2; var4 >= 0; var4 -= 2) {
         if (var2[var4] == (class$java$awt$event$ItemListener != null ? class$java$awt$event$ItemListener : (class$java$awt$event$ItemListener = class$("java.awt.event.ItemListener")))) {
            if (var3 == null) {
               var3 = new ItemEvent(this, 701, this, var1.getStateChange());
            }

            ((ItemListener)var2[var4 + 1]).itemStateChanged(var3);
         }
      }

   }

   protected void fireStateChanged() {
      Object[] var1 = super.listenerList.getListenerList();

      for(int var2 = var1.length - 2; var2 >= 0; var2 -= 2) {
         if (var1[var2] == (class$javax$swing$event$ChangeListener != null ? class$javax$swing$event$ChangeListener : (class$javax$swing$event$ChangeListener = class$("javax.swing.event.ChangeListener")))) {
            if (this.changeEvent == null) {
               this.changeEvent = new ChangeEvent(this);
            }

            ((ChangeListener)var1[var2 + 1]).stateChanged(this.changeEvent);
         }
      }

   }

   public String getActionCommand() {
      String var1 = this.getModel().getActionCommand();
      if (var1 == null) {
         var1 = this.getText();
      }

      return var1;
   }

   public Icon getDisabledIcon() {
      if (this.disabledIcon == null && this.defaultIcon != null && this.defaultIcon instanceof ImageIcon) {
         this.disabledIcon = new ImageIcon(GrayFilter.createDisabledImage(((ImageIcon)this.defaultIcon).getImage()));
      }

      return this.disabledIcon;
   }

   public Icon getDisabledSelectedIcon() {
      if (this.disabledSelectedIcon == null) {
         if (this.selectedIcon == null || !(this.selectedIcon instanceof ImageIcon)) {
            return this.disabledIcon;
         }

         this.disabledSelectedIcon = new ImageIcon(GrayFilter.createDisabledImage(((ImageIcon)this.selectedIcon).getImage()));
      }

      return this.disabledSelectedIcon;
   }

   public int getHorizontalAlignment() {
      return this.horizontalAlignment;
   }

   public int getHorizontalTextPosition() {
      return this.horizontalTextPosition;
   }

   public Icon getIcon() {
      return this.defaultIcon;
   }

   /** @deprecated */
   public String getLabel() {
      return this.getText();
   }

   public Insets getMargin() {
      return this.margin;
   }

   public int getMnemonic() {
      return this.model.getMnemonic();
   }

   public ButtonModel getModel() {
      return this.model;
   }

   public Icon getPressedIcon() {
      return this.pressedIcon;
   }

   public Icon getRolloverIcon() {
      return this.rolloverIcon;
   }

   public Icon getRolloverSelectedIcon() {
      return this.rolloverSelectedIcon;
   }

   public Icon getSelectedIcon() {
      return this.selectedIcon;
   }

   public synchronized Object[] getSelectedObjects() {
      if (!this.isSelected()) {
         return null;
      } else {
         Object[] var1 = new Object[]{this.getText()};
         return var1;
      }
   }

   public String getText() {
      return this.text;
   }

   public ButtonUI getUI() {
      return (ButtonUI)super.ui;
   }

   public int getVerticalAlignment() {
      return this.verticalAlignment;
   }

   public int getVerticalTextPosition() {
      return this.verticalTextPosition;
   }

   protected void init(String var1, Icon var2) {
      ((Container)this).setLayout(new OverlayLayout(this));
      if (var1 != null) {
         this.setText(var1);
      }

      if (var2 != null) {
         this.setIcon(var2);
      }

      this.updateUI();
      ((Component)this).addFocusListener(new 1(this));
      ((JComponent)this).setAlignmentX(0.0F);
      ((JComponent)this).setAlignmentY(0.5F);
   }

   public boolean isBorderPainted() {
      return this.paintBorder;
   }

   public boolean isContentAreaFilled() {
      return this.contentAreaFilled;
   }

   public boolean isFocusPainted() {
      return this.paintFocus;
   }

   public boolean isRolloverEnabled() {
      return this.rolloverEnabled;
   }

   public boolean isSelected() {
      return this.model.isSelected();
   }

   protected void paintBorder(Graphics var1) {
      if (this.isBorderPainted()) {
         super.paintBorder(var1);
      }

   }

   protected String paramString() {
      String var1 = this.defaultIcon != null ? this.defaultIcon.toString() : "";
      String var2 = this.pressedIcon != null ? this.pressedIcon.toString() : "";
      String var3 = this.disabledIcon != null ? this.disabledIcon.toString() : "";
      String var4 = this.selectedIcon != null ? this.selectedIcon.toString() : "";
      String var5 = this.disabledSelectedIcon != null ? this.disabledSelectedIcon.toString() : "";
      String var6 = this.rolloverIcon != null ? this.rolloverIcon.toString() : "";
      String var7 = this.rolloverSelectedIcon != null ? this.rolloverSelectedIcon.toString() : "";
      String var8 = this.paintBorder ? "true" : "false";
      String var9 = this.paintFocus ? "true" : "false";
      String var10 = this.rolloverEnabled ? "true" : "false";
      return super.paramString() + ",defaultIcon=" + var1 + ",disabledIcon=" + var3 + ",disabledSelectedIcon=" + var5 + ",margin=" + this.margin + ",paintBorder=" + var8 + ",paintFocus=" + var9 + ",pressedIcon=" + var2 + ",rolloverEnabled=" + var10 + ",rolloverIcon=" + var6 + ",rolloverSelectedIcon=" + var7 + ",selectedIcon=" + var4 + ",text=" + this.text;
   }

   public void removeActionListener(ActionListener var1) {
      super.listenerList.remove(class$java$awt$event$ActionListener != null ? class$java$awt$event$ActionListener : (class$java$awt$event$ActionListener = class$("java.awt.event.ActionListener")), var1);
   }

   public void removeChangeListener(ChangeListener var1) {
      super.listenerList.remove(class$javax$swing$event$ChangeListener != null ? class$javax$swing$event$ChangeListener : (class$javax$swing$event$ChangeListener = class$("javax.swing.event.ChangeListener")), var1);
   }

   public void removeItemListener(ItemListener var1) {
      super.listenerList.remove(class$java$awt$event$ItemListener != null ? class$java$awt$event$ItemListener : (class$java$awt$event$ItemListener = class$("java.awt.event.ItemListener")), var1);
   }

   public void setActionCommand(String var1) {
      this.getModel().setActionCommand(var1);
   }

   public void setBorderPainted(boolean var1) {
      boolean var2 = this.paintBorder;
      this.paintBorder = var1;
      ((JComponent)this).firePropertyChange("borderPainted", var2, this.paintBorder);
      if (var1 != var2) {
         ((JComponent)this).revalidate();
         ((Component)this).repaint();
      }

   }

   public void setContentAreaFilled(boolean var1) {
      boolean var2 = this.contentAreaFilled;
      this.contentAreaFilled = var1;
      ((JComponent)this).firePropertyChange("contentAreaFilled", var2, this.contentAreaFilled);
      if (var1 != var2) {
         ((Component)this).repaint();
      }

   }

   public void setDisabledIcon(Icon var1) {
      Icon var2 = this.disabledIcon;
      this.disabledIcon = var1;
      ((JComponent)this).firePropertyChange("disabledIcon", var2, var1);
      if (super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleVisibleData", var2, var1);
      }

      if (var1 != var2 && !((Component)this).isEnabled()) {
         ((Component)this).repaint();
      }

   }

   public void setDisabledSelectedIcon(Icon var1) {
      Icon var2 = this.disabledSelectedIcon;
      this.disabledSelectedIcon = var1;
      ((JComponent)this).firePropertyChange("disabledSelectedIcon", var2, var1);
      if (super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleVisibleData", var2, var1);
      }

      if (var1 != var2) {
         if (var1 == null || var2 == null || var1.getIconWidth() != var2.getIconWidth() || var1.getIconHeight() != var2.getIconHeight()) {
            ((JComponent)this).revalidate();
         }

         if (!((Component)this).isEnabled() && this.isSelected()) {
            ((Component)this).repaint();
         }
      }

   }

   public void setEnabled(boolean var1) {
      super.setEnabled(var1);
      this.model.setEnabled(var1);
   }

   public void setFocusPainted(boolean var1) {
      boolean var2 = this.paintFocus;
      this.paintFocus = var1;
      ((JComponent)this).firePropertyChange("focusPainted", var2, this.paintFocus);
      if (var1 != var2 && ((JComponent)this).hasFocus()) {
         ((JComponent)this).revalidate();
         ((Component)this).repaint();
      }

   }

   public void setHorizontalAlignment(int var1) {
      if (var1 != this.horizontalAlignment) {
         int var2 = this.horizontalAlignment;
         this.horizontalAlignment = this.checkHorizontalKey(var1, "horizontalAlignment");
         ((JComponent)this).firePropertyChange("horizontalAlignment", var2, this.horizontalAlignment);
         ((Component)this).repaint();
      }
   }

   public void setHorizontalTextPosition(int var1) {
      if (var1 != this.horizontalTextPosition) {
         int var2 = this.horizontalTextPosition;
         this.horizontalTextPosition = this.checkHorizontalKey(var1, "horizontalTextPosition");
         ((JComponent)this).firePropertyChange("horizontalTextPosition", var2, this.horizontalTextPosition);
         ((Component)this).repaint();
      }
   }

   public void setIcon(Icon var1) {
      Icon var2 = this.defaultIcon;
      this.defaultIcon = var1;
      ((JComponent)this).firePropertyChange("icon", var2, var1);
      if (super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleVisibleData", var2, var1);
      }

      if (var1 != var2) {
         if (var1 == null || var2 == null || var1.getIconWidth() != var2.getIconWidth() || var1.getIconHeight() != var2.getIconHeight()) {
            ((JComponent)this).revalidate();
         }

         ((Component)this).repaint();
      }

   }

   /** @deprecated */
   public void setLabel(String var1) {
      this.setText(var1);
   }

   public void setMargin(Insets var1) {
      if (var1 instanceof UIResource) {
         this.defaultMargin = var1;
      } else if (this.margin instanceof UIResource) {
         this.defaultMargin = this.margin;
      }

      if (var1 == null && this.defaultMargin != null) {
         var1 = this.defaultMargin;
      }

      Insets var2 = this.margin;
      this.margin = var1;
      ((JComponent)this).firePropertyChange("margin", var2, var1);
      if (var2 == null || !var1.equals(var2)) {
         ((JComponent)this).revalidate();
         ((Component)this).repaint();
      }

   }

   public void setMnemonic(char var1) {
      int var2 = var1;
      if (var1 >= 'a' && var1 <= 'z') {
         var2 = var1 - 32;
      }

      this.setMnemonic(var2);
   }

   public void setMnemonic(int var1) {
      int var2 = this.getMnemonic();
      this.model.setMnemonic(var1);
      ((JComponent)this).firePropertyChange("mnemonic", var2, var1);
      if (var1 != var2) {
         ((JComponent)this).revalidate();
         ((Component)this).repaint();
      }

   }

   public void setModel(ButtonModel var1) {
      ButtonModel var2 = this.getModel();
      if (var2 != null) {
         var2.removeChangeListener(this.changeListener);
         var2.removeActionListener(this.actionListener);
         this.changeListener = null;
         this.actionListener = null;
      }

      this.model = var1;
      if (var1 != null) {
         this.changeListener = this.createChangeListener();
         this.actionListener = this.createActionListener();
         this.itemListener = this.createItemListener();
         var1.addChangeListener(this.changeListener);
         var1.addActionListener(this.actionListener);
         var1.addItemListener(this.itemListener);
      }

      ((JComponent)this).firePropertyChange("model", var2, var1);
      if (var1 != var2) {
         ((JComponent)this).revalidate();
         ((Component)this).repaint();
      }

   }

   public void setPressedIcon(Icon var1) {
      Icon var2 = this.pressedIcon;
      this.pressedIcon = var1;
      ((JComponent)this).firePropertyChange("pressedIcon", var2, var1);
      if (super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleVisibleData", var2, this.defaultIcon);
      }

      if (var1 != var2 && this.getModel().isPressed()) {
         ((Component)this).repaint();
      }

   }

   public void setRolloverEnabled(boolean var1) {
      boolean var2 = this.rolloverEnabled;
      this.rolloverEnabled = var1;
      ((JComponent)this).firePropertyChange("rolloverEnabled", var2, this.rolloverEnabled);
      if (var1 != var2) {
         ((Component)this).repaint();
      }

   }

   public void setRolloverIcon(Icon var1) {
      Icon var2 = this.rolloverIcon;
      this.rolloverIcon = var1;
      ((JComponent)this).firePropertyChange("rolloverIcon", var2, var1);
      if (super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleVisibleData", var2, var1);
      }

      this.setRolloverEnabled(true);
      if (var1 != var2) {
         ((Component)this).repaint();
      }

   }

   public void setRolloverSelectedIcon(Icon var1) {
      Icon var2 = this.rolloverSelectedIcon;
      this.rolloverSelectedIcon = var1;
      ((JComponent)this).firePropertyChange("rolloverSelectedIcon", var2, var1);
      if (super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleVisibleData", var2, var1);
      }

      if (var1 != var2 && this.isSelected()) {
         ((Component)this).repaint();
      }

   }

   public void setSelected(boolean var1) {
      boolean var2 = this.isSelected();
      if (super.accessibleContext != null && var2 != var1) {
         if (var1) {
            super.accessibleContext.firePropertyChange("AccessibleState", (Object)null, AccessibleState.SELECTED);
         } else {
            super.accessibleContext.firePropertyChange("AccessibleState", AccessibleState.SELECTED, (Object)null);
         }
      }

      this.model.setSelected(var1);
   }

   public void setSelectedIcon(Icon var1) {
      Icon var2 = this.selectedIcon;
      this.selectedIcon = var1;
      ((JComponent)this).firePropertyChange("selectedIcon", var2, var1);
      if (super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleVisibleData", var2, var1);
      }

      if (var1 != var2 && this.isSelected()) {
         ((Component)this).repaint();
      }

   }

   public void setText(String var1) {
      String var2 = this.text;
      this.text = var1;
      ((JComponent)this).firePropertyChange("text", var2, var1);
      if (super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleVisibleData", var2, var1);
      }

      if (var1 == null || var2 == null || !var1.equals(var2)) {
         ((JComponent)this).revalidate();
         ((Component)this).repaint();
      }

   }

   public void setUI(ButtonUI var1) {
      super.setUI(var1);
   }

   public void setVerticalAlignment(int var1) {
      if (var1 != this.verticalAlignment) {
         int var2 = this.verticalAlignment;
         this.verticalAlignment = this.checkVerticalKey(var1, "verticalAlignment");
         ((JComponent)this).firePropertyChange("verticalAlignment", var2, this.verticalAlignment);
         ((Component)this).repaint();
      }
   }

   public void setVerticalTextPosition(int var1) {
      if (var1 != this.verticalTextPosition) {
         int var2 = this.verticalTextPosition;
         this.verticalTextPosition = this.checkVerticalKey(var1, "verticalTextPosition");
         ((JComponent)this).firePropertyChange("verticalTextPosition", var2, this.verticalTextPosition);
         ((Component)this).repaint();
      }
   }

   public void updateUI() {
   }
}
