package javax.swing;

import java.io.IOException;
import java.io.ObjectOutputStream;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;
import javax.swing.plaf.ButtonUI;

public class JButton extends AbstractButton implements Accessible {
   private static final String uiClassID = "ButtonUI";
   private boolean defaultCapable;

   public JButton() {
      this((String)null, (Icon)null);
   }

   public JButton(String var1) {
      this(var1, (Icon)null);
   }

   public JButton(String var1, Icon var2) {
      this.defaultCapable = true;
      ((AbstractButton)this).setModel(new DefaultButtonModel());
      ((AbstractButton)this).init(var1, var2);
   }

   public JButton(Icon var1) {
      this((String)null, var1);
   }

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleJButton(this);
      }

      return super.accessibleContext;
   }

   public String getUIClassID() {
      return "ButtonUI";
   }

   public boolean isDefaultButton() {
      JRootPane var1 = SwingUtilities.getRootPane(this);
      if (var1 != null) {
         return var1.getDefaultButton() == this;
      } else {
         return false;
      }
   }

   public boolean isDefaultCapable() {
      return this.defaultCapable;
   }

   protected String paramString() {
      String var1 = this.defaultCapable ? "true" : "false";
      return super.paramString() + ",defaultCapable=" + var1;
   }

   public void setDefaultCapable(boolean var1) {
      boolean var2 = this.defaultCapable;
      this.defaultCapable = var1;
      ((JComponent)this).firePropertyChange("defaultCapable", var2, var1);
   }

   public void updateUI() {
      ((AbstractButton)this).setUI((ButtonUI)UIManager.getUI(this));
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      if (super.ui != null && this.getUIClassID().equals("ButtonUI")) {
         super.ui.installUI(this);
      }

   }
}
