package javax.swing;

import java.awt.Component;
import java.awt.Container;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.util.Vector;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;
import javax.swing.plaf.DesktopPaneUI;

public class JDesktopPane extends JLayeredPane implements Accessible {
   private static final String uiClassID = "DesktopPaneUI";
   transient DesktopManager desktopManager;

   public JDesktopPane() {
      this.updateUI();
   }

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleJDesktopPane(this);
      }

      return super.accessibleContext;
   }

   public JInternalFrame[] getAllFrames() {
      Vector var4 = new Vector(10);
      int var2 = ((Container)this).getComponentCount();

      for(int var1 = 0; var1 < var2; ++var1) {
         Component var5 = ((Container)this).getComponent(var1);
         if (var5 instanceof JInternalFrame) {
            var4.addElement(var5);
         } else if (var5 instanceof JInternalFrame.JDesktopIcon) {
            JInternalFrame var6 = ((JInternalFrame.JDesktopIcon)var5).getInternalFrame();
            if (var6 != null) {
               var4.addElement(var6);
            }
         }
      }

      JInternalFrame[] var3 = new JInternalFrame[var4.size()];
      var4.copyInto(var3);
      return var3;
   }

   public JInternalFrame[] getAllFramesInLayer(int var1) {
      Vector var5 = new Vector(10);
      int var3 = ((Container)this).getComponentCount();

      for(int var2 = 0; var2 < var3; ++var2) {
         Component var6 = ((Container)this).getComponent(var2);
         if (var6 instanceof JInternalFrame) {
            if (((JInternalFrame)var6).getLayer() == var1) {
               var5.addElement(var6);
            } else if (var6 instanceof JInternalFrame.JDesktopIcon) {
               JInternalFrame var7 = ((JInternalFrame.JDesktopIcon)var6).getInternalFrame();
               if (var7 != null && ((JInternalFrame)var7).getLayer() == var1) {
                  var5.addElement(var7);
               }
            }
         }
      }

      JInternalFrame[] var4 = new JInternalFrame[var5.size()];
      var5.copyInto(var4);
      return var4;
   }

   public DesktopManager getDesktopManager() {
      return this.desktopManager;
   }

   public DesktopPaneUI getUI() {
      return (DesktopPaneUI)super.ui;
   }

   public String getUIClassID() {
      return "DesktopPaneUI";
   }

   public boolean isOpaque() {
      return true;
   }

   protected String paramString() {
      String var1 = this.desktopManager != null ? this.desktopManager.toString() : "";
      return super.paramString() + ",desktopManager=" + var1;
   }

   public void setDesktopManager(DesktopManager var1) {
      this.desktopManager = var1;
   }

   public void setUI(DesktopPaneUI var1) {
      super.setUI(var1);
   }

   public void updateUI() {
      this.setUI((DesktopPaneUI)UIManager.getUI(this));
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      if (super.ui != null && this.getUIClassID().equals("DesktopPaneUI")) {
         super.ui.installUI(this);
      }

   }
}
