package javax.swing;

import java.applet.Applet;
import java.awt.AWTEvent;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dialog;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.Graphics;
import java.awt.LayoutManager;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.Window;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.awt.event.WindowEvent;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;

public class JDialog extends Dialog implements WindowConstants, Accessible, RootPaneContainer {
   private int defaultCloseOperation;
   protected JRootPane rootPane;
   protected boolean rootPaneCheckingEnabled;
   protected AccessibleContext accessibleContext;

   public JDialog() {
      this((Frame)null, false);
   }

   public JDialog(Frame var1) {
      this(var1, false);
   }

   public JDialog(Frame var1, String var2) {
      this(var1, var2, false);
   }

   public JDialog(Frame var1, String var2, boolean var3) {
      super(var1 == null ? SwingUtilities.getSharedOwnerFrame() : var1, var2, var3);
      this.defaultCloseOperation = 1;
      this.rootPaneCheckingEnabled = false;
      this.accessibleContext = null;
      this.dialogInit();
   }

   public JDialog(Frame var1, boolean var2) {
      this(var1, (String)null, var2);
   }

   protected void addImpl(Component var1, Object var2, int var3) {
      if (this.isRootPaneCheckingEnabled()) {
         throw this.createRootPaneException("add");
      } else {
         super.addImpl(var1, var2, var3);
      }
   }

   protected JRootPane createRootPane() {
      return new JRootPane();
   }

   private Error createRootPaneException(String var1) {
      String var2 = this.getClass().getName();
      return new Error("Do not use " + var2 + "." + var1 + "() use " + var2 + ".getContentPane()." + var1 + "() instead");
   }

   protected void dialogInit() {
      ((Component)this).enableEvents(72L);
      this.setRootPane(this.createRootPane());
      this.setRootPaneCheckingEnabled(true);
   }

   public AccessibleContext getAccessibleContext() {
      if (this.accessibleContext == null) {
         this.accessibleContext = new AccessibleJDialog(this);
      }

      return this.accessibleContext;
   }

   public Container getContentPane() {
      return this.getRootPane().getContentPane();
   }

   public int getDefaultCloseOperation() {
      return this.defaultCloseOperation;
   }

   public Component getGlassPane() {
      return this.getRootPane().getGlassPane();
   }

   public JMenuBar getJMenuBar() {
      return this.getRootPane().getMenuBar();
   }

   public JLayeredPane getLayeredPane() {
      return this.getRootPane().getLayeredPane();
   }

   public JRootPane getRootPane() {
      return this.rootPane;
   }

   protected boolean isRootPaneCheckingEnabled() {
      return this.rootPaneCheckingEnabled;
   }

   protected String paramString() {
      String var1;
      if (this.defaultCloseOperation == 1) {
         var1 = "HIDE_ON_CLOSE";
      } else if (this.defaultCloseOperation == 2) {
         var1 = "DISPOSE_ON_CLOSE";
      } else if (this.defaultCloseOperation == 0) {
         var1 = "DO_NOTHING_ON_CLOSE";
      } else if (this.defaultCloseOperation == 3) {
         var1 = "EXIT_ON_CLOSE";
      } else {
         var1 = "";
      }

      String var2 = this.rootPane != null ? this.rootPane.toString() : "";
      String var3 = this.rootPaneCheckingEnabled ? "true" : "false";
      return super.paramString() + ",defaultCloseOperation=" + var1 + ",rootPane=" + var2 + ",rootPaneCheckingEnabled=" + var3;
   }

   protected void processKeyEvent(KeyEvent var1) {
      super.processKeyEvent(var1);
      if (!((InputEvent)var1).isConsumed()) {
         JComponent.processKeyBindingsForAllComponents(var1, this, ((AWTEvent)var1).getID() == 401);
      }

   }

   protected void processWindowEvent(WindowEvent var1) {
      super.processWindowEvent(var1);
      if (((AWTEvent)var1).getID() == 201) {
         switch (this.defaultCloseOperation) {
            case 0:
            default:
               break;
            case 1:
               ((Component)this).setVisible(false);
               break;
            case 2:
               ((Component)this).setVisible(false);
               ((Window)this).dispose();
               break;
            case 3:
               System.exit(0);
         }
      }

   }

   public void remove(Component var1) {
      if (var1 == this.rootPane) {
         super.remove(var1);
      } else {
         this.getContentPane().remove(var1);
      }

   }

   public void setContentPane(Container var1) {
      this.getRootPane().setContentPane(var1);
   }

   public void setDefaultCloseOperation(int var1) {
      this.defaultCloseOperation = var1;
   }

   public void setGlassPane(Component var1) {
      this.getRootPane().setGlassPane(var1);
   }

   public void setJMenuBar(JMenuBar var1) {
      this.getRootPane().setMenuBar(var1);
   }

   public void setLayeredPane(JLayeredPane var1) {
      this.getRootPane().setLayeredPane(var1);
   }

   public void setLayout(LayoutManager var1) {
      if (this.isRootPaneCheckingEnabled()) {
         throw this.createRootPaneException("setLayout");
      } else {
         super.setLayout(var1);
      }
   }

   public void setLocationRelativeTo(Component var1) {
      Container var2 = null;
      if (var1 != null) {
         if (!(var1 instanceof Window) && !(var1 instanceof Applet)) {
            for(Container var3 = var1.getParent(); var3 != null; var3 = ((Component)var3).getParent()) {
               if (var3 instanceof Window || var3 instanceof Applet) {
                  var2 = var3;
                  break;
               }
            }
         } else {
            var2 = (Container)var1;
         }
      }

      if ((var1 == null || var1.isShowing()) && var2 != null && ((Component)var2).isShowing()) {
         Dimension var10 = var1.getSize();
         Point var11;
         if (var2 instanceof Applet) {
            var11 = var1.getLocationOnScreen();
         } else {
            var11 = new Point(0, 0);

            for(Object var5 = var1; var5 != null; var5 = ((Component)var5).getParent()) {
               Point var6 = ((Component)var5).getLocation();
               var11.x += var6.x;
               var11.y += var6.y;
               if (var5 == var2) {
                  break;
               }
            }
         }

         Rectangle var12 = ((Component)this).getBounds();
         int var13 = var11.x + (var10.width - var12.width >> 1);
         int var7 = var11.y + (var10.height - var12.height >> 1);
         Dimension var8 = ((Window)this).getToolkit().getScreenSize();
         if (var7 + var12.height > var8.height) {
            var7 = var8.height - var12.height;
            var13 = var11.x < var8.width >> 1 ? var11.x + var10.width : var11.x - var12.width;
         }

         if (var13 + var12.width > var8.width) {
            var13 = var8.width - var12.width;
         }

         if (var13 < 0) {
            var13 = 0;
         }

         if (var7 < 0) {
            var7 = 0;
         }

         ((Component)this).setLocation(var13, var7);
      } else {
         Dimension var9 = ((Component)this).getSize();
         Dimension var4 = ((Window)this).getToolkit().getScreenSize();
         ((Component)this).setLocation((var4.width - var9.width) / 2, (var4.height - var9.height) / 2);
      }

   }

   protected void setRootPane(JRootPane var1) {
      if (this.rootPane != null) {
         this.remove(this.rootPane);
      }

      this.rootPane = var1;
      if (this.rootPane != null) {
         boolean var2 = this.isRootPaneCheckingEnabled();

         try {
            this.setRootPaneCheckingEnabled(false);
            ((Container)this).add(this.rootPane, "Center");
         } finally {
            this.setRootPaneCheckingEnabled(var2);
         }
      }

   }

   protected void setRootPaneCheckingEnabled(boolean var1) {
      this.rootPaneCheckingEnabled = var1;
   }

   public void update(Graphics var1) {
      ((Container)this).paint(var1);
   }
}
