package javax.swing;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dialog;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.Window;
import java.beans.PropertyVetoException;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.util.Vector;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;
import javax.swing.plaf.OptionPaneUI;

public class JOptionPane extends JComponent implements Accessible {
   private static final String uiClassID = "OptionPaneUI";
   public static final Object UNINITIALIZED_VALUE = "uninitializedValue";
   public static final int DEFAULT_OPTION = -1;
   public static final int YES_NO_OPTION = 0;
   public static final int YES_NO_CANCEL_OPTION = 1;
   public static final int OK_CANCEL_OPTION = 2;
   public static final int YES_OPTION = 0;
   public static final int NO_OPTION = 1;
   public static final int CANCEL_OPTION = 2;
   public static final int OK_OPTION = 0;
   public static final int CLOSED_OPTION = -1;
   public static final int ERROR_MESSAGE = 0;
   public static final int INFORMATION_MESSAGE = 1;
   public static final int WARNING_MESSAGE = 2;
   public static final int QUESTION_MESSAGE = 3;
   public static final int PLAIN_MESSAGE = -1;
   public static final String ICON_PROPERTY = "icon";
   public static final String MESSAGE_PROPERTY = "message";
   public static final String VALUE_PROPERTY = "value";
   public static final String OPTIONS_PROPERTY = "options";
   public static final String INITIAL_VALUE_PROPERTY = "initialValue";
   public static final String MESSAGE_TYPE_PROPERTY = "messageType";
   public static final String OPTION_TYPE_PROPERTY = "optionType";
   public static final String SELECTION_VALUES_PROPERTY = "selectionValues";
   public static final String INITIAL_SELECTION_VALUE_PROPERTY = "initialSelectionValue";
   public static final String INPUT_VALUE_PROPERTY = "inputValue";
   public static final String WANTS_INPUT_PROPERTY = "wantsInput";
   protected transient Icon icon;
   protected transient Object message;
   protected transient Object[] options;
   protected transient Object initialValue;
   protected int messageType;
   protected int optionType;
   protected transient Object value;
   protected transient Object[] selectionValues;
   protected transient Object inputValue;
   protected transient Object initialSelectionValue;
   protected boolean wantsInput;
   private static final Object sharedFrameKey;
   // $FF: synthetic field
   static Class class$javax$swing$JOptionPane;

   static {
      sharedFrameKey = class$javax$swing$JOptionPane != null ? class$javax$swing$JOptionPane : (class$javax$swing$JOptionPane = class$("javax.swing.JOptionPane"));
   }

   public JOptionPane() {
      this("JOptionPane message");
   }

   public JOptionPane(Object var1) {
      this(var1, -1);
   }

   public JOptionPane(Object var1, int var2) {
      this(var1, var2, -1);
   }

   public JOptionPane(Object var1, int var2, int var3) {
      this(var1, var2, var3, (Icon)null);
   }

   public JOptionPane(Object var1, int var2, int var3, Icon var4) {
      this(var1, var2, var3, var4, (Object[])null);
   }

   public JOptionPane(Object var1, int var2, int var3, Icon var4, Object[] var5) {
      this(var1, var2, var3, var4, var5, (Object)null);
   }

   public JOptionPane(Object var1, int var2, int var3, Icon var4, Object[] var5, Object var6) {
      this.message = var1;
      this.options = var5;
      this.initialValue = var6;
      this.icon = var4;
      this.setMessageType(var2);
      this.setOptionType(var3);
      this.value = "uninitializedValue";
      this.inputValue = "uninitializedValue";
      this.updateUI();
   }

   private void adjustPreferredSize() {
      Dimension var1 = ((JComponent)this).getPreferredSize();
      var1.width += 5;
      var1.height += 2;
      ((JComponent)this).setPreferredSize(var1);
   }

   // $FF: synthetic method
   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(((Throwable)var2).getMessage());
      }
   }

   public JDialog createDialog(Component var1, String var2) {
      Frame var3 = getFrameForComponent(var1);
      String var5 = System.getProperty("os.name");
      boolean var6 = var5 != null && var5.indexOf("Solaris") != -1;
      JDialog var4;
      if (var6) {
         var4 = SwingUtilities.getRecycledModalDialog(var3, var2);
      } else {
         var4 = new JDialog(var3, var2, true);
      }

      Container var7 = var4.getContentPane();
      var7.setLayout(new BorderLayout());
      var7.add(this, "Center");
      ((Window)var4).pack();
      var4.setLocationRelativeTo(var1);
      ((Window)var4).addWindowListener(new 1(this));
      ((JComponent)this).addPropertyChangeListener(new 2(var4, var6, this));
      return var4;
   }

   public JInternalFrame createInternalFrame(Component var1, String var2) {
      Object var3 = getDesktopPaneForComponent(var1);
      if (var3 != null || var1 != null && (var3 = var1.getParent()) != null) {
         JInternalFrame var4 = new JInternalFrame(var2, true, false, false, false);
         ((JComponent)this).addPropertyChangeListener(new 3(var4, this));
         var4.getContentPane().add(this, "Center");
         if (var3 instanceof JDesktopPane) {
            ((Container)var3).add(var4, JLayeredPane.MODAL_LAYER);
         } else {
            ((Container)var3).add(var4, "Center");
         }

         Dimension var5 = ((JComponent)var4).getPreferredSize();
         Dimension var6 = ((Component)var3).getSize();
         ((Component)var4).setBounds((var6.width - var5.width) / 2, (var6.height - var5.height) / 2, var5.width, var5.height);
         ((Container)var3).validate();

         try {
            var4.setSelected(true);
         } catch (PropertyVetoException var7) {
         }

         return var4;
      } else {
         throw new RuntimeException("JOptionPane: parentComponent does not have a valid parent");
      }
   }

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleJOptionPane(this);
      }

      return super.accessibleContext;
   }

   public static JDesktopPane getDesktopPaneForComponent(Component var0) {
      if (var0 == null) {
         return null;
      } else {
         return var0 instanceof JDesktopPane ? (JDesktopPane)var0 : getDesktopPaneForComponent(var0.getParent());
      }
   }

   public static Frame getFrameForComponent(Component var0) {
      if (var0 == null) {
         return getRootFrame();
      } else {
         return var0 instanceof Frame ? (Frame)var0 : getFrameForComponent(var0.getParent());
      }
   }

   public Icon getIcon() {
      return this.icon;
   }

   public Object getInitialSelectionValue() {
      return this.initialSelectionValue;
   }

   public Object getInitialValue() {
      return this.initialValue;
   }

   public Object getInputValue() {
      return this.inputValue;
   }

   public int getMaxCharactersPerLineCount() {
      return Integer.MAX_VALUE;
   }

   public Object getMessage() {
      return this.message;
   }

   public int getMessageType() {
      return this.messageType;
   }

   public int getOptionType() {
      return this.optionType;
   }

   public Object[] getOptions() {
      if (this.options != null) {
         int var1 = this.options.length;
         Object[] var2 = new Object[var1];
         System.arraycopy(this.options, 0, var2, 0, var1);
         return var2;
      } else {
         return this.options;
      }
   }

   public static Frame getRootFrame() {
      Frame var0 = (Frame)SwingUtilities.appContextGet(sharedFrameKey);
      if (var0 == null) {
         var0 = SwingUtilities.getSharedOwnerFrame();
         SwingUtilities.appContextPut(sharedFrameKey, var0);
      }

      return var0;
   }

   public Object[] getSelectionValues() {
      return this.selectionValues;
   }

   public OptionPaneUI getUI() {
      return (OptionPaneUI)super.ui;
   }

   public String getUIClassID() {
      return "OptionPaneUI";
   }

   public Object getValue() {
      return this.value;
   }

   public boolean getWantsInput() {
      return this.wantsInput;
   }

   protected String paramString() {
      String var1 = this.icon != null ? this.icon.toString() : "";
      String var2 = this.initialValue != null ? this.initialValue.toString() : "";
      String var3 = this.message != null ? this.message.toString() : "";
      String var4;
      if (this.messageType == 0) {
         var4 = "ERROR_MESSAGE";
      } else if (this.messageType == 1) {
         var4 = "INFORMATION_MESSAGE";
      } else if (this.messageType == 2) {
         var4 = "WARNING_MESSAGE";
      } else if (this.messageType == 3) {
         var4 = "QUESTION_MESSAGE";
      } else if (this.messageType == -1) {
         var4 = "PLAIN_MESSAGE";
      } else {
         var4 = "";
      }

      String var5;
      if (this.optionType == -1) {
         var5 = "DEFAULT_OPTION";
      } else if (this.optionType == 0) {
         var5 = "YES_NO_OPTION";
      } else if (this.optionType == 1) {
         var5 = "YES_NO_CANCEL_OPTION";
      } else if (this.optionType == 2) {
         var5 = "OK_CANCEL_OPTION";
      } else {
         var5 = "";
      }

      String var6 = this.wantsInput ? "true" : "false";
      return super.paramString() + ",icon=" + var1 + ",initialValue=" + var2 + ",message=" + var3 + ",messageType=" + var4 + ",optionType=" + var5 + ",wantsInput=" + var6;
   }

   private void readObject(ObjectInputStream var1) throws IOException, ClassNotFoundException {
      var1.defaultReadObject();
      Vector var2 = (Vector)var1.readObject();
      int var3 = 0;
      int var4 = var2.size();
      if (var3 < var4 && var2.elementAt(var3).equals("icon")) {
         ++var3;
         this.icon = (Icon)var2.elementAt(var3);
         ++var3;
      }

      if (var3 < var4 && var2.elementAt(var3).equals("message")) {
         ++var3;
         this.message = var2.elementAt(var3);
         ++var3;
      }

      if (var3 < var4 && var2.elementAt(var3).equals("options")) {
         ++var3;
         this.options = var2.elementAt(var3);
         ++var3;
      }

      if (var3 < var4 && var2.elementAt(var3).equals("initialValue")) {
         ++var3;
         this.initialValue = var2.elementAt(var3);
         ++var3;
      }

      if (var3 < var4 && var2.elementAt(var3).equals("value")) {
         ++var3;
         this.value = var2.elementAt(var3);
         ++var3;
      }

      if (var3 < var4 && var2.elementAt(var3).equals("selectionValues")) {
         ++var3;
         this.selectionValues = var2.elementAt(var3);
         ++var3;
      }

      if (var3 < var4 && var2.elementAt(var3).equals("inputValue")) {
         ++var3;
         this.inputValue = var2.elementAt(var3);
         ++var3;
      }

      if (var3 < var4 && var2.elementAt(var3).equals("initialSelectionValue")) {
         ++var3;
         this.initialSelectionValue = var2.elementAt(var3);
         ++var3;
      }

      if (super.ui != null && this.getUIClassID().equals("OptionPaneUI")) {
         super.ui.installUI(this);
      }

   }

   public void selectInitialValue() {
      OptionPaneUI var1 = this.getUI();
      if (var1 != null) {
         var1.selectInitialValue(this);
      }

   }

   public void setIcon(Icon var1) {
      Icon var2 = this.icon;
      this.icon = var1;
      ((JComponent)this).firePropertyChange("icon", var2, this.icon);
   }

   public void setInitialSelectionValue(Object var1) {
      Object var2 = this.initialSelectionValue;
      this.initialSelectionValue = var1;
      ((JComponent)this).firePropertyChange("initialSelectionValue", var2, var1);
   }

   public void setInitialValue(Object var1) {
      Object var2 = this.initialValue;
      this.initialValue = var1;
      ((JComponent)this).firePropertyChange("initialValue", var2, this.initialValue);
   }

   public void setInputValue(Object var1) {
      Object var2 = this.inputValue;
      this.inputValue = var1;
      ((JComponent)this).firePropertyChange("inputValue", var2, var1);
   }

   public void setMessage(Object var1) {
      Object var2 = this.message;
      this.message = var1;
      ((JComponent)this).firePropertyChange("message", var2, this.message);
   }

   public void setMessageType(int var1) {
      if (var1 != 0 && var1 != 1 && var1 != 2 && var1 != 3 && var1 != -1) {
         throw new RuntimeException("JOptionPane: type must be one of JOptionPane.ERROR_MESSAGE, JOptionPane.INFORMATION_MESSAGE, JOptionPane.WARNING_MESSAGE, JOptionPane.QUESTION_MESSAGE or JOptionPane.PLAIN_MESSAGE");
      } else {
         int var2 = this.messageType;
         this.messageType = var1;
         ((JComponent)this).firePropertyChange("messageType", var2, this.messageType);
      }
   }

   public void setOptionType(int var1) {
      if (var1 != -1 && var1 != 0 && var1 != 1 && var1 != 2) {
         throw new RuntimeException("JOptionPane: option type must be one of JOptionPane.DEFAULT_OPTION, JOptionPane.YES_NO_OPTION, JOptionPane.YES_NO_CANCEL_OPTION or JOptionPane.OK_CANCEL_OPTION");
      } else {
         int var2 = this.optionType;
         this.optionType = var1;
         ((JComponent)this).firePropertyChange("optionType", var2, this.optionType);
      }
   }

   public void setOptions(Object[] var1) {
      Object[] var2 = this.options;
      this.options = var1;
      ((JComponent)this).firePropertyChange("options", var2, this.options);
   }

   public static void setRootFrame(Frame var0) {
      if (var0 != null) {
         SwingUtilities.appContextPut(sharedFrameKey, var0);
      } else {
         SwingUtilities.appContextRemove(sharedFrameKey);
      }

   }

   public void setSelectionValues(Object[] var1) {
      Object[] var2 = this.selectionValues;
      this.selectionValues = var1;
      ((JComponent)this).firePropertyChange("selectionValues", var2, var1);
      if (this.selectionValues != null) {
         this.setWantsInput(true);
      }

   }

   public void setUI(OptionPaneUI var1) {
      if ((OptionPaneUI)super.ui != var1) {
         super.setUI(var1);
         ((Container)this).invalidate();
      }

   }

   public void setValue(Object var1) {
      Object var2 = this.value;
      this.value = var1;
      ((JComponent)this).firePropertyChange("value", var2, this.value);
   }

   public void setWantsInput(boolean var1) {
      boolean var2 = this.wantsInput;
      this.wantsInput = var1;
      ((JComponent)this).firePropertyChange("wantsInput", var2, var1);
   }

   public static int showConfirmDialog(Component var0, Object var1) {
      return showConfirmDialog(var0, var1, "Select an Option", 1);
   }

   public static int showConfirmDialog(Component var0, Object var1, String var2, int var3) {
      return showConfirmDialog(var0, var1, var2, var3, 3);
   }

   public static int showConfirmDialog(Component var0, Object var1, String var2, int var3, int var4) {
      return showConfirmDialog(var0, var1, var2, var3, var4, (Icon)null);
   }

   public static int showConfirmDialog(Component var0, Object var1, String var2, int var3, int var4, Icon var5) {
      return showOptionDialog(var0, var1, var2, var3, var4, var5, (Object[])null, (Object)null);
   }

   public static String showInputDialog(Component var0, Object var1) {
      return showInputDialog(var0, var1, "Input", 3);
   }

   public static String showInputDialog(Component var0, Object var1, String var2, int var3) {
      return (String)showInputDialog(var0, var1, var2, var3, (Icon)null, (Object[])null, (Object)null);
   }

   public static Object showInputDialog(Component var0, Object var1, String var2, int var3, Icon var4, Object[] var5, Object var6) {
      JOptionPane var7 = new JOptionPane(var1, var3, 2, var4, (Object[])null, (Object)null);
      var7.adjustPreferredSize();
      var7.setWantsInput(true);
      var7.setSelectionValues(var5);
      var7.setInitialSelectionValue(var6);
      JDialog var8 = var7.createDialog(var0, var2);
      var7.selectInitialValue();
      ((Dialog)var8).show();
      Object var9 = var7.getInputValue();
      return var9 == "uninitializedValue" ? null : var9;
   }

   public static String showInputDialog(Object var0) {
      return showInputDialog((Component)null, var0);
   }

   public static int showInternalConfirmDialog(Component var0, Object var1) {
      return showInternalConfirmDialog(var0, var1, "Select an Option", 1);
   }

   public static int showInternalConfirmDialog(Component var0, Object var1, String var2, int var3) {
      return showInternalConfirmDialog(var0, var1, var2, var3, 3);
   }

   public static int showInternalConfirmDialog(Component var0, Object var1, String var2, int var3, int var4) {
      return showInternalConfirmDialog(var0, var1, var2, var3, var4, (Icon)null);
   }

   public static int showInternalConfirmDialog(Component var0, Object var1, String var2, int var3, int var4, Icon var5) {
      return showInternalOptionDialog(var0, var1, var2, var3, var4, var5, (Object[])null, (Object)null);
   }

   public static String showInternalInputDialog(Component var0, Object var1) {
      return showInternalInputDialog(var0, var1, "Input", 3);
   }

   public static String showInternalInputDialog(Component var0, Object var1, String var2, int var3) {
      return (String)showInternalInputDialog(var0, var1, var2, var3, (Icon)null, (Object[])null, (Object)null);
   }

   public static Object showInternalInputDialog(Component var0, Object var1, String var2, int var3, Icon var4, Object[] var5, Object var6) {
      JOptionPane var7 = new JOptionPane(var1, var3, 2, var4, (Object[])null, (Object)null);
      var7.setWantsInput(true);
      var7.setSelectionValues(var5);
      var7.setInitialSelectionValue(var6);
      JInternalFrame var8 = var7.createInternalFrame(var0, var2);
      var7.selectInitialValue();
      var8.startModal();
      Object var9 = var7.getInputValue();
      return var9 == "uninitializedValue" ? null : (String)var9;
   }

   public static void showInternalMessageDialog(Component var0, Object var1) {
      showInternalMessageDialog(var0, var1, "Message", 1);
   }

   public static void showInternalMessageDialog(Component var0, Object var1, String var2, int var3) {
      showInternalMessageDialog(var0, var1, var2, var3, (Icon)null);
   }

   public static void showInternalMessageDialog(Component var0, Object var1, String var2, int var3, Icon var4) {
      showInternalOptionDialog(var0, var1, var2, -1, var3, var4, (Object[])null, (Object)null);
   }

   public static int showInternalOptionDialog(Component var0, Object var1, String var2, int var3, int var4, Icon var5, Object[] var6, Object var7) {
      JOptionPane var8 = new JOptionPane(var1, var4, var3, var5, var6, var7);
      var8.setInitialValue(var7);
      JInternalFrame var9 = var8.createInternalFrame(var0, var2);
      var8.selectInitialValue();
      var9.startModal();
      Object var10 = var8.getValue();
      if (var10 == null) {
         return -1;
      } else if (var6 == null) {
         return var10 instanceof Integer ? (Integer)var10 : -1;
      } else {
         int var11 = 0;

         for(int var12 = var6.length; var11 < var12; ++var11) {
            if (var6[var11].equals(var10)) {
               return var11;
            }
         }

         return -1;
      }
   }

   public static void showMessageDialog(Component var0, Object var1) {
      showMessageDialog(var0, var1, "Message", 1);
   }

   public static void showMessageDialog(Component var0, Object var1, String var2, int var3) {
      showMessageDialog(var0, var1, var2, var3, (Icon)null);
   }

   public static void showMessageDialog(Component var0, Object var1, String var2, int var3, Icon var4) {
      showOptionDialog(var0, var1, var2, -1, var3, var4, (Object[])null, (Object)null);
   }

   public static int showOptionDialog(Component var0, Object var1, String var2, int var3, int var4, Icon var5, Object[] var6, Object var7) {
      JOptionPane var8 = new JOptionPane(var1, var4, var3, var5, var6, var7);
      var8.adjustPreferredSize();
      var8.setInitialValue(var7);
      JDialog var9 = var8.createDialog(var0, var2);
      var8.selectInitialValue();
      ((Dialog)var9).show();
      Object var10 = var8.getValue();
      if (var10 == null) {
         return -1;
      } else if (var6 == null) {
         return var10 instanceof Integer ? (Integer)var10 : -1;
      } else {
         int var11 = 0;

         for(int var12 = var6.length; var11 < var12; ++var11) {
            if (var6[var11].equals(var10)) {
               return var11;
            }
         }

         return -1;
      }
   }

   public void updateUI() {
      this.setUI((OptionPaneUI)UIManager.getUI(this));
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      Vector var2 = new Vector();
      var1.defaultWriteObject();
      if (this.icon != null && this.icon instanceof Serializable) {
         var2.addElement("icon");
         var2.addElement(this.icon);
      }

      if (this.message != null && this.message instanceof Serializable) {
         var2.addElement("message");
         var2.addElement(this.message);
      }

      if (this.options != null) {
         Vector var3 = new Vector();
         int var4 = 0;

         for(int var5 = this.options.length; var4 < var5; ++var4) {
            if (this.options[var4] instanceof Serializable) {
               var3.addElement(this.options[var4]);
            }
         }

         if (var3.size() > 0) {
            int var6 = var3.size();
            Object[] var7 = new Object[var6];
            var3.copyInto(var7);
            var2.addElement("options");
            var2.addElement(var7);
         }
      }

      if (this.initialValue != null && this.initialValue instanceof Serializable) {
         var2.addElement("initialValue");
         var2.addElement(this.initialValue);
      }

      if (this.value != null && this.value instanceof Serializable) {
         var2.addElement("value");
         var2.addElement(this.value);
      }

      if (this.selectionValues != null) {
         boolean var8 = true;
         int var9 = 0;

         for(int var10 = this.selectionValues.length; var9 < var10; ++var9) {
            if (this.selectionValues[var9] != null && !(this.selectionValues[var9] instanceof Serializable)) {
               var8 = false;
               break;
            }
         }

         if (var8) {
            var2.addElement("selectionValues");
            var2.addElement(this.selectionValues);
         }
      }

      if (this.inputValue != null && this.inputValue instanceof Serializable) {
         var2.addElement("inputValue");
         var2.addElement(this.inputValue);
      }

      if (this.initialSelectionValue != null && this.initialSelectionValue instanceof Serializable) {
         var2.addElement("initialSelectionValue");
         var2.addElement(this.initialSelectionValue);
      }

      var1.writeObject(var2);
   }
}
