package javax.swing;

import java.awt.Adjustable;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.event.AdjustmentEvent;
import java.awt.event.AdjustmentListener;
import java.io.IOException;
import java.io.ObjectOutputStream;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;
import javax.accessibility.AccessibleState;
import javax.swing.event.ChangeListener;
import javax.swing.plaf.ScrollBarUI;

public class JScrollBar extends JComponent implements Adjustable, Accessible {
   private static final String uiClassID = "ScrollBarUI";
   private ChangeListener fwdAdjustmentEvents;
   protected BoundedRangeModel model;
   protected int orientation;
   protected int unitIncrement;
   protected int blockIncrement;
   // $FF: synthetic field
   static Class class$java$awt$event$AdjustmentListener;

   public JScrollBar() {
      this(1);
   }

   public JScrollBar(int var1) {
      this(var1, 0, 10, 0, 100);
   }

   public JScrollBar(int var1, int var2, int var3, int var4, int var5) {
      this.fwdAdjustmentEvents = new ModelListener(this);
      this.checkOrientation(var1);
      this.unitIncrement = 1;
      this.blockIncrement = var3 == 0 ? 1 : var3;
      this.orientation = var1;
      this.model = new DefaultBoundedRangeModel(var2, var3, var4, var5);
      this.model.addChangeListener(this.fwdAdjustmentEvents);
      this.updateUI();
   }

   public void addAdjustmentListener(AdjustmentListener var1) {
      super.listenerList.add(class$java$awt$event$AdjustmentListener != null ? class$java$awt$event$AdjustmentListener : (class$java$awt$event$AdjustmentListener = class$("java.awt.event.AdjustmentListener")), var1);
   }

   private void checkOrientation(int var1) {
      switch (var1) {
         case 0:
         case 1:
            return;
         default:
            throw new IllegalArgumentException("orientation must be one of: VERTICAL, HORIZONTAL");
      }
   }

   // $FF: synthetic method
   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(((Throwable)var2).getMessage());
      }
   }

   protected void fireAdjustmentValueChanged(int var1, int var2, int var3) {
      Object[] var4 = super.listenerList.getListenerList();
      AdjustmentEvent var5 = null;

      for(int var6 = var4.length - 2; var6 >= 0; var6 -= 2) {
         if (var4[var6] == (class$java$awt$event$AdjustmentListener != null ? class$java$awt$event$AdjustmentListener : (class$java$awt$event$AdjustmentListener = class$("java.awt.event.AdjustmentListener")))) {
            if (var5 == null) {
               var5 = new AdjustmentEvent(this, var1, var2, var3);
            }

            ((AdjustmentListener)var4[var6 + 1]).adjustmentValueChanged(var5);
         }
      }

   }

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleJScrollBar(this);
      }

      return super.accessibleContext;
   }

   public int getBlockIncrement() {
      return this.blockIncrement;
   }

   public int getBlockIncrement(int var1) {
      return this.blockIncrement;
   }

   public int getMaximum() {
      return this.getModel().getMaximum();
   }

   public Dimension getMaximumSize() {
      Dimension var1 = ((JComponent)this).getPreferredSize();
      return this.getOrientation() == 1 ? new Dimension(var1.width, 32767) : new Dimension(32767, var1.height);
   }

   public int getMinimum() {
      return this.getModel().getMinimum();
   }

   public Dimension getMinimumSize() {
      Dimension var1 = ((JComponent)this).getPreferredSize();
      return this.orientation == 1 ? new Dimension(var1.width, 5) : new Dimension(5, var1.height);
   }

   public BoundedRangeModel getModel() {
      return this.model;
   }

   public int getOrientation() {
      return this.orientation;
   }

   public ScrollBarUI getUI() {
      return (ScrollBarUI)super.ui;
   }

   public String getUIClassID() {
      return "ScrollBarUI";
   }

   public int getUnitIncrement() {
      return this.unitIncrement;
   }

   public int getUnitIncrement(int var1) {
      return this.unitIncrement;
   }

   public int getValue() {
      return this.getModel().getValue();
   }

   public boolean getValueIsAdjusting() {
      return this.getModel().getValueIsAdjusting();
   }

   public int getVisibleAmount() {
      return this.getModel().getExtent();
   }

   protected String paramString() {
      String var1 = this.orientation == 0 ? "HORIZONTAL" : "VERTICAL";
      return super.paramString() + ",blockIncrement=" + this.blockIncrement + ",orientation=" + var1 + ",unitIncrement=" + this.unitIncrement;
   }

   public void removeAdjustmentListener(AdjustmentListener var1) {
      super.listenerList.remove(class$java$awt$event$AdjustmentListener != null ? class$java$awt$event$AdjustmentListener : (class$java$awt$event$AdjustmentListener = class$("java.awt.event.AdjustmentListener")), var1);
   }

   public void setBlockIncrement(int var1) {
      int var2 = this.blockIncrement;
      this.blockIncrement = var1;
      ((JComponent)this).firePropertyChange("blockIncrement", var2, var1);
   }

   public void setEnabled(boolean var1) {
      super.setEnabled(var1);
      Component[] var2 = ((Container)this).getComponents();

      for(int var3 = 0; var3 < var2.length; ++var3) {
         var2[var3].setEnabled(var1);
      }

   }

   public void setMaximum(int var1) {
      this.getModel().setMaximum(var1);
   }

   public void setMinimum(int var1) {
      this.getModel().setMinimum(var1);
   }

   public void setModel(BoundedRangeModel var1) {
      Integer var2 = null;
      BoundedRangeModel var3 = this.model;
      if (this.model != null) {
         this.model.removeChangeListener(this.fwdAdjustmentEvents);
         var2 = new Integer(this.model.getValue());
      }

      this.model = var1;
      if (this.model != null) {
         this.model.addChangeListener(this.fwdAdjustmentEvents);
      }

      ((JComponent)this).firePropertyChange("model", var3, this.model);
      if (super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleValue", var2, new Integer(this.model.getValue()));
      }

   }

   public void setOrientation(int var1) {
      this.checkOrientation(var1);
      int var2 = this.orientation;
      this.orientation = var1;
      ((JComponent)this).firePropertyChange("orientation", var2, var1);
      if (var2 != var1 && super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleState", var2 == 1 ? AccessibleState.VERTICAL : AccessibleState.HORIZONTAL, var1 == 1 ? AccessibleState.VERTICAL : AccessibleState.HORIZONTAL);
      }

      if (var1 != var2) {
         ((JComponent)this).revalidate();
      }

   }

   public void setUnitIncrement(int var1) {
      int var2 = this.unitIncrement;
      this.unitIncrement = var1;
      ((JComponent)this).firePropertyChange("unitIncrement", var2, var1);
   }

   public void setValue(int var1) {
      BoundedRangeModel var2 = this.getModel();
      int var3 = var2.getValue();
      var2.setValue(var1);
      if (super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleValue", new Integer(var3), new Integer(var2.getValue()));
      }

   }

   public void setValueIsAdjusting(boolean var1) {
      BoundedRangeModel var2 = this.getModel();
      boolean var3 = var2.getValueIsAdjusting();
      var2.setValueIsAdjusting(var1);
      if (var3 != var1 && super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleState", var3 ? AccessibleState.BUSY : null, var1 ? AccessibleState.BUSY : null);
      }

   }

   public void setValues(int var1, int var2, int var3, int var4) {
      BoundedRangeModel var5 = this.getModel();
      int var6 = var5.getValue();
      var5.setRangeProperties(var1, var2, var3, var4, var5.getValueIsAdjusting());
      if (super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleValue", new Integer(var6), new Integer(var5.getValue()));
      }

   }

   public void setVisibleAmount(int var1) {
      this.getModel().setExtent(var1);
   }

   public void updateUI() {
      ((JComponent)this).setUI((ScrollBarUI)UIManager.getUI(this));
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      if (super.ui != null && this.getUIClassID().equals("ScrollBarUI")) {
         super.ui.installUI(this);
      }

   }
}
