package javax.swing;

import java.awt.Component;
import java.beans.PropertyChangeListener;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.util.Dictionary;
import java.util.Enumeration;
import java.util.Hashtable;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;
import javax.accessibility.AccessibleState;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.plaf.SliderUI;

public class JSlider extends JComponent implements SwingConstants, Accessible {
   private static final String uiClassID = "SliderUI";
   private boolean paintTicks;
   private boolean paintTrack;
   private boolean paintLabels;
   private boolean isInverted;
   protected BoundedRangeModel sliderModel;
   protected int majorTickSpacing;
   protected int minorTickSpacing;
   protected boolean snapToTicks;
   boolean snapToValue;
   protected int orientation;
   private Dictionary labelTable;
   protected ChangeListener changeListener;
   protected transient ChangeEvent changeEvent;
   // $FF: synthetic field
   static Class class$javax$swing$event$ChangeListener;

   public JSlider() {
      this(0, 0, 100, 50);
   }

   public JSlider(int var1) {
      this(var1, 0, 100, 50);
   }

   public JSlider(int var1, int var2) {
      this(0, var1, var2, 50);
   }

   public JSlider(int var1, int var2, int var3) {
      this(0, var1, var2, var3);
   }

   public JSlider(int var1, int var2, int var3, int var4) {
      this.paintTicks = false;
      this.paintTrack = true;
      this.paintLabels = false;
      this.isInverted = false;
      this.snapToTicks = false;
      this.snapToValue = true;
      this.changeListener = this.createChangeListener();
      this.changeEvent = null;
      this.checkOrientation(var1);
      this.orientation = var1;
      this.sliderModel = new DefaultBoundedRangeModel(var4, 0, var2, var3);
      this.sliderModel.addChangeListener(this.changeListener);
      this.updateUI();
   }

   public JSlider(BoundedRangeModel var1) {
      this.paintTicks = false;
      this.paintTrack = true;
      this.paintLabels = false;
      this.isInverted = false;
      this.snapToTicks = false;
      this.snapToValue = true;
      this.changeListener = this.createChangeListener();
      this.changeEvent = null;
      this.orientation = 0;
      this.setModel(var1);
      this.sliderModel.addChangeListener(this.changeListener);
      this.updateUI();
   }

   public void addChangeListener(ChangeListener var1) {
      super.listenerList.add(class$javax$swing$event$ChangeListener != null ? class$javax$swing$event$ChangeListener : (class$javax$swing$event$ChangeListener = class$("javax.swing.event.ChangeListener")), var1);
   }

   private void checkOrientation(int var1) {
      switch (var1) {
         case 0:
         case 1:
            return;
         default:
            throw new IllegalArgumentException("orientation must be one of: VERTICAL, HORIZONTAL");
      }
   }

   // $FF: synthetic method
   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(((Throwable)var2).getMessage());
      }
   }

   protected ChangeListener createChangeListener() {
      return new ModelListener(this);
   }

   public Hashtable createStandardLabels(int var1) {
      return this.createStandardLabels(var1, this.getMinimum());
   }

   public Hashtable createStandardLabels(int var1, int var2) {
      if (var2 <= this.getMaximum() && var2 >= this.getMinimum()) {
         if (var1 <= 0) {
            throw new IllegalArgumentException("Label incremement must be > 0");
         } else {
            1.SmartHashtable var3 = new 1.SmartHashtable(this, var1, var2);
            if (this.getLabelTable() != null && this.getLabelTable() instanceof PropertyChangeListener) {
               ((JComponent)this).removePropertyChangeListener((PropertyChangeListener)this.getLabelTable());
            }

            ((JComponent)this).addPropertyChangeListener(var3);
            return var3;
         }
      } else {
         throw new IllegalArgumentException("Slider label start point out of range.");
      }
   }

   protected void fireStateChanged() {
      Object[] var1 = super.listenerList.getListenerList();

      for(int var2 = var1.length - 2; var2 >= 0; var2 -= 2) {
         if (var1[var2] == (class$javax$swing$event$ChangeListener != null ? class$javax$swing$event$ChangeListener : (class$javax$swing$event$ChangeListener = class$("javax.swing.event.ChangeListener")))) {
            if (this.changeEvent == null) {
               this.changeEvent = new ChangeEvent(this);
            }

            ((ChangeListener)var1[var2 + 1]).stateChanged(this.changeEvent);
         }
      }

   }

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleJSlider(this);
      }

      return super.accessibleContext;
   }

   public int getExtent() {
      return this.getModel().getExtent();
   }

   public boolean getInverted() {
      return this.isInverted;
   }

   public Dictionary getLabelTable() {
      return this.labelTable;
   }

   public int getMajorTickSpacing() {
      return this.majorTickSpacing;
   }

   public int getMaximum() {
      return this.getModel().getMaximum();
   }

   public int getMinimum() {
      return this.getModel().getMinimum();
   }

   public int getMinorTickSpacing() {
      return this.minorTickSpacing;
   }

   public BoundedRangeModel getModel() {
      return this.sliderModel;
   }

   public int getOrientation() {
      return this.orientation;
   }

   public boolean getPaintLabels() {
      return this.paintLabels;
   }

   public boolean getPaintTicks() {
      return this.paintTicks;
   }

   public boolean getPaintTrack() {
      return this.paintTrack;
   }

   public boolean getSnapToTicks() {
      return this.snapToTicks;
   }

   boolean getSnapToValue() {
      return this.snapToValue;
   }

   public SliderUI getUI() {
      return (SliderUI)super.ui;
   }

   public String getUIClassID() {
      return "SliderUI";
   }

   public int getValue() {
      return this.getModel().getValue();
   }

   public boolean getValueIsAdjusting() {
      return this.getModel().getValueIsAdjusting();
   }

   protected String paramString() {
      String var1 = this.paintTicks ? "true" : "false";
      String var2 = this.paintTrack ? "true" : "false";
      String var3 = this.paintLabels ? "true" : "false";
      String var4 = this.isInverted ? "true" : "false";
      String var5 = this.snapToTicks ? "true" : "false";
      String var6 = this.snapToValue ? "true" : "false";
      String var7 = this.orientation == 0 ? "HORIZONTAL" : "VERTICAL";
      return super.paramString() + ",isInverted=" + var4 + ",majorTickSpacing=" + this.majorTickSpacing + ",minorTickSpacing=" + this.minorTickSpacing + ",orientation=" + var7 + ",paintLabels=" + var3 + ",paintTicks=" + var1 + ",paintTrack=" + var2 + ",snapToTicks=" + var5 + ",snapToValue=" + var6;
   }

   public void removeChangeListener(ChangeListener var1) {
      super.listenerList.remove(class$javax$swing$event$ChangeListener != null ? class$javax$swing$event$ChangeListener : (class$javax$swing$event$ChangeListener = class$("javax.swing.event.ChangeListener")), var1);
   }

   public void setExtent(int var1) {
      this.getModel().setExtent(var1);
   }

   public void setInverted(boolean var1) {
      boolean var2 = this.isInverted;
      this.isInverted = var1;
      ((JComponent)this).firePropertyChange("inverted", var2, this.isInverted);
      if (var1 != var2) {
         ((Component)this).repaint();
      }

   }

   public void setLabelTable(Dictionary var1) {
      Dictionary var2 = this.labelTable;
      this.labelTable = var1;
      this.updateLabelUIs();
      ((JComponent)this).firePropertyChange("labelTable", var2, this.labelTable);
      if (var1 != var2) {
         ((JComponent)this).revalidate();
         ((Component)this).repaint();
      }

   }

   public void setMajorTickSpacing(int var1) {
      int var2 = this.majorTickSpacing;
      this.majorTickSpacing = var1;
      if (this.labelTable == null && this.getMajorTickSpacing() > 0 && this.getPaintLabels()) {
         this.setLabelTable(this.createStandardLabels(this.getMajorTickSpacing()));
      }

      ((JComponent)this).firePropertyChange("majorTickSpacing", var2, this.majorTickSpacing);
      if (this.majorTickSpacing != var2 && this.getPaintTicks()) {
         ((Component)this).repaint();
      }

   }

   public void setMaximum(int var1) {
      int var2 = this.getModel().getMaximum();
      this.getModel().setMaximum(var1);
      ((JComponent)this).firePropertyChange("maximum", new Integer(var2), new Integer(var1));
   }

   public void setMinimum(int var1) {
      int var2 = this.getModel().getMinimum();
      this.getModel().setMinimum(var1);
      ((JComponent)this).firePropertyChange("minimum", new Integer(var2), new Integer(var1));
   }

   public void setMinorTickSpacing(int var1) {
      int var2 = this.minorTickSpacing;
      this.minorTickSpacing = var1;
      ((JComponent)this).firePropertyChange("minorTickSpacing", var2, this.minorTickSpacing);
      if (this.minorTickSpacing != var2 && this.getPaintTicks()) {
         ((Component)this).repaint();
      }

   }

   public void setModel(BoundedRangeModel var1) {
      BoundedRangeModel var2 = this.getModel();
      if (var2 != null) {
         var2.removeChangeListener(this.changeListener);
      }

      this.sliderModel = var1;
      if (var1 != null) {
         var1.addChangeListener(this.changeListener);
         if (super.accessibleContext != null) {
            super.accessibleContext.firePropertyChange("AccessibleValue", var2 == null ? null : new Integer(var2.getValue()), var1 == null ? null : new Integer(var1.getValue()));
         }
      }

      ((JComponent)this).firePropertyChange("model", var2, this.sliderModel);
   }

   public void setOrientation(int var1) {
      this.checkOrientation(var1);
      int var2 = this.orientation;
      this.orientation = var1;
      ((JComponent)this).firePropertyChange("orientation", var2, var1);
      if (var2 != var1 && super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleState", var2 == 1 ? AccessibleState.VERTICAL : AccessibleState.HORIZONTAL, var1 == 1 ? AccessibleState.VERTICAL : AccessibleState.HORIZONTAL);
      }

      if (var1 != var2) {
         ((JComponent)this).revalidate();
      }

   }

   public void setPaintLabels(boolean var1) {
      boolean var2 = this.paintLabels;
      this.paintLabels = var1;
      if (this.labelTable == null && this.getMajorTickSpacing() > 0) {
         this.setLabelTable(this.createStandardLabels(this.getMajorTickSpacing()));
      }

      ((JComponent)this).firePropertyChange("paintLabels", var2, this.paintLabels);
      if (this.paintLabels != var2) {
         ((JComponent)this).revalidate();
         ((Component)this).repaint();
      }

   }

   public void setPaintTicks(boolean var1) {
      boolean var2 = this.paintTicks;
      this.paintTicks = var1;
      ((JComponent)this).firePropertyChange("paintTicks", var2, this.paintTicks);
      if (this.paintTicks != var2) {
         ((JComponent)this).revalidate();
         ((Component)this).repaint();
      }

   }

   public void setPaintTrack(boolean var1) {
      boolean var2 = this.paintTrack;
      this.paintTrack = var1;
      ((JComponent)this).firePropertyChange("paintTrack", var2, this.paintTrack);
      if (this.paintTrack != var2) {
         ((Component)this).repaint();
      }

   }

   public void setSnapToTicks(boolean var1) {
      boolean var2 = this.snapToTicks;
      this.snapToTicks = var1;
      ((JComponent)this).firePropertyChange("snapToTicks", var2, this.snapToTicks);
   }

   void setSnapToValue(boolean var1) {
      boolean var2 = this.snapToValue;
      this.snapToValue = var1;
      ((JComponent)this).firePropertyChange("snapToValue", var2, this.snapToValue);
   }

   public void setUI(SliderUI var1) {
      super.setUI(var1);
   }

   public void setValue(int var1) {
      BoundedRangeModel var2 = this.getModel();
      int var3 = var2.getValue();
      var2.setValue(var1);
      if (super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleValue", new Integer(var3), new Integer(var2.getValue()));
      }

   }

   public void setValueIsAdjusting(boolean var1) {
      BoundedRangeModel var2 = this.getModel();
      boolean var3 = var2.getValueIsAdjusting();
      var2.setValueIsAdjusting(var1);
      if (var3 != var1 && super.accessibleContext != null) {
         super.accessibleContext.firePropertyChange("AccessibleState", var3 ? AccessibleState.BUSY : null, var1 ? AccessibleState.BUSY : null);
      }

   }

   protected void updateLabelUIs() {
      if (this.getLabelTable() != null) {
         Enumeration var1 = this.getLabelTable().keys();

         while(var1.hasMoreElements()) {
            Object var2 = this.getLabelTable().get(var1.nextElement());
            if (var2 instanceof JComponent) {
               JComponent var3 = (JComponent)var2;
               var3.updateUI();
               ((Component)var3).setSize(var3.getPreferredSize());
            }
         }

      }
   }

   public void updateUI() {
      this.updateLabelUIs();
      this.setUI((SliderUI)UIManager.getUI(this));
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      if (super.ui != null && this.getUIClassID().equals("SliderUI")) {
         super.ui.installUI(this);
      }

   }
}
