package javax.swing;

import java.awt.AWTEvent;
import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.LayoutManager;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.event.InputEvent;
import java.awt.event.MouseEvent;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.util.Enumeration;
import java.util.EventObject;
import java.util.Hashtable;
import java.util.Vector;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;
import javax.swing.border.Border;
import javax.swing.border.LineBorder;
import javax.swing.event.CellEditorListener;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import javax.swing.event.TableColumnModelEvent;
import javax.swing.event.TableColumnModelListener;
import javax.swing.event.TableModelEvent;
import javax.swing.event.TableModelListener;
import javax.swing.plaf.TableUI;
import javax.swing.plaf.UIResource;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.table.DefaultTableColumnModel;
import javax.swing.table.DefaultTableModel;
import javax.swing.table.JTableHeader;
import javax.swing.table.TableCellEditor;
import javax.swing.table.TableCellRenderer;
import javax.swing.table.TableColumn;
import javax.swing.table.TableColumnModel;
import javax.swing.table.TableModel;

public class JTable extends JComponent implements TableModelListener, Scrollable, TableColumnModelListener, ListSelectionListener, CellEditorListener, Accessible {
   private static final String uiClassID = "TableUI";
   public static final int AUTO_RESIZE_OFF = 0;
   public static final int AUTO_RESIZE_NEXT_COLUMN = 1;
   public static final int AUTO_RESIZE_SUBSEQUENT_COLUMNS = 2;
   public static final int AUTO_RESIZE_LAST_COLUMN = 3;
   public static final int AUTO_RESIZE_ALL_COLUMNS = 4;
   protected TableModel dataModel;
   protected TableColumnModel columnModel;
   protected ListSelectionModel selectionModel;
   protected JTableHeader tableHeader;
   protected int rowHeight;
   protected int rowMargin;
   protected Color gridColor;
   protected boolean showHorizontalLines;
   protected boolean showVerticalLines;
   protected int autoResizeMode;
   protected boolean autoCreateColumnsFromModel;
   protected Dimension preferredViewportSize;
   protected boolean rowSelectionAllowed;
   protected boolean cellSelectionEnabled;
   protected transient Component editorComp;
   protected transient TableCellEditor cellEditor;
   protected transient int editingColumn;
   protected transient int editingRow;
   protected transient Hashtable defaultRenderersByColumnClass;
   protected transient Hashtable defaultEditorsByColumnClass;
   protected Color selectionForeground;
   protected Color selectionBackground;
   // $FF: synthetic field
   static Class class$java$lang$Object;
   // $FF: synthetic field
   static Class class$java$lang$Number;
   // $FF: synthetic field
   static Class class$java$util$Date;
   // $FF: synthetic field
   static Class class$javax$swing$ImageIcon;
   // $FF: synthetic field
   static Class class$java$lang$Boolean;

   public JTable() {
      this((TableModel)null, (TableColumnModel)null, (ListSelectionModel)null);
   }

   public JTable(int var1, int var2) {
      this(new DefaultTableModel(var1, var2));
   }

   public JTable(Vector var1, Vector var2) {
      this(new 1(var2, var1));
   }

   public JTable(TableModel var1) {
      this(var1, (TableColumnModel)null, (ListSelectionModel)null);
   }

   public JTable(TableModel var1, TableColumnModel var2) {
      this(var1, var2, (ListSelectionModel)null);
   }

   public JTable(TableModel var1, TableColumnModel var2, ListSelectionModel var3) {
      ((Container)this).setLayout((LayoutManager)null);
      if (var2 == null) {
         var2 = this.createDefaultColumnModel();
         this.autoCreateColumnsFromModel = true;
      }

      this.setColumnModel(var2);
      if (var3 == null) {
         var3 = this.createDefaultSelectionModel();
      }

      this.setSelectionModel(var3);
      if (var1 == null) {
         var1 = this.createDefaultDataModel();
      }

      this.setModel(var1);
      this.initializeLocalVars();
      this.updateUI();
   }

   public JTable(Object[][] var1, Object[] var2) {
      this(new 2(var2, var1));
   }

   private void accommodateDelta(int var1, int var2) {
      int var3 = this.getColumnCount();
      int var4;
      int var5;
      switch (this.autoResizeMode) {
         case 1:
            var4 = var1 + 1;
            var5 = var4 + 1;
            break;
         case 2:
            var4 = var1 + 1;
            var5 = var3;
            break;
         case 3:
            var4 = var3 - 1;
            var5 = var4 + 1;
            break;
         case 4:
            var4 = 0;
            var5 = var3;
            break;
         default:
            return;
      }

      TableColumnModel var8 = this.columnModel;
      4 var9 = new 4(var8, var5, var4);
      int var10 = 0;

      for(int var11 = var4; var11 < var5; ++var11) {
         TableColumn var12 = this.columnModel.getColumn(var11);
         int var13 = var12.getWidth();
         var10 += var13;
      }

      this.adjustSizes((long)(var10 + var2), (Resizable3)var9, false);
      this.setWidthsFromPreferredWidths(true);
   }

   public void addColumn(TableColumn var1) {
      int var2 = var1.getModelIndex();
      String var3 = this.getModel().getColumnName(var2);
      if (var1.getHeaderValue() == null) {
         var1.setHeaderValue(var3);
      }

      this.getColumnModel().addColumn(var1);
   }

   public void addColumnSelectionInterval(int var1, int var2) {
      this.columnModel.getSelectionModel().addSelectionInterval(var1, var2);
   }

   public void addNotify() {
      super.addNotify();
      this.configureEnclosingScrollPane();
   }

   public void addRowSelectionInterval(int var1, int var2) {
      this.selectionModel.addSelectionInterval(var1, var2);
   }

   private void adjustSizes(long var1, Resizable2 var3, boolean var4) {
      long var5 = 0L;
      long var7 = 0L;

      for(int var9 = 0; var9 < var3.getElementCount(); ++var9) {
         var5 += (long)var3.getLowerBoundAt(var9);
         var7 += (long)var3.getUpperBoundAt(var9);
      }

      if (var4) {
         var1 = Math.min(Math.max(var5, var1), var7);
      }

      for(int var10 = 0; var10 < var3.getElementCount(); ++var10) {
         int var11 = var3.getLowerBoundAt(var10);
         int var12 = var3.getUpperBoundAt(var10);
         int var13;
         if (var5 == var7) {
            var13 = var11;
         } else {
            double var14 = (double)(var1 - var5) / (double)(var7 - var5);
            var13 = (int)Math.round((double)var11 + var14 * (double)(var12 - var11));
         }

         var3.setSizeAt(var13, var10);
         var1 -= (long)var13;
         var5 -= (long)var11;
         var7 -= (long)var12;
      }

   }

   private void adjustSizes(long var1, Resizable3 var3, boolean var4) {
      int var5 = var3.getElementCount();
      long var6 = 0L;

      for(int var8 = 0; var8 < var5; ++var8) {
         var6 += (long)var3.getMidPointAt(var8);
      }

      Object var9;
      if (var1 < var6 == (var4 ^ true)) {
         var9 = new 5(var3);
      } else {
         var9 = new 6(var3);
      }

      this.adjustSizes(var1, (Resizable2)var9, var4 ^ true);
   }

   // $FF: synthetic method
   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(((Throwable)var2).getMessage());
      }
   }

   public void clearSelection() {
      this.columnModel.getSelectionModel().clearSelection();
      this.selectionModel.clearSelection();
   }

   public void columnAdded(TableColumnModelEvent var1) {
      if (this.isEditing()) {
         this.removeEditor();
      }

      this.resizeAndRepaint();
   }

   public int columnAtPoint(Point var1) {
      return this.getColumnModel().getColumnIndexAtX(var1.x);
   }

   public void columnMarginChanged(ChangeEvent var1) {
      if (this.isEditing()) {
         this.removeEditor();
      }

      this.resizeAndRepaint();
   }

   public void columnMoved(TableColumnModelEvent var1) {
      if (this.isEditing()) {
         this.removeEditor();
      }

      ((Component)this).repaint();
   }

   public void columnRemoved(TableColumnModelEvent var1) {
      if (this.isEditing()) {
         this.removeEditor();
      }

      this.resizeAndRepaint();
   }

   public void columnSelectionChanged(ListSelectionEvent var1) {
      int var2 = var1.getFirstIndex();
      int var3 = var1.getLastIndex();
      if (var2 == -1 && var3 == -1) {
         ((Component)this).repaint();
      }

      Rectangle var4 = this.getCellRect(0, var2, false);
      Rectangle var5 = this.getCellRect(this.getRowCount(), var3, false);
      Rectangle var6 = var4.union(var5);
      ((Component)this).repaint(var6.x, var6.y, var6.width, var6.height);
   }

   protected void configureEnclosingScrollPane() {
      Container var1 = ((Component)this).getParent();
      if (var1 instanceof JViewport) {
         Container var2 = ((Component)var1).getParent();
         if (var2 instanceof JScrollPane) {
            JScrollPane var3 = (JScrollPane)var2;
            JViewport var4 = var3.getViewport();
            if (var4 == null || var4.getView() != this) {
               return;
            }

            var3.setColumnHeaderView(this.getTableHeader());
            var3.getViewport().setBackingStoreEnabled(true);
            Border var5 = ((JComponent)var3).getBorder();
            if (var5 == null || var5 instanceof UIResource) {
               ((JComponent)var3).setBorder(UIManager.getBorder("Table.scrollPaneBorder"));
            }
         }
      }

   }

   public int convertColumnIndexToModel(int var1) {
      return var1 < 0 ? var1 : this.getColumnModel().getColumn(var1).getModelIndex();
   }

   public int convertColumnIndexToView(int var1) {
      if (var1 < 0) {
         return var1;
      } else {
         TableColumnModel var2 = this.getColumnModel();

         for(int var3 = 0; var3 < this.getColumnCount(); ++var3) {
            if (var2.getColumn(var3).getModelIndex() == var1) {
               return var3;
            }
         }

         return -1;
      }
   }

   protected TableColumnModel createDefaultColumnModel() {
      return new DefaultTableColumnModel();
   }

   public void createDefaultColumnsFromModel() {
      TableModel var1 = this.getModel();
      if (var1 != null) {
         TableColumnModel var2 = this.getColumnModel();
         var2.removeColumnModelListener(this);

         while(var2.getColumnCount() > 0) {
            var2.removeColumn(var2.getColumn(0));
         }

         for(int var3 = 0; var3 < var1.getColumnCount(); ++var3) {
            TableColumn var4 = new TableColumn(var3);
            this.addColumn(var4);
         }

         var2.addColumnModelListener(this);
      }

   }

   protected TableModel createDefaultDataModel() {
      return new DefaultTableModel();
   }

   protected void createDefaultEditors() {
      this.defaultEditorsByColumnClass = new Hashtable();
      JTextField var1 = new JTextField();
      ((JComponent)var1).setBorder(new LineBorder(Color.black));
      this.setDefaultEditor(class$java$lang$Object != null ? class$java$lang$Object : (class$java$lang$Object = class$("java.lang.Object")), new DefaultCellEditor(var1));
      JTextField var2 = new JTextField();
      var2.setHorizontalAlignment(4);
      ((JComponent)var2).setBorder(new LineBorder(Color.black));
      this.setDefaultEditor(class$java$lang$Number != null ? class$java$lang$Number : (class$java$lang$Number = class$("java.lang.Number")), new DefaultCellEditor(var2));
      JCheckBox var3 = new JCheckBox();
      ((AbstractButton)var3).setHorizontalAlignment(0);
      this.setDefaultEditor(class$java$lang$Boolean != null ? class$java$lang$Boolean : (class$java$lang$Boolean = class$("java.lang.Boolean")), new DefaultCellEditor(var3));
   }

   protected void createDefaultRenderers() {
      this.defaultRenderersByColumnClass = new Hashtable();
      DefaultTableCellRenderer var1 = new DefaultTableCellRenderer();
      this.setDefaultRenderer(class$java$lang$Object != null ? class$java$lang$Object : (class$java$lang$Object = class$("java.lang.Object")), var1);
      7 var2 = new 7();
      ((JLabel)var2).setHorizontalAlignment(4);
      this.setDefaultRenderer(class$java$lang$Number != null ? class$java$lang$Number : (class$java$lang$Number = class$("java.lang.Number")), var2);
      8 var3 = new 8();
      ((JLabel)var3).setHorizontalAlignment(4);
      this.setDefaultRenderer(class$java$util$Date != null ? class$java$util$Date : (class$java$util$Date = class$("java.util.Date")), var3);
      9 var4 = new 9();
      ((JLabel)var4).setHorizontalAlignment(0);
      this.setDefaultRenderer(class$javax$swing$ImageIcon != null ? class$javax$swing$ImageIcon : (class$javax$swing$ImageIcon = class$("javax.swing.ImageIcon")), var4);
      CheckBoxRenderer var5 = new CheckBoxRenderer(this);
      ((AbstractButton)var5).setHorizontalAlignment(0);
      this.setDefaultRenderer(class$java$lang$Boolean != null ? class$java$lang$Boolean : (class$java$lang$Boolean = class$("java.lang.Boolean")), var5);
   }

   protected ListSelectionModel createDefaultSelectionModel() {
      return new DefaultListSelectionModel();
   }

   protected JTableHeader createDefaultTableHeader() {
      return new JTableHeader(this.columnModel);
   }

   /** @deprecated */
   public static JScrollPane createScrollPaneForTable(JTable var0) {
      return new JScrollPane(var0);
   }

   public boolean editCellAt(int var1, int var2) {
      return this.editCellAt(var1, var2, (EventObject)null);
   }

   public boolean editCellAt(int var1, int var2, EventObject var3) {
      if (this.cellEditor != null && !this.cellEditor.stopCellEditing()) {
         return false;
      } else if (!this.isCellEditable(var1, var2)) {
         return false;
      } else {
         TableCellEditor var4 = this.getCellEditor(var1, var2);
         if (var4 != null && var4.isCellEditable(var3)) {
            this.editorComp = this.prepareEditor(var4, var1, var2);
            this.editorComp.setBounds(this.getCellRect(var1, var2, false));
            ((Container)this).add(this.editorComp);
            this.editorComp.validate();
            this.setCellEditor(var4);
            this.setEditingRow(var1);
            this.setEditingColumn(var2);
            var4.addCellEditorListener(this);
            return true;
         } else {
            return false;
         }
      }
   }

   public void editingCanceled(ChangeEvent var1) {
      this.removeEditor();
   }

   public void editingStopped(ChangeEvent var1) {
      TableCellEditor var2 = this.getCellEditor();
      if (var2 != null) {
         Object var3 = var2.getCellEditorValue();
         this.setValueAt(var3, this.editingRow, this.editingColumn);
         this.removeEditor();
      }

   }

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleJTable(this);
      }

      return super.accessibleContext;
   }

   public boolean getAutoCreateColumnsFromModel() {
      return this.autoCreateColumnsFromModel;
   }

   public int getAutoResizeMode() {
      return this.autoResizeMode;
   }

   public TableCellEditor getCellEditor() {
      return this.cellEditor;
   }

   public TableCellEditor getCellEditor(int var1, int var2) {
      TableColumn var3 = this.getColumnModel().getColumn(var2);
      TableCellEditor var4 = var3.getCellEditor();
      if (var4 == null) {
         var4 = this.getDefaultEditor(this.getColumnClass(var2));
      }

      return var4;
   }

   public Rectangle getCellRect(int var1, int var2, boolean var3) {
      int var4 = 0;
      int var6 = this.getColumnModel().getColumnMargin();
      Enumeration var7 = this.getColumnModel().getColumns();
      Rectangle var5 = new Rectangle();
      var5.height = this.getRowHeight() + this.rowMargin;

      for(var5.y = var1 * var5.height; var7.hasMoreElements(); ++var4) {
         TableColumn var8 = (TableColumn)var7.nextElement();
         var5.width = var8.getWidth() + var6;
         if (var4 == var2) {
            break;
         }

         var5.x += var5.width;
      }

      if (!var3) {
         Dimension var9 = this.getIntercellSpacing();
         var5.setBounds(var5.x + var9.width / 2, var5.y + var9.height / 2, var5.width - var9.width, var5.height - var9.height);
      }

      return var5;
   }

   public TableCellRenderer getCellRenderer(int var1, int var2) {
      TableColumn var3 = this.getColumnModel().getColumn(var2);
      TableCellRenderer var4 = var3.getCellRenderer();
      if (var4 == null) {
         var4 = this.getDefaultRenderer(this.getColumnClass(var2));
      }

      return var4;
   }

   public boolean getCellSelectionEnabled() {
      return this.cellSelectionEnabled;
   }

   public TableColumn getColumn(Object var1) {
      TableColumnModel var2 = this.getColumnModel();
      int var3 = var2.getColumnIndex(var1);
      return var2.getColumn(var3);
   }

   public Class getColumnClass(int var1) {
      return this.getModel().getColumnClass(this.convertColumnIndexToModel(var1));
   }

   public int getColumnCount() {
      return this.getColumnModel().getColumnCount();
   }

   public TableColumnModel getColumnModel() {
      return this.columnModel;
   }

   public String getColumnName(int var1) {
      return this.getModel().getColumnName(this.convertColumnIndexToModel(var1));
   }

   public boolean getColumnSelectionAllowed() {
      return this.columnModel.getColumnSelectionAllowed();
   }

   public TableCellEditor getDefaultEditor(Class var1) {
      if (var1 == null) {
         return null;
      } else {
         Object var2 = this.defaultEditorsByColumnClass.get(var1);
         return var2 != null ? (TableCellEditor)var2 : this.getDefaultEditor(var1.getSuperclass());
      }
   }

   public TableCellRenderer getDefaultRenderer(Class var1) {
      if (var1 == null) {
         return null;
      } else {
         Object var2 = this.defaultRenderersByColumnClass.get(var1);
         return var2 != null ? (TableCellRenderer)var2 : this.getDefaultRenderer(var1.getSuperclass());
      }
   }

   public int getEditingColumn() {
      return this.editingColumn;
   }

   public int getEditingRow() {
      return this.editingRow;
   }

   public Component getEditorComponent() {
      return this.editorComp;
   }

   public Color getGridColor() {
      return this.gridColor;
   }

   public Dimension getIntercellSpacing() {
      return new Dimension(this.getColumnModel().getColumnMargin(), this.rowMargin);
   }

   public TableModel getModel() {
      return this.dataModel;
   }

   public Dimension getPreferredScrollableViewportSize() {
      return this.preferredViewportSize;
   }

   public int getRowCount() {
      return this.getModel().getRowCount();
   }

   public int getRowHeight() {
      return this.rowHeight;
   }

   public int getRowMargin() {
      return this.rowMargin;
   }

   public boolean getRowSelectionAllowed() {
      return this.rowSelectionAllowed;
   }

   public int getScrollableBlockIncrement(Rectangle var1, int var2, int var3) {
      if (var2 == 1) {
         int var4 = this.getRowHeight() + this.getRowMargin();
         return var4 > 0 ? Math.max(var4, var1.height / var4 * var4) : var1.height;
      } else {
         return var1.width;
      }
   }

   public boolean getScrollableTracksViewportHeight() {
      return false;
   }

   public boolean getScrollableTracksViewportWidth() {
      return this.autoResizeMode != 0;
   }

   public int getScrollableUnitIncrement(Rectangle var1, int var2, int var3) {
      return var2 == 0 ? 100 : this.rowHeight + this.rowMargin;
   }

   public int getSelectedColumn() {
      return this.columnModel.getSelectionModel().getMinSelectionIndex();
   }

   public int getSelectedColumnCount() {
      return this.columnModel.getSelectedColumnCount();
   }

   public int[] getSelectedColumns() {
      return this.columnModel.getSelectedColumns();
   }

   public int getSelectedRow() {
      return this.selectionModel.getMinSelectionIndex();
   }

   public int getSelectedRowCount() {
      if (this.selectionModel != null) {
         int var1 = this.selectionModel.getMinSelectionIndex();
         int var2 = this.selectionModel.getMaxSelectionIndex();
         int var3 = 0;

         for(int var4 = var1; var4 <= var2; ++var4) {
            if (this.selectionModel.isSelectedIndex(var4)) {
               ++var3;
            }
         }

         return var3;
      } else {
         return 0;
      }
   }

   public int[] getSelectedRows() {
      if (this.selectionModel != null) {
         int var1 = this.selectionModel.getMinSelectionIndex();
         int var2 = this.selectionModel.getMaxSelectionIndex();
         if (var1 != -1 && var2 != -1) {
            int[] var3 = new int[1 + (var2 - var1)];
            int var4 = 0;

            for(int var5 = var1; var5 <= var2; ++var5) {
               if (this.selectionModel.isSelectedIndex(var5)) {
                  var3[var4++] = var5;
               }
            }

            int[] var6 = new int[var4];
            System.arraycopy(var3, 0, var6, 0, var4);
            return var6;
         } else {
            return new int[0];
         }
      } else {
         return new int[0];
      }
   }

   public Color getSelectionBackground() {
      return this.selectionBackground;
   }

   public Color getSelectionForeground() {
      return this.selectionForeground;
   }

   public ListSelectionModel getSelectionModel() {
      return this.selectionModel;
   }

   public boolean getShowHorizontalLines() {
      return this.showHorizontalLines;
   }

   public boolean getShowVerticalLines() {
      return this.showVerticalLines;
   }

   public JTableHeader getTableHeader() {
      return this.tableHeader;
   }

   public String getToolTipText(MouseEvent var1) {
      String var2 = null;
      Point var3 = var1.getPoint();
      int var4 = this.columnAtPoint(var3);
      int var5 = this.rowAtPoint(var3);
      if (var4 != -1 && var5 != -1) {
         TableCellRenderer var6 = this.getCellRenderer(var5, var4);
         Component var7 = this.prepareRenderer(var6, var5, var4);
         if (var7 instanceof JComponent) {
            Rectangle var8 = this.getCellRect(var5, var4, false);
            var3.translate(-var8.x, -var8.y);
            MouseEvent var9 = new MouseEvent(var7, ((AWTEvent)var1).getID(), ((InputEvent)var1).getWhen(), ((InputEvent)var1).getModifiers(), var3.x, var3.y, var1.getClickCount(), var1.isPopupTrigger());
            var2 = ((JComponent)var7).getToolTipText(var9);
         }
      }

      if (var2 == null) {
         var2 = ((JComponent)this).getToolTipText();
      }

      return var2;
   }

   public TableUI getUI() {
      return (TableUI)super.ui;
   }

   public String getUIClassID() {
      return "TableUI";
   }

   public Object getValueAt(int var1, int var2) {
      return this.getModel().getValueAt(var1, this.convertColumnIndexToModel(var2));
   }

   protected void initializeLocalVars() {
      this.getSelectionModel().setAnchorSelectionIndex(0);
      this.columnModel.getSelectionModel().setAnchorSelectionIndex(0);
      ((JComponent)this).setOpaque(true);
      this.createDefaultRenderers();
      this.createDefaultEditors();
      this.setTableHeader(this.createDefaultTableHeader());
      this.setShowGrid(true);
      this.setAutoResizeMode(2);
      this.setRowHeight(16);
      this.rowMargin = 1;
      this.setRowSelectionAllowed(true);
      this.setCellSelectionEnabled(false);
      this.cellEditor = null;
      this.editingColumn = this.editingRow = -1;
      this.preferredViewportSize = new Dimension(450, 400);
      ToolTipManager var1 = ToolTipManager.sharedInstance();
      var1.registerComponent(this);
      ((JComponent)this).setAutoscrolls(true);
   }

   public boolean isCellEditable(int var1, int var2) {
      return this.getModel().isCellEditable(var1, this.convertColumnIndexToModel(var2));
   }

   public boolean isCellSelected(int var1, int var2) {
      if (this.cellSelectionEnabled) {
         return this.isRowSelected(var1) && this.isColumnSelected(var2);
      } else {
         return this.getRowSelectionAllowed() && this.isRowSelected(var1) || this.getColumnSelectionAllowed() && this.isColumnSelected(var2);
      }
   }

   public boolean isColumnSelected(int var1) {
      return this.columnModel.getSelectionModel().isSelectedIndex(var1);
   }

   public boolean isEditing() {
      return this.cellEditor != null;
   }

   public boolean isManagingFocus() {
      return true;
   }

   public boolean isRowSelected(int var1) {
      return this.selectionModel != null ? this.selectionModel.isSelectedIndex(var1) : false;
   }

   public void moveColumn(int var1, int var2) {
      this.getColumnModel().moveColumn(var1, var2);
   }

   protected String paramString() {
      String var1 = this.gridColor != null ? this.gridColor.toString() : "";
      String var2 = this.showHorizontalLines ? "true" : "false";
      String var3 = this.showVerticalLines ? "true" : "false";
      String var4;
      if (this.autoResizeMode == 0) {
         var4 = "AUTO_RESIZE_OFF";
      } else if (this.autoResizeMode == 1) {
         var4 = "AUTO_RESIZE_NEXT_COLUMN";
      } else if (this.autoResizeMode == 2) {
         var4 = "AUTO_RESIZE_SUBSEQUENT_COLUMNS";
      } else if (this.autoResizeMode == 3) {
         var4 = "AUTO_RESIZE_LAST_COLUMN";
      } else if (this.autoResizeMode == 4) {
         var4 = "AUTO_RESIZE_ALL_COLUMNS";
      } else {
         var4 = "";
      }

      String var5 = this.autoCreateColumnsFromModel ? "true" : "false";
      String var6 = this.preferredViewportSize != null ? this.preferredViewportSize.toString() : "";
      String var7 = this.rowSelectionAllowed ? "true" : "false";
      String var8 = this.cellSelectionEnabled ? "true" : "false";
      String var9 = this.selectionForeground != null ? this.selectionForeground.toString() : "";
      String var10 = this.selectionBackground != null ? this.selectionBackground.toString() : "";
      return super.paramString() + ",autoCreateColumnsFromModel=" + var5 + ",autoResizeMode=" + var4 + ",cellSelectionEnabled=" + var8 + ",editingColumn=" + this.editingColumn + ",editingRow=" + this.editingRow + ",gridColor=" + var1 + ",preferredViewportSize=" + var6 + ",rowHeight=" + this.rowHeight + ",rowMargin=" + this.rowMargin + ",rowSelectionAllowed=" + var7 + ",selectionBackground=" + var10 + ",selectionForeground=" + var9 + ",showHorizontalLines=" + var2 + ",showVerticalLines=" + var3;
   }

   public Component prepareEditor(TableCellEditor var1, int var2, int var3) {
      Object var4 = this.getValueAt(var2, var3);
      boolean var5 = this.isCellSelected(var2, var3);
      Component var6 = var1.getTableCellEditorComponent(this, var4, var5, var2, var3);
      if (var6 instanceof JComponent) {
         ((JComponent)var6).setNextFocusableComponent(this);
      }

      return var6;
   }

   public Component prepareRenderer(TableCellRenderer var1, int var2, int var3) {
      Object var4 = this.getValueAt(var2, var3);
      boolean var5 = this.isCellSelected(var2, var3);
      boolean var6 = this.selectionModel.getAnchorSelectionIndex() == var2;
      boolean var7 = this.columnModel.getSelectionModel().getAnchorSelectionIndex() == var3;
      boolean var8 = var6 && var7 && ((JComponent)this).hasFocus();
      return var1.getTableCellRendererComponent(this, var4, var5, var8, var2, var3);
   }

   private void readObject(ObjectInputStream var1) throws IOException, ClassNotFoundException {
      var1.defaultReadObject();
      if (super.ui != null && this.getUIClassID().equals("TableUI")) {
         super.ui.installUI(this);
      }

      this.createDefaultRenderers();
      this.createDefaultEditors();
   }

   public void removeColumn(TableColumn var1) {
      this.getColumnModel().removeColumn(var1);
   }

   public void removeColumnSelectionInterval(int var1, int var2) {
      this.columnModel.getSelectionModel().removeSelectionInterval(var1, var2);
   }

   public void removeEditor() {
      TableCellEditor var1 = this.getCellEditor();
      if (var1 != null) {
         var1.removeCellEditorListener(this);
         ((JComponent)this).requestFocus();
         ((Container)this).remove(this.editorComp);
         Rectangle var2 = this.getCellRect(this.editingRow, this.editingColumn, false);
         this.setCellEditor((TableCellEditor)null);
         this.setEditingColumn(-1);
         this.setEditingRow(-1);
         this.editorComp = null;
         ((JComponent)this).repaint(var2);
      }

   }

   public void removeRowSelectionInterval(int var1, int var2) {
      this.selectionModel.removeSelectionInterval(var1, var2);
   }

   public void reshape(int var1, int var2, int var3, int var4) {
      boolean var5 = ((JComponent)this).getWidth() != var3;
      super.reshape(var1, var2, var3, var4);
      if (var5) {
         this.sizeColumnsToFit(-1);
      }

   }

   protected void resizeAndRepaint() {
      ((JComponent)this).revalidate();
      ((Component)this).repaint();
   }

   public int rowAtPoint(Point var1) {
      int var2 = var1.y;
      int var3 = this.getRowHeight();
      int var4 = this.getIntercellSpacing().height;
      int var5 = var3 + var4;
      int var6 = var2 / var5;
      if (var6 < 0) {
         return -1;
      } else {
         return var6 >= this.getRowCount() ? -1 : var6;
      }
   }

   public void selectAll() {
      if (this.isEditing()) {
         this.removeEditor();
      }

      this.setRowSelectionInterval(0, this.getRowCount() - 1);
      this.setColumnSelectionInterval(0, this.getColumnCount() - 1);
   }

   public void setAutoCreateColumnsFromModel(boolean var1) {
      if (this.autoCreateColumnsFromModel != var1) {
         this.autoCreateColumnsFromModel = var1;
         if (this.autoCreateColumnsFromModel) {
            this.createDefaultColumnsFromModel();
         }
      }

   }

   public void setAutoResizeMode(int var1) {
      if (var1 == 0 || var1 == 1 || var1 == 2 || var1 == 3 || var1 == 4) {
         this.autoResizeMode = var1;
         this.resizeAndRepaint();
         if (this.tableHeader != null) {
            this.tableHeader.resizeAndRepaint();
         }
      }

   }

   public void setCellEditor(TableCellEditor var1) {
      TableCellEditor var2 = this.cellEditor;
      this.cellEditor = var1;
      ((JComponent)this).firePropertyChange("tableCellEditor", var2, var1);
   }

   public void setCellSelectionEnabled(boolean var1) {
      this.cellSelectionEnabled = var1;
   }

   public void setColumnModel(TableColumnModel var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("Cannot set a null ColumnModel");
      } else {
         TableColumnModel var2 = this.columnModel;
         if (var1 != var2) {
            if (var2 != null) {
               var2.removeColumnModelListener(this);
            }

            this.columnModel = var1;
            var1.addColumnModelListener(this);
            if (this.tableHeader != null) {
               this.tableHeader.setColumnModel(var1);
            }

            ((JComponent)this).firePropertyChange("columnModel", var2, var1);
            this.resizeAndRepaint();
         }

      }
   }

   public void setColumnSelectionAllowed(boolean var1) {
      this.columnModel.setColumnSelectionAllowed(var1);
   }

   public void setColumnSelectionInterval(int var1, int var2) {
      this.columnModel.getSelectionModel().setSelectionInterval(var1, var2);
   }

   public void setDefaultEditor(Class var1, TableCellEditor var2) {
      if (var2 != null) {
         this.defaultEditorsByColumnClass.put(var1, var2);
      } else {
         this.defaultEditorsByColumnClass.remove(var1);
      }

   }

   public void setDefaultRenderer(Class var1, TableCellRenderer var2) {
      if (var2 != null) {
         this.defaultRenderersByColumnClass.put(var1, var2);
      } else {
         this.defaultRenderersByColumnClass.remove(var1);
      }

   }

   public void setEditingColumn(int var1) {
      this.editingColumn = var1;
   }

   public void setEditingRow(int var1) {
      this.editingRow = var1;
   }

   public void setGridColor(Color var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("New color is null");
      } else {
         this.gridColor = var1;
         ((Component)this).repaint();
      }
   }

   public void setIntercellSpacing(Dimension var1) {
      this.rowMargin = var1.height;
      this.getColumnModel().setColumnMargin(var1.width);
      this.resizeAndRepaint();
   }

   public void setModel(TableModel var1) {
      TableModel var2 = this.dataModel;
      if (var1 == null) {
         throw new IllegalArgumentException("Cannot set a null TableModel");
      } else {
         if (var1 != var2) {
            if (var2 != null) {
               var2.removeTableModelListener(this);
            }

            this.dataModel = var1;
            var1.addTableModelListener(this);
            if (this.getColumnModel() != null) {
               this.tableChanged(new TableModelEvent(this.dataModel, -1));
            }

            ((JComponent)this).firePropertyChange("model", var2, var1);
         }

      }
   }

   public void setPreferredScrollableViewportSize(Dimension var1) {
      this.preferredViewportSize = var1;
   }

   public void setRowHeight(int var1) {
      if (var1 <= 0) {
         throw new IllegalArgumentException("New row height less than 1");
      } else {
         this.rowHeight = var1;
         this.resizeAndRepaint();
      }
   }

   public void setRowMargin(int var1) {
      this.rowMargin = var1;
   }

   public void setRowSelectionAllowed(boolean var1) {
      this.rowSelectionAllowed = var1;
   }

   public void setRowSelectionInterval(int var1, int var2) {
      this.selectionModel.setSelectionInterval(var1, var2);
   }

   public void setSelectionBackground(Color var1) {
      Color var2 = this.selectionBackground;
      this.selectionBackground = var1;
      ((JComponent)this).firePropertyChange("selectionBackground", var2, var1);
   }

   public void setSelectionForeground(Color var1) {
      Color var2 = this.selectionForeground;
      this.selectionForeground = var1;
      ((JComponent)this).firePropertyChange("selectionForeground", var2, var1);
   }

   public void setSelectionMode(int var1) {
      this.clearSelection();
      this.getSelectionModel().setSelectionMode(var1);
      this.getColumnModel().getSelectionModel().setSelectionMode(var1);
   }

   public void setSelectionModel(ListSelectionModel var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("Cannot set a null SelectionModel");
      } else {
         ListSelectionModel var2 = this.selectionModel;
         if (var1 != var2) {
            if (var2 != null) {
               var2.removeListSelectionListener(this);
            }

            this.selectionModel = var1;
            if (var1 != null) {
               var1.addListSelectionListener(this);
            }

            ((JComponent)this).firePropertyChange("selectionModel", var2, var1);
            ((Component)this).repaint();
         }

      }
   }

   public void setShowGrid(boolean var1) {
      this.setShowHorizontalLines(var1);
      this.setShowVerticalLines(var1);
      ((Component)this).repaint();
   }

   public void setShowHorizontalLines(boolean var1) {
      this.showHorizontalLines = var1;
      ((Component)this).repaint();
   }

   public void setShowVerticalLines(boolean var1) {
      this.showVerticalLines = var1;
      ((Component)this).repaint();
   }

   public void setTableHeader(JTableHeader var1) {
      if (this.tableHeader != var1) {
         if (this.tableHeader != null) {
            this.tableHeader.setTable((JTable)null);
         }

         this.tableHeader = var1;
         if (this.tableHeader != null) {
            this.tableHeader.setTable(this);
         }
      }

   }

   public void setUI(TableUI var1) {
      if (super.ui != var1) {
         super.setUI(var1);
         ((Component)this).repaint();
      }

   }

   public void setValueAt(Object var1, int var2, int var3) {
      this.getModel().setValueAt(var1, var2, this.convertColumnIndexToModel(var3));
   }

   private void setWidthsFromPreferredWidths(boolean var1) {
      int var2 = this.getColumnCount();
      int var3 = var2 * this.getColumnModel().getColumnMargin();
      int var4 = ((JComponent)this).getWidth() - var3;
      int var5 = ((JComponent)this).getPreferredSize().width - var3;
      int var6 = !var1 ? var4 : var5;
      TableColumnModel var7 = this.columnModel;
      3 var8 = new 3(var7, var1);
      this.adjustSizes((long)var6, (Resizable3)var8, var1);
   }

   public void sizeColumnsToFit(int var1) {
      if (var1 == -1) {
         this.setWidthsFromPreferredWidths(false);
      } else if (this.autoResizeMode == 0) {
         Enumeration var2 = this.getColumnModel().getColumns();

         while(var2.hasMoreElements()) {
            TableColumn var3 = (TableColumn)var2.nextElement();
            var3.setPreferredWidth(var3.getWidth());
         }
      } else {
         int var4 = ((JComponent)this).getWidth() - this.getColumnModel().getTotalColumnWidth();
         this.accommodateDelta(var1, var4);
      }

   }

   /** @deprecated */
   public void sizeColumnsToFit(boolean var1) {
      int var2 = this.autoResizeMode;
      this.setAutoResizeMode(var1 ? 3 : 4);
      this.sizeColumnsToFit(-1);
      this.setAutoResizeMode(var2);
   }

   public void tableChanged(TableModelEvent var1) {
      if (var1 != null && var1.getFirstRow() != -1) {
         if (var1.getType() == 1) {
            this.tableRowsInserted(var1);
         } else if (var1.getType() == -1) {
            this.tableRowsDeleted(var1);
         } else {
            int var2 = var1.getColumn();
            int var3 = var1.getFirstRow();
            int var4 = var1.getLastRow();
            if (var3 == -1) {
               var3 = 0;
               var4 = Integer.MAX_VALUE;
            }

            int var5 = this.getRowHeight() + this.rowMargin;
            Rectangle var6;
            if (var2 == -1) {
               var6 = new Rectangle(0, var3 * var5, this.getColumnModel().getTotalColumnWidth(), 0);
            } else {
               int var7 = this.convertColumnIndexToView(var2);
               var6 = this.getCellRect(var3, var7, false);
            }

            if (var4 != Integer.MAX_VALUE) {
               var6.height = (var4 - var3 + 1) * var5;
               ((Component)this).repaint(var6.x, var6.y, var6.width, var6.height);
            } else {
               this.resizeAndRepaint();
            }

         }
      } else {
         this.clearSelection();
         if (this.getAutoCreateColumnsFromModel()) {
            this.createDefaultColumnsFromModel();
         }

         this.resizeAndRepaint();
         if (this.tableHeader != null) {
            this.tableHeader.resizeAndRepaint();
         }

      }
   }

   private void tableRowsDeleted(TableModelEvent var1) {
      int var2 = var1.getFirstRow();
      int var3 = var1.getLastRow();
      if (var2 < 0) {
         var2 = 0;
      }

      int var4 = var3 - var2 + 1;
      int var5 = this.getRowCount() + var4;
      int var6 = this.getRowHeight() + this.rowMargin;
      Rectangle var7 = new Rectangle(0, var2 * var6, this.getColumnModel().getTotalColumnWidth(), (var5 - var2) * var6);
      if (this.selectionModel != null) {
         if (var3 < 0) {
            var3 = this.getRowCount() - 1;
         }

         this.selectionModel.removeIndexInterval(var2, var3);
      }

      ((JComponent)this).revalidate();
      ((JComponent)this).repaint(var7);
   }

   private void tableRowsInserted(TableModelEvent var1) {
      int var2 = var1.getFirstRow();
      int var3 = var1.getLastRow();
      if (var2 < 0) {
         var2 = 0;
      }

      int var4 = this.getRowHeight() + this.rowMargin;
      Rectangle var5 = new Rectangle(0, var2 * var4, this.getColumnModel().getTotalColumnWidth(), (this.getRowCount() - var2) * var4);
      if (this.selectionModel != null) {
         if (var3 < 0) {
            var3 = this.getRowCount() - 1;
         }

         int var6 = var3 - var2 + 1;
         this.selectionModel.insertIndexInterval(var2, var6, true);
      }

      ((JComponent)this).revalidate();
      ((JComponent)this).repaint(var5);
   }

   private void updateSubComponentUI(Object var1) {
      if (var1 != null) {
         Component var2 = null;
         if (var1 instanceof Component) {
            var2 = (Component)var1;
         }

         if (var1 instanceof DefaultCellEditor) {
            var2 = ((DefaultCellEditor)var1).getComponent();
         }

         if (var2 != null && var2 instanceof JComponent) {
            ((JComponent)var2).updateUI();
         }

      }
   }

   public void updateUI() {
      TableColumnModel var1 = this.getColumnModel();

      for(int var2 = 0; var2 < var1.getColumnCount(); ++var2) {
         TableColumn var3 = var1.getColumn(var2);
         this.updateSubComponentUI(var3.getCellEditor());
      }

      Enumeration var4 = this.defaultEditorsByColumnClass.elements();

      while(var4.hasMoreElements()) {
         this.updateSubComponentUI(var4.nextElement());
      }

      this.setUI((TableUI)UIManager.getUI(this));
      this.resizeAndRepaint();
      ((Container)this).invalidate();
   }

   public void valueChanged(ListSelectionEvent var1) {
      int var2 = var1.getFirstIndex();
      int var3 = var1.getLastIndex();
      if (var2 == -1 && var3 == -1) {
         ((Component)this).repaint();
      }

      Rectangle var4 = this.getCellRect(var2, 0, false);
      Rectangle var5 = this.getCellRect(var3, this.getColumnCount(), false);
      Rectangle var6 = var4.union(var5);
      ((Component)this).repaint(var6.x, var6.y, var6.width, var6.height);
   }
}
