package javax.swing;

import java.awt.Component;
import java.io.IOException;
import java.io.ObjectOutputStream;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.Caret;
import javax.swing.text.Document;
import javax.swing.text.EditorKit;
import javax.swing.text.Element;
import javax.swing.text.JTextComponent;
import javax.swing.text.MutableAttributeSet;
import javax.swing.text.Style;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyledDocument;
import javax.swing.text.StyledEditorKit;

public class JTextPane extends JEditorPane {
   private static final String uiClassID = "TextPaneUI";

   public JTextPane() {
      this.setEditorKit(new StyledEditorKit());
   }

   public JTextPane(StyledDocument var1) {
      this();
      this.setStyledDocument(var1);
   }

   public Style addStyle(String var1, Style var2) {
      StyledDocument var3 = this.getStyledDocument();
      return var3.addStyle(var1, var2);
   }

   protected EditorKit createDefaultEditorKit() {
      return new StyledEditorKit();
   }

   public AttributeSet getCharacterAttributes() {
      StyledDocument var1 = this.getStyledDocument();
      Element var2 = var1.getCharacterElement(((JTextComponent)this).getCaretPosition());
      return var2 != null ? var2.getAttributes() : null;
   }

   public MutableAttributeSet getInputAttributes() {
      return this.getStyledEditorKit().getInputAttributes();
   }

   public Style getLogicalStyle() {
      StyledDocument var1 = this.getStyledDocument();
      return var1.getLogicalStyle(((JTextComponent)this).getCaretPosition());
   }

   public AttributeSet getParagraphAttributes() {
      StyledDocument var1 = this.getStyledDocument();
      Element var2 = var1.getParagraphElement(((JTextComponent)this).getCaretPosition());
      return var2 != null ? var2.getAttributes() : null;
   }

   public boolean getScrollableTracksViewportWidth() {
      return true;
   }

   public Style getStyle(String var1) {
      StyledDocument var2 = this.getStyledDocument();
      return var2.getStyle(var1);
   }

   public StyledDocument getStyledDocument() {
      return (StyledDocument)((JTextComponent)this).getDocument();
   }

   protected final StyledEditorKit getStyledEditorKit() {
      return (StyledEditorKit)((JEditorPane)this).getEditorKit();
   }

   public String getUIClassID() {
      return "TextPaneUI";
   }

   public void insertComponent(Component var1) {
      MutableAttributeSet var2 = this.getInputAttributes();
      var2.removeAttributes(var2);
      StyleConstants.setComponent(var2, var1);
      this.replaceSelection(" ");
      var2.removeAttributes(var2);
   }

   public void insertIcon(Icon var1) {
      MutableAttributeSet var2 = this.getInputAttributes();
      var2.removeAttributes(var2);
      StyleConstants.setIcon(var2, var1);
      this.replaceSelection(" ");
      var2.removeAttributes(var2);
   }

   protected String paramString() {
      return super.paramString();
   }

   public void removeStyle(String var1) {
      StyledDocument var2 = this.getStyledDocument();
      var2.removeStyle(var1);
   }

   public void replaceSelection(String var1) {
      if (!((JTextComponent)this).isEditable()) {
         ((Component)this).getToolkit().beep();
      } else {
         StyledDocument var2 = this.getStyledDocument();
         if (var2 != null) {
            try {
               Caret var3 = ((JTextComponent)this).getCaret();
               int var4 = Math.min(var3.getDot(), var3.getMark());
               int var5 = Math.max(var3.getDot(), var3.getMark());
               if (var4 != var5) {
                  var2.remove(var4, var5 - var4);
               }

               if (var1 != null && var1.length() > 0) {
                  var2.insertString(var4, var1, this.getInputAttributes());
               }
            } catch (BadLocationException var6) {
               ((Component)this).getToolkit().beep();
            }
         }

      }
   }

   public void setCharacterAttributes(AttributeSet var1, boolean var2) {
      int var3 = ((JTextComponent)this).getSelectionStart();
      int var4 = ((JTextComponent)this).getSelectionEnd();
      if (var3 != var4) {
         StyledDocument var5 = this.getStyledDocument();
         var5.setCharacterAttributes(var3, var4 - var3, var1, var2);
      } else {
         MutableAttributeSet var6 = this.getInputAttributes();
         if (var2) {
            var6.removeAttributes(var6);
         }

         var6.addAttributes(var1);
      }

   }

   public void setDocument(Document var1) {
      if (var1 instanceof StyledDocument) {
         super.setDocument(var1);
      } else {
         throw new IllegalArgumentException("Model must be StyledDocument");
      }
   }

   public final void setEditorKit(EditorKit var1) {
      if (var1 instanceof StyledEditorKit) {
         super.setEditorKit(var1);
      } else {
         throw new IllegalArgumentException("Must be StyledEditorKit");
      }
   }

   public void setLogicalStyle(Style var1) {
      StyledDocument var2 = this.getStyledDocument();
      var2.setLogicalStyle(((JTextComponent)this).getCaretPosition(), var1);
   }

   public void setParagraphAttributes(AttributeSet var1, boolean var2) {
      int var3 = ((JTextComponent)this).getSelectionStart();
      int var4 = ((JTextComponent)this).getSelectionEnd();
      StyledDocument var5 = this.getStyledDocument();
      var5.setParagraphAttributes(var3, var4 - var3, var1, var2);
   }

   public void setStyledDocument(StyledDocument var1) {
      super.setDocument(var1);
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      if (super.ui != null && this.getUIClassID().equals("TextPaneUI")) {
         super.ui.installUI(this);
      }

   }
}
