package javax.swing.plaf.metal;

import java.awt.Container;
import java.beans.PropertyChangeListener;
import javax.swing.JComponent;
import javax.swing.JInternalFrame;
import javax.swing.LookAndFeel;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.UIResource;
import javax.swing.plaf.basic.BasicInternalFrameUI;

public class MetalInternalFrameUI extends BasicInternalFrameUI {
   private MetalInternalFrameTitlePane titlePane;
   private PropertyChangeListener paletteListener;
   private PropertyChangeListener contentPaneListener;
   private static final Border handyEmptyBorder = new EmptyBorder(0, 0, 0, 0);
   protected static String IS_PALETTE = "JInternalFrame.isPalette";

   public MetalInternalFrameUI(JInternalFrame var1) {
      super(var1);
   }

   // $FF: synthetic method
   static void access$0(MetalInternalFrameUI var0, Object var1) {
      var0.stripContentBorder(var1);
   }

   protected JComponent createNorthPane(JInternalFrame var1) {
      this.titlePane = new MetalInternalFrameTitlePane(var1);
      return this.titlePane;
   }

   public static ComponentUI createUI(JComponent var0) {
      return new MetalInternalFrameUI((JInternalFrame)var0);
   }

   protected void installKeyboardActions() {
   }

   public void installUI(JComponent var1) {
      super.frame = (JInternalFrame)var1;
      this.paletteListener = new PaletteListener(this);
      this.contentPaneListener = new ContentPaneListener(this);
      var1.addPropertyChangeListener(this.paletteListener);
      var1.addPropertyChangeListener(this.contentPaneListener);
      super.installUI(var1);
      Object var2 = var1.getClientProperty(IS_PALETTE);
      if (var2 != null) {
         this.setPalette((Boolean)var2);
      }

      Container var3 = super.frame.getContentPane();
      this.stripContentBorder(var3);
   }

   protected void replacePane(JComponent var1, JComponent var2) {
      super.replacePane(var1, var2);
      if (var1 != null && var1 instanceof MetalInternalFrameTitlePane) {
         super.frame.removePropertyChangeListener((PropertyChangeListener)var1);
      }

   }

   public void setPalette(boolean var1) {
      if (var1) {
         LookAndFeel.installBorder(super.frame, "InternalFrame.paletteBorder");
      } else {
         LookAndFeel.installBorder(super.frame, "InternalFrame.border");
      }

      this.titlePane.setPalette(var1);
   }

   private void stripContentBorder(Object var1) {
      if (var1 instanceof JComponent) {
         JComponent var2 = (JComponent)var1;
         Border var3 = var2.getBorder();
         if (var3 == null || var3 instanceof UIResource) {
            var2.setBorder(handyEmptyBorder);
         }
      }

   }

   protected void uninstallKeyboardActions() {
   }

   public void uninstallUI(JComponent var1) {
      var1.removePropertyChangeListener(this.paletteListener);
      var1.removePropertyChangeListener(this.contentPaneListener);
      Container var2 = ((JInternalFrame)var1).getContentPane();
      if (var2 instanceof JComponent) {
         JComponent var3 = (JComponent)var2;
         if (var3.getBorder() == handyEmptyBorder) {
            var3.setBorder((Border)null);
         }
      }

      super.uninstallUI(var1);
   }
}
