package javax.swing.plaf.metal;

import java.awt.Component;
import java.awt.Container;
import java.awt.Insets;
import java.awt.Point;
import java.awt.event.ContainerListener;
import java.beans.PropertyChangeListener;
import java.util.Hashtable;
import javax.swing.AbstractButton;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.SwingUtilities;
import javax.swing.border.Border;
import javax.swing.border.CompoundBorder;
import javax.swing.event.MouseInputListener;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.UIResource;
import javax.swing.plaf.basic.BasicBorders;
import javax.swing.plaf.basic.BasicToolBarUI;

public class MetalToolBarUI extends BasicToolBarUI {
   private static Border rolloverBorder = new CompoundBorder(new MetalBorders.RolloverButtonBorder(), new BasicBorders.MarginBorder());
   private static Border nonRolloverBorder = new CompoundBorder(new MetalBorders.ButtonBorder(), new BasicBorders.MarginBorder());
   protected ContainerListener contListener;
   protected PropertyChangeListener rolloverListener;
   private Hashtable borderTable = new Hashtable();
   private Hashtable marginTable = new Hashtable();
   private boolean rolloverBorders = false;
   private static String IS_ROLLOVER = "JToolBar.isRollover";
   private static final Insets insets0 = new Insets(0, 0, 0, 0);

   // $FF: synthetic method
   static boolean access$0(MetalToolBarUI var0) {
      return var0.rolloverBorders;
   }

   // $FF: synthetic method
   static String access$1() {
      return IS_ROLLOVER;
   }

   protected ContainerListener createContainerListener() {
      return new MetalContainerListener(this);
   }

   protected MouseInputListener createDockingListener() {
      return new MetalDockingListener(this, super.toolBar);
   }

   protected PropertyChangeListener createRolloverListener() {
      return new MetalRolloverListener(this);
   }

   public static ComponentUI createUI(JComponent var0) {
      return new MetalToolBarUI();
   }

   protected void installListeners() {
      super.installListeners();
      this.contListener = this.createContainerListener();
      if (this.contListener != null) {
         super.toolBar.addContainerListener(this.contListener);
      }

      this.rolloverListener = this.createRolloverListener();
      if (this.rolloverListener != null) {
         super.toolBar.addPropertyChangeListener(this.rolloverListener);
      }

   }

   protected void installNonRolloverBorders(JComponent var1) {
      Component[] var2 = ((Container)var1).getComponents();

      for(int var3 = 0; var3 < var2.length; ++var3) {
         if (var2[var3] instanceof JComponent) {
            ((JComponent)var2[var3]).updateUI();
            this.setBorderToNonRollover(var2[var3]);
         }
      }

   }

   protected void installNormalBorders(JComponent var1) {
      Component[] var2 = ((Container)var1).getComponents();

      for(int var3 = 0; var3 < var2.length; ++var3) {
         this.setBorderToNormal(var2[var3]);
      }

   }

   protected void installRolloverBorders(JComponent var1) {
      Component[] var2 = ((Container)var1).getComponents();

      for(int var3 = 0; var3 < var2.length; ++var3) {
         if (var2[var3] instanceof JComponent) {
            ((JComponent)var2[var3]).updateUI();
            this.setBorderToRollover(var2[var3]);
         }
      }

   }

   public void installUI(JComponent var1) {
      super.installUI(var1);
      Object var2 = var1.getClientProperty(IS_ROLLOVER);
      if (var2 != null) {
         this.rolloverBorders = (Boolean)var2;
      } else {
         this.rolloverBorders = false;
      }

      SwingUtilities.invokeLater(new 1(this));
   }

   public boolean isRolloverBorders() {
      return this.rolloverBorders;
   }

   protected void setBorderToNonRollover(Component var1) {
      if (var1 instanceof JButton) {
         JButton var2 = (JButton)var1;
         if (((AbstractButton)var2).getUI() instanceof MetalButtonUI) {
            if (((JComponent)var2).getBorder() instanceof UIResource) {
               this.borderTable.put(var2, ((JComponent)var2).getBorder());
            }

            if (((JComponent)var2).getBorder() instanceof UIResource || ((JComponent)var2).getBorder() == rolloverBorder) {
               ((JComponent)var2).setBorder(nonRolloverBorder);
            }

            if (((AbstractButton)var2).getMargin() == null || ((AbstractButton)var2).getMargin() instanceof UIResource) {
               this.marginTable.put(var2, ((AbstractButton)var2).getMargin());
               ((AbstractButton)var2).setMargin(insets0);
            }

            ((AbstractButton)var2).setRolloverEnabled(false);
         }
      }

   }

   protected void setBorderToNormal(Component var1) {
      if (var1 instanceof JButton) {
         JButton var2 = (JButton)var1;
         if (((AbstractButton)var2).getUI() instanceof MetalButtonUI) {
            if (((JComponent)var2).getBorder() == rolloverBorder || ((JComponent)var2).getBorder() == nonRolloverBorder) {
               ((JComponent)var2).setBorder((Border)this.borderTable.remove(var2));
            }

            if (((AbstractButton)var2).getMargin() == insets0) {
               ((AbstractButton)var2).setMargin((Insets)this.marginTable.remove(var2));
            }

            ((AbstractButton)var2).setRolloverEnabled(false);
         }
      }

   }

   protected void setBorderToRollover(Component var1) {
      if (var1 instanceof JButton) {
         JButton var2 = (JButton)var1;
         if (((AbstractButton)var2).getUI() instanceof MetalButtonUI) {
            if (((JComponent)var2).getBorder() instanceof UIResource) {
               this.borderTable.put(var2, ((JComponent)var2).getBorder());
            }

            if (((JComponent)var2).getBorder() instanceof UIResource || ((JComponent)var2).getBorder() == nonRolloverBorder) {
               ((JComponent)var2).setBorder(rolloverBorder);
            }

            if (((AbstractButton)var2).getMargin() == null || ((AbstractButton)var2).getMargin() instanceof UIResource) {
               this.marginTable.put(var2, ((AbstractButton)var2).getMargin());
               ((AbstractButton)var2).setMargin(insets0);
            }

            ((AbstractButton)var2).setRolloverEnabled(true);
         }
      }

   }

   protected void setDragOffset(Point var1) {
      if (super.dragWindow == null) {
         super.dragWindow = ((BasicToolBarUI)this).createDragWindow(super.toolBar);
      }

      super.dragWindow.setOffset(var1);
   }

   public void setRolloverBorders(boolean var1) {
      this.rolloverBorders = var1;
      if (this.rolloverBorders) {
         this.installRolloverBorders(super.toolBar);
      } else {
         this.installNonRolloverBorders(super.toolBar);
      }

   }

   protected void uninstallListeners() {
      super.uninstallListeners();
      if (this.contListener != null) {
         super.toolBar.removeContainerListener(this.contListener);
      }

      this.contListener = null;
      if (this.rolloverListener != null) {
         super.toolBar.removePropertyChangeListener(this.rolloverListener);
      }

      this.rolloverListener = null;
   }

   public void uninstallUI(JComponent var1) {
      super.uninstallUI(var1);
      this.installNormalBorders(var1);
   }
}
